@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 # Majority of code shamelessly stolen from
 # http://www.v13.gr/blog/?p=303
-'''
+"""
 Authenticate via a PKI certificate.
 
 .. note::
@@ -14,38 +13,45 @@ a user via their public cert against a pre-defined Certificate Authority.
 TODO: Add a 'ca_dir' option to configure a directory of CA files, a la Apache.
 
 :depends:    - pyOpenSSL module
-'''
-# Import python libs
-from __future__ import absolute_import
+"""
 import logging
 
-# Import third party libs
+import salt.utils.files
+import salt.utils.versions
+
 # pylint: disable=import-error
 try:
-    from Crypto.Util import asn1
-    import OpenSSL
+    try:
+        from M2Crypto import X509
+
+        HAS_M2 = True
+    except ImportError:
+        HAS_M2 = False
+        try:
+            from Cryptodome.Util import asn1
+        except ImportError:
+            from Crypto.Util import asn1  # nosec
+        import OpenSSL  # pylint: disable=W8410
     HAS_DEPS = True
 except ImportError:
     HAS_DEPS = False
 # pylint: enable=import-error
 
-# Import salt libs
-import salt.utils
 
 log = logging.getLogger(__name__)
 
 
 def __virtual__():
-    '''
+    """
     Requires newer pycrypto and pyOpenSSL
-    '''
+    """
     if HAS_DEPS:
         return True
     return False
 
 
 def auth(username, password, **kwargs):
-    '''
+    """
     Returns True if the given user cert (password is the cert contents)
     was issued by the CA and if cert's Common Name is equal to username.
 
@@ -65,18 +71,32 @@ def auth(username, password, **kwargs):
             ca_file: /etc/pki/tls/ca_certs/trusted-ca.crt
             your_user:
               - .*
-    '''
-    c = OpenSSL.crypto
+    """
+    salt.utils.versions.warn_until(
+        3008,
+        "This module has been deprecated as it is known to be insecure.",
+    )
     pem = password
-    cert = OpenSSL.crypto.load_certificate(OpenSSL.crypto.FILETYPE_PEM, pem)
+    cacert_file = __salt__["config.get"]("external_auth:pki:ca_file")
 
-    cacert_file = __salt__['config.get']('external_auth:pki:ca_file')
-    with salt.utils.fopen(cacert_file) as f:
-        cacert = OpenSSL.crypto.load_certificate(OpenSSL.crypto.FILETYPE_PEM, f.read())
+    log.debug("Attempting to authenticate via pki.")
+    log.debug("Using CA file: %s", cacert_file)
+    log.debug("Certificate contents: %s", pem)
 
-    log.debug('Attempting to authenticate via pki.')
-    log.debug('Using CA file: {0}'.format(cacert_file))
-    log.debug('Certificate contents: {0}'.format(pem))
+    if HAS_M2:
+        cert = X509.load_cert_string(pem, X509.FORMAT_PEM)
+        cacert = X509.load_cert(cacert_file, X509.FORMAT_PEM)
+        if cert.verify(cacert.get_pubkey()):
+            log.info("Successfully authenticated certificate: %s", pem)
+            return True
+        log.info("Failed to authenticate certificate: %s", pem)
+        return False
+
+    c = OpenSSL.crypto  # pylint: disable=used-before-assignment
+    cert = c.load_certificate(c.FILETYPE_PEM, pem)
+
+    with salt.utils.files.fopen(cacert_file) as f:
+        cacert = c.load_certificate(c.FILETYPE_PEM, f.read())
 
     # Get the signing algorithm
     algo = cert.get_signature_algorithm()
@@ -85,7 +105,7 @@ def auth(username, password, **kwargs):
     cert_asn1 = c.dump_certificate(c.FILETYPE_ASN1, cert)
 
     # Decode the certificate
-    der = asn1.DerSequence()
+    der = asn1.DerSequence()  # pylint: disable=used-before-assignment
     der.decode(cert_asn1)
 
     # The certificate has three parts:
@@ -94,7 +114,7 @@ def auth(username, password, **kwargs):
     # - signature
     # http://usefulfor.com/nothing/2009/06/10/x509-certificate-basics/
     der_cert = der[0]
-    #der_algo = der[1]
+    # der_algo = der[1]
     der_sig = der[2]
 
     # The signature is a BIT STRING (Type 3)
@@ -110,17 +130,19 @@ def auth(username, password, **kwargs):
 
     # First byte is the number of unused bits. This should be 0
     # http://msdn.microsoft.com/en-us/library/windows/desktop/bb540792(v=vs.85).aspx
-    if sig0[0] != '\x00':
-        raise Exception('Number of unused bits is strange')
+    if sig0[0] != "\x00":
+        raise Exception("Number of unused bits is strange")
     # Now get the signature itself
     sig = sig0[1:]
 
     # And verify the certificate
     try:
         c.verify(cacert, sig, der_cert, algo)
-        assert dict(cert.get_subject().get_components())['CN'] == username, "Certificate's CN should match the username"
-        log.info('Successfully authenticated certificate: {0}'.format(pem))
+        assert (
+            dict(cert.get_subject().get_components())["CN"] == username
+        ), "Certificate's CN should match the username"
+        log.info("Successfully authenticated certificate: %s", pem)
         return True
     except (OpenSSL.crypto.Error, AssertionError):
-        log.info('Failed to authenticate certificate: {0}'.format(pem))
+        log.info("Failed to authenticate certificate: %s", pem)
     return False
