@@ -412,9 +412,7 @@ def get_image(vm_):
 
     if vm_image and str(vm_image) in images:
         return images[vm_image]["ImageId"]
-    raise SaltCloudNotFound(
-        "The specified image, '{}', could not be found.".format(vm_image)
-    )
+    raise SaltCloudNotFound(f"The specified image, '{vm_image}', could not be found.")
 
 
 def get_securitygroup(vm_):
@@ -432,7 +430,7 @@ def get_securitygroup(vm_):
     if securitygroup and str(securitygroup) in sgs:
         return sgs[securitygroup]["SecurityGroupId"]
     raise SaltCloudNotFound(
-        "The specified security group, '{}', could not be found.".format(securitygroup)
+        f"The specified security group, '{securitygroup}', could not be found."
     )
 
 
@@ -451,9 +449,7 @@ def get_size(vm_):
     if vm_size and str(vm_size) in sizes:
         return sizes[vm_size]["InstanceTypeId"]
 
-    raise SaltCloudNotFound(
-        "The specified size, '{}', could not be found.".format(vm_size)
-    )
+    raise SaltCloudNotFound(f"The specified size, '{vm_size}', could not be found.")
 
 
 def __get_location(vm_):
@@ -471,7 +467,7 @@ def __get_location(vm_):
     if vm_location and str(vm_location) in locations:
         return locations[vm_location]["RegionId"]
     raise SaltCloudNotFound(
-        "The specified location, '{}', could not be found.".format(vm_location)
+        f"The specified location, '{vm_location}', could not be found."
     )
 
 
@@ -575,7 +571,7 @@ def create_node(kwargs):
         "HostName",
         "Password",
         "SystemDisk.Category",
-        "VSwitchId"
+        "VSwitchId",
         # 'DataDisk.n.Size', 'DataDisk.n.Category', 'DataDisk.n.SnapshotId'
     ]
 
@@ -798,7 +794,7 @@ def query(params=None):
     signature = _compute_signature(parameters, access_key_secret)
     parameters["Signature"] = signature
 
-    request = requests.get(path, params=parameters, verify=True)
+    request = requests.get(path, params=parameters, verify=True, timeout=120)
     if request.status_code != 200:
         raise SaltCloudSystemExit(
             "An error occurred while querying aliyun ECS. HTTP Code: {}  "
@@ -920,7 +916,7 @@ def _get_node(name):
             )
             # Just a little delay between attempts...
             time.sleep(0.5)
-    raise SaltCloudNotFound("The specified instance {} not found".format(name))
+    raise SaltCloudNotFound(f"The specified instance {name} not found")
 
 
 def show_image(kwargs, call=None):
@@ -982,7 +978,7 @@ def destroy(name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "destroying instance",
-        "salt/cloud/{}/destroying".format(name),
+        f"salt/cloud/{name}/destroying",
         args={"name": name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -1001,7 +997,7 @@ def destroy(name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "destroyed instance",
-        "salt/cloud/{}/destroyed".format(name),
+        f"salt/cloud/{name}/destroyed",
         args={"name": name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
