@@ -91,6 +91,7 @@ The salt specific ones are:
   - ssh_key_file: The name of the keypair in openstack
   - userdata_template: The renderer to use if the userdata is a file that is templated. Default: False
   - ssh_interface: The interface to use to login for bootstrapping: public_ips, private_ips, floating_ips, fixed_ips
+  - ignore_cidr: Specify a CIDR range of unreachable private addresses for salt to ignore when connecting
 
 .. code-block:: yaml
 
@@ -120,6 +121,15 @@ If metadata is set to make sure that the host has finished setting up the
         rax_service_level_automation: Complete
         rackconnect_automation_status: DEPLOYED
 
+If your OpenStack instances only have private IP addresses and a CIDR range of
+private addresses are not reachable from the salt-master, you may set your
+preference to have Salt ignore it:
+
+.. code-block:: yaml
+
+    my-openstack-config:
+      ignore_cidr: 192.168.0.0/16
+
 Anything else from the create_server_ docs can be passed through here.
 
 - **image**: Image dict, name or ID to boot with. image is required
@@ -221,28 +231,28 @@ import pprint
 import socket
 
 import salt.config as config
-import salt.utils.versions
 from salt.exceptions import (
     SaltCloudConfigError,
     SaltCloudExecutionFailure,
     SaltCloudExecutionTimeout,
     SaltCloudSystemExit,
 )
+from salt.utils.versions import Version
 
 try:
-    import shade
-    import shade.openstackcloud
-    import shade.exc
     import os_client_config
+    import shade
+    import shade.exc
+    import shade.openstackcloud
 
     HAS_SHADE = (
-        salt.utils.versions._LooseVersion(shade.__version__)
-        >= salt.utils.versions._LooseVersion("1.19.0"),
+        Version(shade.__version__) >= Version("1.19.0"),
         "Please install newer version of shade: >= 1.19.0",
     )
 except ImportError:
     HAS_SHADE = (False, "Install pypi module shade >= 1.19.0")
 
+
 log = logging.getLogger(__name__)
 __virtualname__ = "openstack"
 
@@ -294,16 +304,14 @@ def get_dependencies():
     elif hasattr(HAS_SHADE, "__len__") and not HAS_SHADE[0]:
         log.warning(HAS_SHADE[1])
         return False
-    deps = {
-        "shade": HAS_SHADE[0],
-        "os_client_config": HAS_SHADE[0],
-    }
+    deps = {"shade": HAS_SHADE[0], "os_client_config": HAS_SHADE[0]}
     return config.check_driver_dependencies(__virtualname__, deps)
 
 
 def preferred_ip(vm_, ips):
     """
-    Return the preferred Internet protocol. Either 'ipv4' (default) or 'ipv6'.
+    Return either an 'ipv4' (default) or 'ipv6' address depending on 'protocol' option.
+    The list of 'ipv4' IPs is filtered by ignore_cidr() to remove any unreachable private addresses.
     """
     proto = config.get_cloud_config_value(
         "protocol", vm_, __opts__, default="ipv4", search_global=False
@@ -313,6 +321,9 @@ def preferred_ip(vm_, ips):
     if proto == "ipv6":
         family = socket.AF_INET6
     for ip in ips:
+        ignore_ip = ignore_cidr(vm_, ip)
+        if ignore_ip:
+            continue
         try:
             socket.inet_pton(family, ip)
             return ip
@@ -321,6 +332,25 @@ def preferred_ip(vm_, ips):
     return False
 
 
+def ignore_cidr(vm_, ip):
+    """
+    Return True if we are to ignore the specified IP.
+    """
+    from ipaddress import ip_address, ip_network
+
+    cidrs = config.get_cloud_config_value(
+        "ignore_cidr", vm_, __opts__, default=[], search_global=False
+    )
+    if cidrs and isinstance(cidrs, str):
+        cidrs = [cidrs]
+    for cidr in cidrs or []:
+        if ip_address(ip) in ip_network(cidr):
+            log.warning("IP %r found within %r; ignoring it.", ip, cidr)
+            return True
+
+    return False
+
+
 def ssh_interface(vm_):
     """
     Return the ssh_interface type to connect to. Either 'public_ips' (default)
@@ -477,7 +507,7 @@ def list_nodes_select(conn=None, call=None):
             "The list_nodes_select function must be called with -f or --function."
         )
     return __utils__["cloud.list_nodes_select"](
-        list_nodes(conn, "function"), __opts__["query.selection"], call,
+        list_nodes(conn, "function"), __opts__["query.selection"], call
     )
 
 
@@ -577,7 +607,7 @@ def list_networks(conn=None, call=None):
     """
     if call == "action":
         raise SaltCloudSystemExit(
-            "The list_networks function must be called with " "-f or --function"
+            "The list_networks function must be called with -f or --function"
         )
     if conn is None:
         conn = get_conn()
@@ -598,7 +628,7 @@ def list_subnets(conn=None, call=None, kwargs=None):
     """
     if call == "action":
         raise SaltCloudSystemExit(
-            "The list_subnets function must be called with " "-f or --function."
+            "The list_subnets function must be called with -f or --function."
         )
     if conn is None:
         conn = get_conn()
@@ -707,7 +737,7 @@ def create(vm_):
     )
     if key_filename is not None and not os.path.isfile(key_filename):
         raise SaltCloudConfigError(
-            "The defined ssh_key_file '{}' does not exist".format(key_filename)
+            f"The defined ssh_key_file '{key_filename}' does not exist"
         )
 
     vm_["key_filename"] = key_filename
@@ -810,13 +840,13 @@ def destroy(name, conn=None, call=None):
     """
     if call == "function":
         raise SaltCloudSystemExit(
-            "The destroy action must be called with -d, --destroy, " "-a or --action."
+            "The destroy action must be called with -d, --destroy, -a or --action."
         )
 
     __utils__["cloud.fire_event"](
         "event",
         "destroying instance",
-        "salt/cloud/{}/destroying".format(name),
+        f"salt/cloud/{name}/destroying",
         args={"name": name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -833,7 +863,7 @@ def destroy(name, conn=None, call=None):
         __utils__["cloud.fire_event"](
             "event",
             "destroyed instance",
-            "salt/cloud/{}/destroyed".format(name),
+            f"salt/cloud/{name}/destroyed",
             args={"name": name},
             sock_dir=__opts__["sock_dir"],
             transport=__opts__["transport"],
@@ -870,7 +900,7 @@ def call(conn=None, call=None, kwargs=None):
     """
     if call == "action":
         raise SaltCloudSystemExit(
-            "The call function must be called with " "-f or --function."
+            "The call function must be called with -f or --function."
         )
 
     if "func" not in kwargs:
