@@ -108,23 +108,23 @@ from salt.exceptions import (
     SaltCloudNotFound,
     SaltCloudSystemExit,
 )
-from salt.utils.versions import LooseVersion
+from salt.utils.versions import Version
 
 try:
     # pylint: disable=no-name-in-module
     import profitbricks
     from profitbricks.client import (
-        ProfitBricksService,
-        Server,
+        LAN,
         NIC,
-        Volume,
+        Datacenter,
         FirewallRule,
         IPBlock,
-        Datacenter,
         LoadBalancer,
-        LAN,
-        PBNotFoundError,
         PBError,
+        PBNotFoundError,
+        ProfitBricksService,
+        Server,
+        Volume,
     )
 
     # pylint: enable=no-name-in-module
@@ -174,7 +174,7 @@ def version_compatible(version):
     """
     Checks profitbricks version
     """
-    return LooseVersion(profitbricks.API_VERSION) >= LooseVersion(version)
+    return Version(profitbricks.API_VERSION) >= Version(version)
 
 
 def get_dependencies():
@@ -258,13 +258,12 @@ def list_images(call=None, kwargs=None):
     """
     if call != "function":
         raise SaltCloudSystemExit(
-            "The list_images function must be called with " "-f or --function."
+            "The list_images function must be called with -f or --function."
         )
 
     if not version_compatible("4.0"):
         raise SaltCloudNotFound(
-            "The 'image_alias' feature requires the profitbricks "
-            "SDK v4.0.0 or greater."
+            "The 'image_alias' feature requires the profitbricks SDK v4.0.0 or greater."
         )
 
     ret = {}
@@ -329,9 +328,7 @@ def get_size(vm_):
         combinations = (str(sizes[size]["id"]), str(size))
         if vm_size and str(vm_size) in combinations:
             return sizes[size]
-    raise SaltCloudNotFound(
-        "The specified size, '{}', could not be found.".format(vm_size)
-    )
+    raise SaltCloudNotFound(f"The specified size, '{vm_size}', could not be found.")
 
 
 def get_datacenter_id():
@@ -416,7 +413,7 @@ def get_datacenter(conn):
             return item
 
     raise SaltCloudNotFound(
-        "The specified datacenter '{}' could not be found.".format(datacenter_id)
+        f"The specified datacenter '{datacenter_id}' could not be found."
     )
 
 
@@ -489,9 +486,7 @@ def get_image(vm_):
         if vm_image and vm_image in (images[key]["id"], images[key]["name"]):
             return images[key]
 
-    raise SaltCloudNotFound(
-        "The specified image, '{}', could not be found.".format(vm_image)
-    )
+    raise SaltCloudNotFound(f"The specified image, '{vm_image}', could not be found.")
 
 
 def list_datacenters(conn=None, call=None):
@@ -506,7 +501,7 @@ def list_datacenters(conn=None, call=None):
     """
     if call != "function":
         raise SaltCloudSystemExit(
-            "The list_datacenters function must be called with " "-f or --function."
+            "The list_datacenters function must be called with -f or --function."
         )
 
     datacenters = []
@@ -540,7 +535,7 @@ def list_nodes(conn=None, call=None):
     try:
         nodes = conn.list_servers(datacenter_id=datacenter_id)
     except PBNotFoundError:
-        log.error("Failed to get nodes list " "from datacenter: %s", datacenter_id)
+        log.error("Failed to get nodes list from datacenter: %s", datacenter_id)
         raise
 
     for item in nodes["items"]:
@@ -558,7 +553,7 @@ def list_nodes_full(conn=None, call=None):
     """
     if call == "action":
         raise SaltCloudSystemExit(
-            "The list_nodes_full function must be called with -f or " "--function."
+            "The list_nodes_full function must be called with -f or --function."
         )
 
     if not conn:
@@ -599,7 +594,7 @@ def reserve_ipblock(call=None, kwargs=None):
     """
     if call == "action":
         raise SaltCloudSystemExit(
-            "The reserve_ipblock function must be called with -f or " "--function."
+            "The reserve_ipblock function must be called with -f or --function."
         )
 
     conn = get_conn()
@@ -726,7 +721,7 @@ def get_public_keys(vm_):
         key_filename = os.path.expanduser(key_filename)
         if not os.path.isfile(key_filename):
             raise SaltCloudConfigError(
-                "The defined ssh_public_key '{}' does not exist".format(key_filename)
+                f"The defined ssh_public_key '{key_filename}' does not exist"
             )
         ssh_keys = []
         with salt.utils.files.fopen(key_filename) as rfh:
@@ -747,7 +742,7 @@ def get_key_filename(vm_):
         key_filename = os.path.expanduser(key_filename)
         if not os.path.isfile(key_filename):
             raise SaltCloudConfigError(
-                "The defined ssh_private_key '{}' does not exist".format(key_filename)
+                f"The defined ssh_private_key '{key_filename}' does not exist"
             )
 
         return key_filename
@@ -936,13 +931,13 @@ def destroy(name, call=None):
     """
     if call == "function":
         raise SaltCloudSystemExit(
-            "The destroy action must be called with -d, --destroy, " "-a or --action."
+            "The destroy action must be called with -d, --destroy, -a or --action."
         )
 
     __utils__["cloud.fire_event"](
         "event",
         "destroying instance",
-        "salt/cloud/{}/destroying".format(name),
+        f"salt/cloud/{name}/destroying",
         args={"name": name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -973,7 +968,7 @@ def destroy(name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "destroyed instance",
-        "salt/cloud/{}/destroyed".format(name),
+        f"salt/cloud/{name}/destroyed",
         args={"name": name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -1143,9 +1138,7 @@ def _get_data_volumes(vm_):
         # Verify the required 'disk_size' property is present in the cloud
         # profile config
         if "disk_size" not in volumes[key].keys():
-            raise SaltCloudConfigError(
-                "The volume '{}' is missing 'disk_size'".format(key)
-            )
+            raise SaltCloudConfigError(f"The volume '{key}' is missing 'disk_size'")
         # Use 'HDD' if no 'disk_type' property is present in cloud profile
         if "disk_type" not in volumes[key].keys():
             volumes[key]["disk_type"] = "HDD"
@@ -1188,7 +1181,7 @@ def _get_firewall_rules(firewall_rules):
         # profile config
         if "protocol" not in firewall_rules[key].keys():
             raise SaltCloudConfigError(
-                "The firewall rule '{}' is missing 'protocol'".format(key)
+                f"The firewall rule '{key}' is missing 'protocol'"
             )
         ret.append(
             FirewallRule(
