@@ -108,7 +108,7 @@ def _compute_signature(parameters, access_key_secret, method, path):
     """
     parameters["signature_method"] = "HmacSHA256"
 
-    string_to_sign = "{}\n{}\n".format(method.upper(), path)
+    string_to_sign = f"{method.upper()}\n{path}\n"
 
     keys = sorted(parameters.keys())
     pairs = []
@@ -166,9 +166,9 @@ def query(params=None):
                         for sk, sv in value[i - 1].items():
                             if isinstance(sv, dict) or isinstance(sv, list):
                                 sv = salt.utils.json.dumps(sv, separators=(",", ":"))
-                            real_parameters["{}.{}.{}".format(key, i, sk)] = sv
+                            real_parameters[f"{key}.{i}.{sk}"] = sv
                     else:
-                        real_parameters["{}.{}".format(key, i)] = value[i - 1]
+                        real_parameters[f"{key}.{i}"] = value[i - 1]
             else:
                 real_parameters[key] = value
 
@@ -179,7 +179,7 @@ def query(params=None):
     # print('parameters:')
     # pprint.pprint(real_parameters)
 
-    request = requests.get(path, params=real_parameters, verify=verify_ssl)
+    request = requests.get(path, params=real_parameters, verify=verify_ssl, timeout=120)
 
     # print('url:')
     # print(request.url)
@@ -252,7 +252,7 @@ def _get_location(vm_=None):
         return vm_location
 
     raise SaltCloudNotFound(
-        "The specified location, '{}', could not be found.".format(vm_location)
+        f"The specified location, '{vm_location}', could not be found."
     )
 
 
@@ -320,9 +320,7 @@ def _get_image(vm_):
     if vm_image in images:
         return vm_image
 
-    raise SaltCloudNotFound(
-        "The specified image, '{}', could not be found.".format(vm_image)
-    )
+    raise SaltCloudNotFound(f"The specified image, '{vm_image}', could not be found.")
 
 
 def show_image(kwargs, call=None):
@@ -339,7 +337,7 @@ def show_image(kwargs, call=None):
     """
     if call != "function":
         raise SaltCloudSystemExit(
-            "The show_images function must be called with " "-f or --function"
+            "The show_images function must be called with -f or --function"
         )
 
     if not isinstance(kwargs, dict):
@@ -439,12 +437,10 @@ def _get_size(vm_):
     if not vm_size:
         raise SaltCloudNotFound("No size specified for this instance.")
 
-    if vm_size in sizes.keys():
+    if vm_size in sizes:
         return vm_size
 
-    raise SaltCloudNotFound(
-        "The specified size, '{}', could not be found.".format(vm_size)
-    )
+    raise SaltCloudNotFound(f"The specified size, '{vm_size}', could not be found.")
 
 
 def _show_normalized_node(full_node):
@@ -596,7 +592,9 @@ def list_nodes_select(call=None):
         salt-cloud -S my-qingcloud
     """
     return salt.utils.cloud.list_nodes_select(
-        list_nodes_full("function"), __opts__["query.selection"], call,
+        list_nodes_full("function"),
+        __opts__["query.selection"],
+        call,
     )
 
 
@@ -624,7 +622,7 @@ def show_instance(instance_id, call=None, kwargs=None):
 
     if items["total_count"] == 0:
         raise SaltCloudNotFound(
-            "The specified instance, '{}', could not be found.".format(instance_id)
+            f"The specified instance, '{instance_id}', could not be found."
         )
 
     full_node = items["instance_set"][0]
@@ -867,7 +865,7 @@ def destroy(instance_id, call=None):
     """
     if call == "function":
         raise SaltCloudSystemExit(
-            "The destroy action must be called with -d, --destroy, " "-a or --action."
+            "The destroy action must be called with -d, --destroy, -a or --action."
         )
 
     instance_data = show_instance(instance_id, call="action")
@@ -876,7 +874,7 @@ def destroy(instance_id, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "destroying instance",
-        "salt/cloud/{}/destroying".format(name),
+        f"salt/cloud/{name}/destroying",
         args={"name": name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -892,7 +890,7 @@ def destroy(instance_id, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "destroyed instance",
-        "salt/cloud/{}/destroyed".format(name),
+        f"salt/cloud/{name}/destroyed",
         args={"name": name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
