@@ -198,8 +198,8 @@ def __virtual__():
     if not HAS_NAPALM_LOGS or not zmq:
         return (
             False,
-            "napalm_syslog could not be loaded. \
-            Please install napalm-logs library amd ZeroMQ.",
+            "napalm_syslog could not be loaded. Please install "
+            "napalm-logs library and ZeroMQ.",
         )
     return True
 
@@ -209,7 +209,7 @@ def _zmq(address, port, **kwargs):
     socket = context.socket(zmq.SUB)
     if salt.utils.network.is_ipv6(address):
         socket.ipv6 = True
-    socket.connect("tcp://{addr}:{port}".format(addr=address, port=port))
+    socket.connect(f"tcp://{address}:{port}")
     socket.setsockopt(zmq.SUBSCRIBE, b"")
     return socket.recv
 
