@@ -2,7 +2,6 @@
 File server pluggable modules and generic backend functions
 """
 
-
 import errno
 import fnmatch
 import logging
@@ -12,12 +11,10 @@ import time
 from collections.abc import Sequence
 
 import salt.loader
-import salt.utils.data
 import salt.utils.files
 import salt.utils.path
 import salt.utils.url
 import salt.utils.versions
-from salt.ext import six
 from salt.utils.args import get_function_argspec as _argspec
 from salt.utils.decorators import ensure_unicode_args
 
@@ -105,7 +102,6 @@ def check_file_list_cache(opts, form, list_cache, w_lock):
     """
     refresh_cache = False
     save_cache = True
-    serial = salt.payload.Serial(opts)
     wait_lock(w_lock, list_cache, 5 * 60)
     if not os.path.isfile(list_cache) and _lock_cache(w_lock):
         refresh_cache = True
@@ -150,11 +146,7 @@ def check_file_list_cache(opts, form, list_cache, w_lock):
                             opts.get("fileserver_list_cache_time", 20),
                             list_cache,
                         )
-                        return (
-                            salt.utils.data.decode(serial.load(fp_).get(form, [])),
-                            False,
-                            False,
-                        )
+                        return salt.payload.load(fp_).get(form, []), False, False
                 elif _lock_cache(w_lock):
                     # Set the w_lock and go
                     refresh_cache = True
@@ -175,9 +167,8 @@ def write_file_list_cache(opts, data, list_cache, w_lock):
     returns the match (if found, along with booleans used by the fileserver
     backend to determine if the cache needs to be refreshed/written).
     """
-    serial = salt.payload.Serial(opts)
     with salt.utils.files.fopen(list_cache, "w+b") as fp_:
-        fp_.write(serial.dumps(data))
+        fp_.write(salt.payload.dumps(data))
         _unlock_cache(w_lock)
         log.trace("Lockfile %s removed", w_lock)
 
@@ -191,8 +182,7 @@ def check_env_cache(opts, env_cache):
     try:
         with salt.utils.files.fopen(env_cache, "rb") as fp_:
             log.trace("Returning env cache data from %s", env_cache)
-            serial = salt.payload.Serial(opts)
-            return salt.utils.data.decode(serial.load(fp_))
+            return salt.payload.load(fp_)
     except OSError:
         pass
     return None
@@ -323,9 +313,9 @@ def clear_lock(clear_func, role, remote=None, lock_type="update"):
 
     Returns the return data from ``clear_func``.
     """
-    msg = "Clearing {} lock for {} remotes".format(lock_type, role)
+    msg = f"Clearing {lock_type} lock for {role} remotes"
     if remote:
-        msg += " matching {}".format(remote)
+        msg += f" matching {remote}"
     log.debug(msg)
     return clear_func(remote=remote, lock_type=lock_type)
 
@@ -378,12 +368,12 @@ class Fileserver:
                 # Only subtracting backends from enabled ones
                 ret = self.opts["fileserver_backend"]
                 for sub in back:
-                    if "{}.envs".format(sub[1:]) in server_funcs:
+                    if f"{sub[1:]}.envs" in server_funcs:
                         ret.remove(sub[1:])
                 return ret
 
         for sub in back:
-            if "{}.envs".format(sub) in server_funcs:
+            if f"{sub}.envs" in server_funcs:
                 ret.append(sub)
         return ret
 
@@ -411,7 +401,7 @@ class Fileserver:
         cleared = []
         errors = []
         for fsb in back:
-            fstr = "{}.clear_cache".format(fsb)
+            fstr = f"{fsb}.clear_cache"
             if fstr in self.servers:
                 log.debug("Clearing %s fileserver cache", fsb)
                 failed = self.servers[fstr]()
@@ -419,7 +409,7 @@ class Fileserver:
                     errors.extend(failed)
                 else:
                     cleared.append(
-                        "The {} fileserver cache was successfully cleared".format(fsb)
+                        f"The {fsb} fileserver cache was successfully cleared"
                     )
         return cleared, errors
 
@@ -433,17 +423,15 @@ class Fileserver:
         locked = []
         errors = []
         for fsb in back:
-            fstr = "{}.lock".format(fsb)
+            fstr = f"{fsb}.lock"
             if fstr in self.servers:
-                msg = "Setting update lock for {} remotes".format(fsb)
+                msg = f"Setting update lock for {fsb} remotes"
                 if remote:
                     if not isinstance(remote, str):
-                        errors.append(
-                            "Badly formatted remote pattern '{}'".format(remote)
-                        )
+                        errors.append(f"Badly formatted remote pattern '{remote}'")
                         continue
                     else:
-                        msg += " matching {}".format(remote)
+                        msg += f" matching {remote}"
                 log.debug(msg)
                 good, bad = self.servers[fstr](remote=remote)
                 locked.extend(good)
@@ -466,7 +454,7 @@ class Fileserver:
         cleared = []
         errors = []
         for fsb in back:
-            fstr = "{}.clear_lock".format(fsb)
+            fstr = f"{fsb}.clear_lock"
             if fstr in self.servers:
                 good, bad = clear_lock(self.servers[fstr], fsb, remote=remote)
                 cleared.extend(good)
@@ -480,7 +468,7 @@ class Fileserver:
         """
         back = self.backends(back)
         for fsb in back:
-            fstr = "{}.update".format(fsb)
+            fstr = f"{fsb}.update"
             if fstr in self.servers:
                 log.debug("Updating %s fileserver cache", fsb)
                 self.servers[fstr](**kwargs)
@@ -493,7 +481,7 @@ class Fileserver:
         back = self.backends(back)
         ret = {}
         for fsb in back:
-            fstr = "{}.update_intervals".format(fsb)
+            fstr = f"{fsb}.update_intervals"
             if fstr in self.servers:
                 ret[fsb] = self.servers[fstr]()
         return ret
@@ -507,7 +495,7 @@ class Fileserver:
         if sources:
             ret = {}
         for fsb in back:
-            fstr = "{}.envs".format(fsb)
+            fstr = f"{fsb}.envs"
             kwargs = (
                 {"ignore_cache": True}
                 if "ignore_cache" in _argspec(self.servers[fstr]).args
@@ -529,7 +517,7 @@ class Fileserver:
         if load is None:
             load = {}
         load.pop("cmd", None)
-        return self.envs(**load)
+        return self.envs(back=load.get("back", None), sources=load.get("sources", None))
 
     def init(self, back=None):
         """
@@ -537,7 +525,7 @@ class Fileserver:
         """
         back = self.backends(back)
         for fsb in back:
-            fstr = "{}.init".format(fsb)
+            fstr = f"{fsb}.init"
             if fstr in self.servers:
                 self.servers[fstr]()
 
@@ -570,11 +558,6 @@ class Fileserver:
         saltenv = salt.utils.stringutils.to_unicode(saltenv)
         back = self.backends(back)
         kwargs = {}
-        fnd = {"path": "", "rel": ""}
-        if os.path.isabs(path):
-            return fnd
-        if "../" in path:
-            return fnd
         if salt.utils.url.is_escaped(path):
             # don't attempt to find URL query arguments in the path
             path = salt.utils.url.unescape(path)
@@ -590,6 +573,10 @@ class Fileserver:
                     args = comp.split("=", 1)
                     kwargs[args[0]] = args[1]
 
+        fnd = {"path": "", "rel": ""}
+        if os.path.isabs(path) or "../" in path:
+            return fnd
+
         if "env" in kwargs:
             # "env" is not supported; Use "saltenv".
             kwargs.pop("env")
@@ -600,7 +587,7 @@ class Fileserver:
             saltenv = str(saltenv)
 
         for fsb in back:
-            fstr = "{}.find_file".format(fsb)
+            fstr = f"{fsb}.find_file"
             if fstr in self.servers:
                 fnd = self.servers[fstr](path, saltenv, **kwargs)
                 if fnd.get("path"):
@@ -770,7 +757,7 @@ class Fileserver:
             load["saltenv"] = str(load["saltenv"])
 
         for fsb in self.backends(load.pop("fsbackend", None)):
-            fstr = "{}.file_list".format(fsb)
+            fstr = f"{fsb}.file_list"
             if fstr in self.servers:
                 ret.update(self.servers[fstr](load))
         # some *fs do not handle prefix. Ensure it is filtered
@@ -795,7 +782,7 @@ class Fileserver:
             load["saltenv"] = str(load["saltenv"])
 
         for fsb in self.backends(None):
-            fstr = "{}.file_list_emptydirs".format(fsb)
+            fstr = f"{fsb}.file_list_emptydirs"
             if fstr in self.servers:
                 ret.update(self.servers[fstr](load))
         # some *fs do not handle prefix. Ensure it is filtered
@@ -820,7 +807,7 @@ class Fileserver:
             load["saltenv"] = str(load["saltenv"])
 
         for fsb in self.backends(load.pop("fsbackend", None)):
-            fstr = "{}.dir_list".format(fsb)
+            fstr = f"{fsb}.dir_list"
             if fstr in self.servers:
                 ret.update(self.servers[fstr](load))
         # some *fs do not handle prefix. Ensure it is filtered
@@ -845,7 +832,7 @@ class Fileserver:
             load["saltenv"] = str(load["saltenv"])
 
         for fsb in self.backends(load.pop("fsbackend", None)):
-            symlstr = "{}.symlink_list".format(fsb)
+            symlstr = f"{fsb}.symlink_list"
             if symlstr in self.servers:
                 ret = self.servers[symlstr](load)
         # some *fs do not handle prefix. Ensure it is filtered
