@@ -1,13 +1,9 @@
-# -*- coding: utf-8 -*-
 """
 Detect MDADM RAIDs
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import python libs
 import logging
 
-# Import salt libs
 import salt.utils.files
 
 log = logging.getLogger(__name__)
@@ -28,7 +24,7 @@ def mdadm():
                     continue
                 if " : " in line:
                     devices.add(line.split(" : ")[0])
-    except IOError:
+    except OSError:
         return {}
 
     devices = sorted(devices)
