@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 ZFS grain provider
 
@@ -10,16 +9,12 @@ ZFS grain provider
 .. versionadded:: 2018.3.0
 
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import python libs
 import logging
 
 # Solve the Chicken and egg problem where grains need to run before any
 # of the modules are loaded and are generally available for any usage.
 import salt.modules.cmdmod
-
-# Import salt libs
 import salt.utils.dictupdate
 import salt.utils.path
 import salt.utils.platform
@@ -59,7 +54,9 @@ def _zfs_pool_data():
 
     # collect zpool data
     zpool_list_cmd = __utils__["zfs.zpool_command"](
-        "list", flags=["-H"], opts={"-o": "name,size"},
+        "list",
+        flags=["-H"],
+        opts={"-o": "name,size"},
     )
     for zpool in __salt__["cmd.run"](zpool_list_cmd, ignore_retcode=True).splitlines():
         if "zpool" not in grains:
@@ -84,6 +81,3 @@ def zfs():
         )
 
     return grains
-
-
-# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
