@@ -280,6 +280,12 @@ def install(name=None, refresh=False, pkgs=None, version=None, test=False, **kwa
         Install a specific version of a fileset/rpm package.
         (Unused at present).
 
+        .. note::
+            Remember that versions that contain a single `.` will be interpreted
+            as numbers and must be double-quoted. For example, version
+            ``3006.10`` will be rendered as ``3006.1``. To pass ``3006.10``
+            you'll need to use double-quotes. ``version="'3006.10'"``
+
     test
         Verify that command functions correctly.
 
