@@ -107,7 +107,7 @@ def _describe_resource(
     key=None,
     keyid=None,
     profile=None,
-    **args
+    **args,
 ):
     if conn is None:
         conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
@@ -115,9 +115,7 @@ def _describe_resource(
         func = "describe_" + res_type + "s"
         f = getattr(conn, func)
     except (AttributeError, KeyError) as e:
-        raise SaltInvocationError(
-            "No function '{}()' found: {}".format(func, e.message)
-        )
+        raise SaltInvocationError(f"No function '{func}()' found: {e.message}")
     # Undocumented, but you can't pass 'Marker' if searching for a specific resource...
     args.update({name_param: name} if name else {"Marker": ""})
     args = {k: v for k, v in args.items() if not k.startswith("_")}
@@ -140,7 +138,7 @@ def _delete_resource(
     key=None,
     keyid=None,
     profile=None,
-    **args
+    **args,
 ):
     """
     Delete a generic Elasticache resource.
@@ -171,9 +169,7 @@ def _delete_resource(
             func = "describe_" + res_type + "s"
             s = globals()[func]
     except (AttributeError, KeyError) as e:
-        raise SaltInvocationError(
-            "No function '{}()' found: {}".format(func, e.message)
-        )
+        raise SaltInvocationError(f"No function '{func}()' found: {e.message}")
     try:
 
         f(**args)
@@ -211,7 +207,7 @@ def _create_resource(
     key=None,
     keyid=None,
     profile=None,
-    **args
+    **args,
 ):
     try:
         wait = int(wait)
@@ -239,9 +235,7 @@ def _create_resource(
             func = "describe_" + res_type + "s"
             s = globals()[func]
     except (AttributeError, KeyError) as e:
-        raise SaltInvocationError(
-            "No function '{}()' found: {}".format(func, e.message)
-        )
+        raise SaltInvocationError(f"No function '{func}()' found: {e.message}")
     try:
         f(**args)
         if not wait:
@@ -270,7 +264,7 @@ def _create_resource(
         )
         return False
     except botocore.exceptions.ClientError as e:
-        msg = "Failed to create {} {}: {}".format(desc, name, e)
+        msg = f"Failed to create {desc} {name}: {e}"
         log.error(msg)
         return False
 
@@ -287,7 +281,7 @@ def _modify_resource(
     key=None,
     keyid=None,
     profile=None,
-    **args
+    **args,
 ):
     try:
         wait = int(wait)
@@ -315,9 +309,7 @@ def _modify_resource(
             func = "describe_" + res_type + "s"
             s = globals()[func]
     except (AttributeError, KeyError) as e:
-        raise SaltInvocationError(
-            "No function '{}()' found: {}".format(func, e.message)
-        )
+        raise SaltInvocationError(f"No function '{func}()' found: {e.message}")
     try:
         f(**args)
         if not wait:
@@ -346,7 +338,7 @@ def _modify_resource(
         )
         return False
     except botocore.exceptions.ClientError as e:
-        msg = "Failed to modify {} {}: {}".format(desc, name, e)
+        msg = f"Failed to modify {desc} {name}: {e}"
         log.error(msg)
         return False
 
@@ -374,7 +366,7 @@ def describe_cache_clusters(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -405,7 +397,7 @@ def create_cache_cluster(
     key=None,
     keyid=None,
     profile=None,
-    **args
+    **args,
 ):
     """
     Create a cache cluster.
@@ -442,7 +434,7 @@ def create_cache_cluster(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -454,7 +446,7 @@ def modify_cache_cluster(
     key=None,
     keyid=None,
     profile=None,
-    **args
+    **args,
 ):
     """
     Update a cache cluster in place.
@@ -496,7 +488,7 @@ def modify_cache_cluster(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -523,7 +515,7 @@ def delete_cache_cluster(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -578,7 +570,7 @@ def create_replication_group(
     key=None,
     keyid=None,
     profile=None,
-    **args
+    **args,
 ):
     """
     Create a replication group.
@@ -615,7 +607,7 @@ def create_replication_group(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -627,7 +619,7 @@ def modify_replication_group(
     key=None,
     keyid=None,
     profile=None,
-    **args
+    **args,
 ):
     """
     Modify a replication group.
@@ -661,7 +653,7 @@ def modify_replication_group(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -688,7 +680,7 @@ def delete_replication_group(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -783,13 +775,13 @@ def create_cache_subnet_group(
             ).get("subnets")
             if not sn:
                 raise SaltInvocationError(
-                    "Could not resolve Subnet Name {} to an ID.".format(subnet)
+                    f"Could not resolve Subnet Name {subnet} to an ID."
                 )
             if len(sn) == 1:
                 args["SubnetIds"] += [sn[0]["id"]]
             elif len(sn) > 1:
                 raise CommandExecutionError(
-                    "Subnet Name {} returned more than one ID.".format(subnet)
+                    f"Subnet Name {subnet} returned more than one ID."
                 )
     args = {k: v for k, v in args.items() if not k.startswith("_")}
     return _create_resource(
@@ -801,7 +793,7 @@ def create_cache_subnet_group(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -836,14 +828,14 @@ def modify_cache_subnet_group(
                 args["SubnetIds"] += [sn[0]["id"]]
             elif len(sn) > 1:
                 raise CommandExecutionError(
-                    "Subnet Name {} returned more than one ID.".format(subnet)
+                    f"Subnet Name {subnet} returned more than one ID."
                 )
             elif subnet.startswith("subnet-"):
                 # Moderately safe assumption... :)  Will be caught later if incorrect.
                 args["SubnetIds"] += [subnet]
             else:
                 raise SaltInvocationError(
-                    "Could not resolve Subnet Name {} to an ID.".format(subnet)
+                    f"Could not resolve Subnet Name {subnet} to an ID."
                 )
     args = {k: v for k, v in args.items() if not k.startswith("_")}
     return _modify_resource(
@@ -855,7 +847,7 @@ def modify_cache_subnet_group(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -880,7 +872,7 @@ def delete_cache_subnet_group(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -948,7 +940,7 @@ def create_cache_security_group(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -973,7 +965,7 @@ def delete_cache_security_group(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -1264,7 +1256,7 @@ def create_cache_parameter_group(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
 
 
@@ -1289,5 +1281,5 @@ def delete_cache_parameter_group(
         key=key,
         keyid=keyid,
         profile=profile,
-        **args
+        **args,
     )
