@@ -40,6 +40,7 @@ Connection module for Amazon Elasticache
 
 :depends: boto
 """
+
 # keep lint from choking on _get_conn and _cache_id
 # pylint: disable=E0602
 
@@ -156,7 +157,7 @@ def create_replication_group(
             if config["status"] == "available":
                 return True
     except boto.exception.BotoServerError as e:
-        msg = "Failed to create replication group {}.".format(name)
+        msg = f"Failed to create replication group {name}."
         log.error(msg)
         log.debug(e)
         return {}
@@ -178,12 +179,12 @@ def delete_replication_group(name, region=None, key=None, keyid=None, profile=No
         return False
     try:
         conn.delete_replication_group(name)
-        msg = "Deleted ElastiCache replication group {}.".format(name)
+        msg = f"Deleted ElastiCache replication group {name}."
         log.info(msg)
         return True
     except boto.exception.BotoServerError as e:
         log.debug(e)
-        msg = "Failed to delete ElastiCache replication group {}".format(name)
+        msg = f"Failed to delete ElastiCache replication group {name}"
         log.error(msg)
         return False
 
@@ -207,7 +208,7 @@ def describe_replication_group(
     try:
         cc = conn.describe_replication_groups(name)
     except boto.exception.BotoServerError as e:
-        msg = "Failed to get config for cache cluster {}.".format(name)
+        msg = f"Failed to get config for cache cluster {name}."
         log.error(msg)
         log.debug(e)
         return {}
@@ -277,7 +278,7 @@ def get_config(name, region=None, key=None, keyid=None, profile=None):
     try:
         cc = conn.describe_cache_clusters(name, show_cache_node_info=True)
     except boto.exception.BotoServerError as e:
-        msg = "Failed to get config for cache cluster {}.".format(name)
+        msg = f"Failed to get config for cache cluster {name}."
         log.error(msg)
         log.debug(e)
         return {}
@@ -356,7 +357,7 @@ def get_node_host(name, region=None, key=None, keyid=None, profile=None):
     try:
         cc = conn.describe_cache_clusters(name, show_cache_node_info=True)
     except boto.exception.BotoServerError as e:
-        msg = "Failed to get config for cache cluster {}.".format(name)
+        msg = f"Failed to get config for cache cluster {name}."
         log.error(msg)
         log.debug(e)
         return {}
@@ -383,7 +384,7 @@ def get_group_host(name, region=None, key=None, keyid=None, profile=None):
     try:
         cc = conn.describe_replication_groups(name)
     except boto.exception.BotoServerError as e:
-        msg = "Failed to get config for cache cluster {}.".format(name)
+        msg = f"Failed to get config for cache cluster {name}."
         log.error(msg)
         log.debug(e)
         return {}
@@ -464,7 +465,7 @@ def subnet_group_exists(
     try:
         ec = conn.describe_cache_subnet_groups(cache_subnet_group_name=name)
         if not ec:
-            msg = "ElastiCache subnet group does not exist in region {}".format(region)
+            msg = f"ElastiCache subnet group does not exist in region {region}"
             log.debug(msg)
             return False
         return True
@@ -495,7 +496,7 @@ def create_subnet_group(
     """
     if not _exactly_one((subnet_ids, subnet_names)):
         raise SaltInvocationError(
-            "Exactly one of either 'subnet_ids' or " "'subnet_names' must be provided."
+            "Exactly one of either 'subnet_ids' or 'subnet_names' must be provided."
         )
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
     if not conn:
@@ -515,14 +516,14 @@ def create_subnet_group(
     try:
         ec = conn.create_cache_subnet_group(name, description, subnet_ids)
         if not ec:
-            msg = "Failed to create ElastiCache subnet group {}".format(name)
+            msg = f"Failed to create ElastiCache subnet group {name}"
             log.error(msg)
             return False
         log.info("Created ElastiCache subnet group %s", name)
         return True
     except boto.exception.BotoServerError as e:
         log.debug(e)
-        msg = "Failed to create ElastiCache subnet group {}".format(name)
+        msg = f"Failed to create ElastiCache subnet group {name}"
         log.error(msg)
         return False
 
@@ -544,12 +545,12 @@ def get_cache_subnet_group(name, region=None, key=None, keyid=None, profile=None
         csg = csg["DescribeCacheSubnetGroupsResponse"]
         csg = csg["DescribeCacheSubnetGroupsResult"]["CacheSubnetGroups"][0]
     except boto.exception.BotoServerError as e:
-        msg = "Failed to get cache subnet group {}.".format(name)
+        msg = f"Failed to get cache subnet group {name}."
         log.error(msg)
         log.debug(e)
         return False
     except (IndexError, TypeError, KeyError):
-        msg = "Failed to get cache subnet group {} (2).".format(name)
+        msg = f"Failed to get cache subnet group {name} (2)."
         log.error(msg)
         return False
     ret = {}
@@ -589,12 +590,12 @@ def delete_subnet_group(name, region=None, key=None, keyid=None, profile=None):
         return False
     try:
         conn.delete_cache_subnet_group(name)
-        msg = "Deleted ElastiCache subnet group {}.".format(name)
+        msg = f"Deleted ElastiCache subnet group {name}."
         log.info(msg)
         return True
     except boto.exception.BotoServerError as e:
         log.debug(e)
-        msg = "Failed to delete ElastiCache subnet group {}".format(name)
+        msg = f"Failed to delete ElastiCache subnet group {name}"
         log.error(msg)
         return False
 
@@ -665,7 +666,7 @@ def create(
                 return True
         log.info("Created cache cluster %s.", name)
     except boto.exception.BotoServerError as e:
-        msg = "Failed to create cache cluster {}.".format(name)
+        msg = f"Failed to create cache cluster {name}."
         log.error(msg)
         log.debug(e)
         return False
@@ -698,7 +699,7 @@ def delete(name, wait=False, region=None, key=None, keyid=None, profile=None):
         log.info("Deleted cache cluster %s.", name)
         return True
     except boto.exception.BotoServerError as e:
-        msg = "Failed to delete cache cluster {}.".format(name)
+        msg = f"Failed to delete cache cluster {name}."
         log.error(msg)
         log.debug(e)
         return False
@@ -723,7 +724,7 @@ def create_cache_security_group(
         log.info("Created cache security group %s.", name)
         return True
     else:
-        msg = "Failed to create cache security group {}.".format(name)
+        msg = f"Failed to create cache security group {name}."
         log.error(msg)
         return False
 
@@ -745,7 +746,7 @@ def delete_cache_security_group(name, region=None, key=None, keyid=None, profile
         log.info("Deleted cache security group %s.", name)
         return True
     else:
-        msg = "Failed to delete cache security group {}.".format(name)
+        msg = f"Failed to delete cache security group {name}."
         log.error(msg)
         return False
 
