@@ -41,6 +41,7 @@ Connection module for Amazon Kinesis
 :depends: boto3
 
 """
+
 # keep lint from choking on _get_conn
 # pylint: disable=E0602
 
@@ -475,7 +476,7 @@ def reshard(
                     StreamName=stream_name,
                     ShardToSplit=shard_id,
                     NewStartingHashKey=str(expected_ending_hash_key + 1),
-                )  # future lint: disable=blacklisted-function
+                )
             else:
                 log.debug(
                     "%s should end at %s, actual %s would split",
@@ -491,7 +492,7 @@ def reshard(
             # merge
             next_shard_id = _get_next_open_shard(stream_details, shard_id)
             if not next_shard_id:
-                r["error"] = "failed to find next shard after {}".format(shard_id)
+                r["error"] = f"failed to find next shard after {shard_id}"
                 return r
             if force:
                 log.debug(
@@ -643,4 +644,4 @@ def _jittered_backoff(attempt, max_retry_delay):
 
         salt myminion boto_kinesis._jittered_backoff current_attempt_number max_delay_in_seconds
     """
-    return min(random.random() * (2 ** attempt), max_retry_delay)
+    return min(random.random() * (2**attempt), max_retry_delay)
