@@ -45,6 +45,7 @@ The dependencies listed above can be installed via package or pip.
             region: us-east-1
 
 """
+
 # keep lint from choking on _get_conn and _cache_id
 # pylint: disable=E0602
 #  disable complaints about perfectly valid non-assignment code
@@ -57,7 +58,6 @@ import salt.utils.compat
 import salt.utils.json
 import salt.utils.versions
 from salt.exceptions import SaltInvocationError
-from salt.ext.six.moves import range  # pylint: disable=import-error
 
 log = logging.getLogger(__name__)
 
@@ -164,9 +164,7 @@ def create(
             "GrantWriteACP",
         ):
             if locals()[arg] is not None:
-                kwargs[arg] = str(
-                    locals()[arg]
-                )  # future lint: disable=blacklisted-function
+                kwargs[arg] = str(locals()[arg])
         if LocationConstraint:
             kwargs["CreateBucketConfiguration"] = {
                 "LocationConstraint": LocationConstraint
@@ -559,9 +557,7 @@ def put_acl(
             "GrantWriteACP",
         ):
             if locals()[arg] is not None:
-                kwargs[arg] = str(
-                    locals()[arg]
-                )  # future lint: disable=blacklisted-function
+                kwargs[arg] = str(locals()[arg])
         conn.put_bucket_acl(Bucket=Bucket, **kwargs)
         return {"updated": True, "name": Bucket}
     except ClientError as e:
@@ -778,7 +774,7 @@ def _get_role_arn(name, region=None, key=None, keyid=None, profile=None):
         region = profile["region"]
     if region is None:
         region = "us-east-1"
-    return "arn:aws:iam::{}:role/{}".format(account_id, name)
+    return f"arn:aws:iam::{account_id}:role/{name}"
 
 
 def put_replication(
