@@ -40,6 +40,7 @@ Connection module for Amazon Security Groups
 
 :depends: boto
 """
+
 # keep lint from choking on _get_conn and _cache_id
 # pylint: disable=E0602
 
@@ -175,7 +176,7 @@ def _get_group(
     """
     if vpc_name and vpc_id:
         raise SaltInvocationError(
-            "The params 'vpc_id' and 'vpc_name' " "are mutually exclusive."
+            "The params 'vpc_id' and 'vpc_name' are mutually exclusive."
         )
     if vpc_name:
         try:
@@ -401,7 +402,7 @@ def convert_to_group_ids(
             # But... if we're running in test mode, it may just be that the SG is scheduled
             # to be created, and thus WOULD have been there if running "for real"...
             if __opts__["test"]:
-                log.warn(
+                log.warning(
                     "Security Group `%s` could not be resolved to an ID.  This may "
                     "cause a failure when not running in test mode.",
                     group,
@@ -409,8 +410,9 @@ def convert_to_group_ids(
                 return []
             else:
                 raise CommandExecutionError(
-                    "Could not resolve Security Group name "
-                    "{} to a Group ID".format(group)
+                    "Could not resolve Security Group name {} to a Group ID".format(
+                        group
+                    )
                 )
         else:
             group_ids.append(str(group_id))
@@ -508,7 +510,7 @@ def create(
         log.info("Created security group %s.", name)
         return True
     else:
-        msg = "Failed to create security group {}.".format(name)
+        msg = f"Failed to create security group {name}."
         log.error(msg)
         return False
 
@@ -551,7 +553,7 @@ def delete(
             log.info("Deleted security group %s with id %s.", group.name, group.id)
             return True
         else:
-            msg = "Failed to delete security group {}.".format(name)
+            msg = f"Failed to delete security group {name}."
             log.error(msg)
             return False
     else:
@@ -752,7 +754,7 @@ def _find_vpcs(
     Borrowed from boto_vpc; these could be refactored into a common library
     """
     if all((vpc_id, vpc_name)):
-        raise SaltInvocationError("Only one of vpc_name or vpc_id may be " "provided.")
+        raise SaltInvocationError("Only one of vpc_name or vpc_id may be provided.")
 
     if not any((vpc_id, vpc_name, tags, cidr)):
         raise SaltInvocationError(
@@ -775,7 +777,7 @@ def _find_vpcs(
 
     if tags:
         for tag_name, tag_value in tags.items():
-            filter_parameters["filters"]["tag:{}".format(tag_name)] = tag_value
+            filter_parameters["filters"][f"tag:{tag_name}"] = tag_value
 
     vpcs = conn.get_all_vpcs(**filter_parameters)
     log.debug(
