@@ -1,24 +1,25 @@
-# -*- coding: utf-8 -*-
 """
 An execution module that interacts with the Datadog API
 
-The following parameters are required for all functions.
+:depends: datadog_ Python module
 
-api_key
-    The datadog API key
+.. _datadog: https://pypi.python.org/pypi/datadog
 
-app_key
-    The datadog application key
+.. note::
+    The following parameters are required for all functions:
+
+    api_key
+        The datadog API key
+
+    app_key
+        The datadog application key
 
 Full argument reference is available on the Datadog API reference page
 https://docs.datadoghq.com/api/
 """
 
-# Import salt libs
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import third party libs
 import requests
+
 from salt.exceptions import SaltInvocationError
 
 HAS_DATADOG = True
@@ -156,7 +157,9 @@ def cancel_downtime(api_key=None, app_key=None, scope=None, id=None):
     elif scope:
         params = {"api_key": api_key, "application_key": app_key, "scope": scope}
         response = requests.post(
-            "https://app.datadoghq.com/api/v1/downtime/cancel/by_scope", params=params
+            "https://app.datadoghq.com/api/v1/downtime/cancel/by_scope",
+            params=params,
+            timeout=120,
         )
         if response.status_code == 200:
             ret["result"] = True
@@ -164,7 +167,7 @@ def cancel_downtime(api_key=None, app_key=None, scope=None, id=None):
             ret["comment"] = "Successfully cancelled downtime"
         else:
             ret["response"] = response.text
-            ret["comment"] = "Status Code: {}".format(response.status_code)
+            ret["comment"] = f"Status Code: {response.status_code}"
         return ret
     else:
         raise SaltInvocationError("One of id or scope must be specified")
@@ -224,9 +227,7 @@ def post_event(
         # Datadog only supports these alert types but the API doesn't return an
         # error for an incorrect alert_type, so we can do it here for now.
         # https://github.com/DataDog/datadogpy/issues/215
-        message = (
-            'alert_type must be one of "error", "warning", "info", or ' '"success"'
-        )
+        message = 'alert_type must be one of "error", "warning", "info", or "success"'
         raise SaltInvocationError(message)
 
     ret = {"result": False, "response": None, "comment": ""}
