@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
 """
 Device-Mapper module
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import os.path
 
@@ -32,7 +30,7 @@ def multipath_flush(device):
         salt '*' devmap.multipath_flush mpath1
     """
     if not os.path.exists(device):
-        return "{0} does not exist".format(device)
+        return f"{device} does not exist"
 
-    cmd = "multipath -f {0}".format(device)
+    cmd = f"multipath -f {device}"
     return __salt__["cmd.run"](cmd).splitlines()
