@@ -104,12 +104,14 @@ def __virtual__():
             )
             return (
                 False,
-                "The freebsdpkg execution module cannot be loaded: the configuration option 'providers:pkg' is set to 'pkgng'",
+                "The freebsdpkg execution module cannot be loaded: the configuration"
+                " option 'providers:pkg' is set to 'pkgng'",
             )
         return __virtualname__
     return (
         False,
-        "The freebsdpkg execution module cannot be loaded: either the os is not FreeBSD or the version of FreeBSD is >= 10.",
+        "The freebsdpkg execution module cannot be loaded: either the os is not FreeBSD"
+        " or the version of FreeBSD is >= 10.",
     )
 
 
@@ -173,20 +175,20 @@ def _match(names):
         cver = pkgs.get(name)
         if cver is not None:
             if len(cver) == 1:
-                matches.append("{}-{}".format(name, cver[0]))
+                matches.append(f"{name}-{cver[0]}")
             else:
                 ambiguous.append(name)
                 errors.append(
                     "Ambiguous package '{}'. Full name/version required. "
                     "Possible matches: {}".format(
-                        name, ", ".join(["{}-{}".format(name, x) for x in cver])
+                        name, ", ".join([f"{name}-{x}" for x in cver])
                     )
                 )
 
     # Find packages that did not match anything
     not_matched = set(names) - set(matches) - set(full_matches) - set(ambiguous)
     for name in not_matched:
-        errors.append("Package '{}' not found".format(name))
+        errors.append(f"Package '{name}' not found")
 
     return matches + full_matches, errors
 
