@@ -1,13 +1,9 @@
-# -*- coding: utf-8 -*-
 """
 Support for haproxy
 
 .. versionadded:: 2014.7.0
 """
 
-# Import Python libs
-from __future__ import absolute_import, generators, print_function, unicode_literals
-
 import logging
 import os
 import stat
@@ -42,7 +38,8 @@ def __virtual__():
         return __virtualname__
     return (
         False,
-        "The haproxyconn execution module cannot be loaded: haproxyctl module not available",
+        "The haproxyconn execution module cannot be loaded: haproxyctl module not"
+        " available",
     )
 
 
@@ -50,9 +47,9 @@ def _get_conn(socket=DEFAULT_SOCKET_URL):
     """
     Get connection to haproxy socket.
     """
-    assert os.path.exists(socket), "{0} does not exist.".format(socket)
+    assert os.path.exists(socket), f"{socket} does not exist."
     issock = os.stat(socket).st_mode
-    assert stat.S_ISSOCK(issock), "{0} is not a socket.".format(socket)
+    assert stat.S_ISSOCK(issock), f"{socket} is not a socket."
     ha_conn = haproxy.conn.HaPConn(socket)
     return ha_conn
 
@@ -317,6 +314,7 @@ def set_state(name, backend, state, socket=DEFAULT_SOCKET_URL):
         salt '*' haproxy.set_state my_proxy_server my_backend ready
 
     """
+
     # Pulling this in from the latest 0.5 release which is not yet in PyPi.
     # https://github.com/neurogeek/haproxyctl
     class setServerState(haproxy.cmds.Cmd):
