@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Module for managing JBoss AS 7 through the CLI interface.
 
@@ -22,19 +21,12 @@ Example:
 
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 import re
 
-# Import Salt libs
 import salt.utils.dictdiffer as dictdiffer
 from salt.exceptions import SaltInvocationError
 
-# Import 3rd-party libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 __func_alias__ = {"reload_": "reload"}
@@ -59,7 +51,7 @@ def status(jboss_config, host=None, server_config=None):
 
         salt '*' jboss7.status '{"cli_path": "integration.modules.sysmod.SysModuleTest.test_valid_docs", "controller": "10.11.12.13:9999", "cli_user": "jbossadm", "cli_password": "jbossadm"}'
 
-       """
+    """
     log.debug("======================== MODULE FUNCTION: jboss7.status")
     if host is None and server_config is None:
         operation = ":read-attribute(name=server-state)"
@@ -69,7 +61,8 @@ def status(jboss_config, host=None, server_config=None):
         )
     else:
         raise SaltInvocationError(
-            "Invalid parameters. Must either pass both host and server_config or neither"
+            "Invalid parameters. Must either pass both host and server_config or"
+            " neither"
         )
     return __salt__["jboss7_cli.run_operation"](
         jboss_config, operation, fail_on_error=False, retries=0
@@ -92,12 +85,12 @@ def stop_server(jboss_config, host=None):
 
         salt '*' jboss7.stop_server '{"cli_path": "integration.modules.sysmod.SysModuleTest.test_valid_docs", "controller": "10.11.12.13:9999", "cli_user": "jbossadm", "cli_password": "jbossadm"}'
 
-       """
+    """
     log.debug("======================== MODULE FUNCTION: jboss7.stop_server")
     if host is None:
         operation = ":shutdown"
     else:
-        operation = '/host="{host}"/:shutdown'.format(host=host)
+        operation = f'/host="{host}"/:shutdown'
     shutdown_result = __salt__["jboss7_cli.run_operation"](
         jboss_config, operation, fail_on_error=False
     )
@@ -131,12 +124,12 @@ def reload_(jboss_config, host=None):
 
         salt '*' jboss7.reload '{"cli_path": "integration.modules.sysmod.SysModuleTest.test_valid_docs", "controller": "10.11.12.13:9999", "cli_user": "jbossadm", "cli_password": "jbossadm"}'
 
-       """
+    """
     log.debug("======================== MODULE FUNCTION: jboss7.reload")
     if host is None:
         operation = ":reload"
     else:
-        operation = '/host="{host}"/:reload'.format(host=host)
+        operation = f'/host="{host}"/:reload'
     reload_result = __salt__["jboss7_cli.run_operation"](
         jboss_config, operation, fail_on_error=False
     )
@@ -185,7 +178,8 @@ def create_datasource(jboss_config, name, datasource_properties, profile=None):
         salt '*' jboss7.create_datasource '{"cli_path": "integration.modules.sysmod.SysModuleTest.test_valid_docs", "controller": "10.11.12.13:9999", "cli_user": "jbossadm", "cli_password": "jbossadm"}' 'my_datasource' '{"driver-name": "mysql", "connection-url": "jdbc:mysql://localhost:3306/sampleDatabase", "jndi-name": "java:jboss/datasources/sampleDS", "user-name": "sampleuser", "password": "secret", "min-pool-size": 3, "use-java-context": True}'
     """
     log.debug(
-        "======================== MODULE FUNCTION: jboss7.create_datasource, name=%s, profile=%s",
+        "======================== MODULE FUNCTION: jboss7.create_datasource, name=%s,"
+        " profile=%s",
         name,
         profile,
     )
@@ -200,7 +194,7 @@ def create_datasource(jboss_config, name, datasource_properties, profile=None):
         ),
     )
     if profile is not None:
-        operation = '/profile="{profile}"'.format(profile=profile) + operation
+        operation = f'/profile="{profile}"' + operation
 
     return __salt__["jboss7_cli.run_operation"](
         jboss_config, operation, fail_on_error=False
@@ -210,7 +204,7 @@ def create_datasource(jboss_config, name, datasource_properties, profile=None):
 def __get_properties_assignment_string(datasource_properties, ds_resource_description):
     assignment_strings = []
     ds_attributes = ds_resource_description["attributes"]
-    for key, val in six.iteritems(datasource_properties):
+    for key, val in datasource_properties.items():
         assignment_strings.append(
             __get_single_assignment_string(key, val, ds_attributes)
         )
@@ -219,7 +213,7 @@ def __get_properties_assignment_string(datasource_properties, ds_resource_descri
 
 
 def __get_single_assignment_string(key, val, ds_attributes):
-    return "{0}={1}".format(key, __format_value(key, val, ds_attributes))
+    return f"{key}={__format_value(key, val, ds_attributes)}"
 
 
 def __format_value(key, value, ds_attributes):
@@ -233,18 +227,14 @@ def __format_value(key, value, ds_attributes):
             else:
                 return "false"
         else:
-            raise Exception(
-                "Don't know how to convert {0} to BOOLEAN type".format(value)
-            )
+            raise Exception(f"Don't know how to convert {value} to BOOLEAN type")
 
     elif type_ == "INT":
-        return six.text_type(value)
+        return str(value)
     elif type_ == "STRING":
-        return '"{0}"'.format(value)
+        return f'"{value}"'
     else:
-        raise Exception(
-            "Don't know how to format value {0} of type {1}".format(value, type_)
-        )
+        raise Exception(f"Don't know how to format value {value} of type {type_}")
 
 
 def update_datasource(jboss_config, name, new_properties, profile=None):
@@ -276,7 +266,8 @@ def update_datasource(jboss_config, name, new_properties, profile=None):
 
     """
     log.debug(
-        "======================== MODULE FUNCTION: jboss7.update_datasource, name=%s, profile=%s",
+        "======================== MODULE FUNCTION: jboss7.update_datasource, name=%s,"
+        " profile=%s",
         name,
         profile,
     )
@@ -297,10 +288,10 @@ def update_datasource(jboss_config, name, new_properties, profile=None):
             )
             if not update_result["success"]:
                 ret["result"] = False
-                ret["comment"] = ret["comment"] + (
-                    "Could not update datasource property {0} with value {1},\n stdout: {2}\n".format(
-                        key, new_properties[key], update_result["stdout"]
-                    )
+                ret["comment"] = ret[
+                    "comment"
+                ] + "Could not update datasource property {} with value {},\n stdout: {}\n".format(
+                    key, new_properties[key], update_result["stdout"]
                 )
 
     return ret
@@ -308,16 +299,19 @@ def update_datasource(jboss_config, name, new_properties, profile=None):
 
 def __get_datasource_resource_description(jboss_config, name, profile=None):
     log.debug(
-        "======================== MODULE FUNCTION: jboss7.__get_datasource_resource_description, name=%s, profile=%s",
+        "======================== MODULE FUNCTION:"
+        " jboss7.__get_datasource_resource_description, name=%s, profile=%s",
         name,
         profile,
     )
 
-    operation = '/subsystem=datasources/data-source="{name}":read-resource-description'.format(
-        name=name
+    operation = (
+        '/subsystem=datasources/data-source="{name}":read-resource-description'.format(
+            name=name
+        )
     )
     if profile is not None:
-        operation = '/profile="{profile}"'.format(profile=profile) + operation
+        operation = f'/profile="{profile}"' + operation
     operation_result = __salt__["jboss7_cli.run_operation"](jboss_config, operation)
     if operation_result["outcome"]:
         return operation_result["result"]
@@ -339,7 +333,7 @@ def read_datasource(jboss_config, name, profile=None):
     .. code-block:: bash
 
         salt '*' jboss7.read_datasource '{"cli_path": "integration.modules.sysmod.SysModuleTest.test_valid_docs", "controller": "10.11.12.13:9999", "cli_user": "jbossadm", "cli_password": "jbossadm"}'
-       """
+    """
     log.debug(
         "======================== MODULE FUNCTION: jboss7.read_datasource, name=%s",
         name,
@@ -370,16 +364,20 @@ def create_simple_binding(jboss_config, binding_name, value, profile=None):
                 my_binding_name my_binding_value
        """
     log.debug(
-        "======================== MODULE FUNCTION: jboss7.create_simple_binding, binding_name=%s, value=%s, profile=%s",
+        "======================== MODULE FUNCTION: jboss7.create_simple_binding,"
+        " binding_name=%s, value=%s, profile=%s",
         binding_name,
         value,
         profile,
     )
-    operation = '/subsystem=naming/binding="{binding_name}":add(binding-type=simple, value="{value}")'.format(
-        binding_name=binding_name, value=__escape_binding_value(value)
+    operation = (
+        '/subsystem=naming/binding="{binding_name}":add(binding-type=simple,'
+        ' value="{value}")'.format(
+            binding_name=binding_name, value=__escape_binding_value(value)
+        )
     )
     if profile is not None:
-        operation = '/profile="{profile}"'.format(profile=profile) + operation
+        operation = f'/profile="{profile}"' + operation
     return __salt__["jboss7_cli.run_operation"](jboss_config, operation)
 
 
@@ -401,18 +399,22 @@ def update_simple_binding(jboss_config, binding_name, value, profile=None):
     .. code-block:: bash
 
         salt '*' jboss7.update_simple_binding '{"cli_path": "integration.modules.sysmod.SysModuleTest.test_valid_docs", "controller": "10.11.12.13:9999", "cli_user": "jbossadm", "cli_password": "jbossadm"}' my_binding_name my_binding_value
-       """
+    """
     log.debug(
-        "======================== MODULE FUNCTION: jboss7.update_simple_binding, binding_name=%s, value=%s, profile=%s",
+        "======================== MODULE FUNCTION: jboss7.update_simple_binding,"
+        " binding_name=%s, value=%s, profile=%s",
         binding_name,
         value,
         profile,
     )
-    operation = '/subsystem=naming/binding="{binding_name}":write-attribute(name=value, value="{value}")'.format(
-        binding_name=binding_name, value=__escape_binding_value(value)
+    operation = (
+        '/subsystem=naming/binding="{binding_name}":write-attribute(name=value,'
+        ' value="{value}")'.format(
+            binding_name=binding_name, value=__escape_binding_value(value)
+        )
     )
     if profile is not None:
-        operation = '/profile="{profile}"'.format(profile=profile) + operation
+        operation = f'/profile="{profile}"' + operation
     return __salt__["jboss7_cli.run_operation"](jboss_config, operation)
 
 
@@ -432,7 +434,7 @@ def read_simple_binding(jboss_config, binding_name, profile=None):
         .. code-block:: bash
 
         salt '*' jboss7.read_simple_binding '{"cli_path": "integration.modules.sysmod.SysModuleTest.test_valid_docs", "controller": "10.11.12.13:9999", "cli_user": "jbossadm", "cli_password": "jbossadm"}' my_binding_name
-       """
+    """
     log.debug(
         "======================== MODULE FUNCTION: jboss7.read_simple_binding, %s",
         binding_name,
@@ -446,7 +448,7 @@ def __read_simple_binding(jboss_config, binding_name, profile=None):
         binding_name=binding_name
     )
     if profile is not None:
-        operation = '/profile="{profile}"'.format(profile=profile) + operation
+        operation = f'/profile="{profile}"' + operation
     return __salt__["jboss7_cli.run_operation"](jboss_config, operation)
 
 
@@ -454,7 +456,8 @@ def __update_datasource_property(
     jboss_config, datasource_name, name, value, ds_attributes, profile=None
 ):
     log.debug(
-        "======================== MODULE FUNCTION: jboss7.__update_datasource_property, datasource_name=%s, name=%s, value=%s, profile=%s",
+        "======================== MODULE FUNCTION: jboss7.__update_datasource_property,"
+        " datasource_name=%s, name=%s, value=%s, profile=%s",
         datasource_name,
         name,
         value,
@@ -467,7 +470,7 @@ def __update_datasource_property(
         value=__format_value(name, value, ds_attributes),
     )
     if profile is not None:
-        operation = '/profile="{profile}"'.format(profile=profile) + operation
+        operation = f'/profile="{profile}"' + operation
 
     return __salt__["jboss7_cli.run_operation"](
         jboss_config, operation, fail_on_error=False
@@ -480,7 +483,7 @@ def __read_datasource(jboss_config, name, profile=None):
         name=name
     )
     if profile is not None:
-        operation = '/profile="{profile}"'.format(profile=profile) + operation
+        operation = f'/profile="{profile}"' + operation
 
     operation_result = __salt__["jboss7_cli.run_operation"](jboss_config, operation)
 
@@ -509,16 +512,17 @@ def remove_datasource(jboss_config, name, profile=None):
     .. code-block:: bash
 
         salt '*' jboss7.remove_datasource '{"cli_path": "integration.modules.sysmod.SysModuleTest.test_valid_docs", "controller": "10.11.12.13:9999", "cli_user": "jbossadm", "cli_password": "jbossadm"}' my_datasource_name
-       """
+    """
     log.debug(
-        "======================== MODULE FUNCTION: jboss7.remove_datasource, name=%s, profile=%s",
+        "======================== MODULE FUNCTION: jboss7.remove_datasource, name=%s,"
+        " profile=%s",
         name,
         profile,
     )
 
-    operation = "/subsystem=datasources/data-source={name}:remove".format(name=name)
+    operation = f"/subsystem=datasources/data-source={name}:remove"
     if profile is not None:
-        operation = '/profile="{profile}"'.format(profile=profile) + operation
+        operation = f'/profile="{profile}"' + operation
 
     return __salt__["jboss7_cli.run_operation"](
         jboss_config, operation, fail_on_error=False
@@ -539,12 +543,12 @@ def deploy(jboss_config, source_file):
     .. code-block:: bash
 
         salt '*' jboss7.deploy '{"cli_path": "integration.modules.sysmod.SysModuleTest.test_valid_docs", "controller": "10.11.12.13:9999", "cli_user": "jbossadm", "cli_password": "jbossadm"}' /opt/deploy_files/my_deploy
-       """
+    """
     log.debug(
         "======================== MODULE FUNCTION: jboss7.deploy, source_file=%s",
         source_file,
     )
-    command = "deploy {source_file} --force ".format(source_file=source_file)
+    command = f"deploy {source_file} --force "
     return __salt__["jboss7_cli.run_command"](
         jboss_config, command, fail_on_error=False
     )
@@ -563,7 +567,7 @@ def list_deployments(jboss_config):
 
          salt '*' jboss7.list_deployments '{"cli_path": "integration.modules.sysmod.SysModuleTest.test_valid_docs", "controller": "10.11.12.13:9999", "cli_user": "jbossadm", "cli_password": "jbossadm"}'
 
-       """
+    """
     log.debug("======================== MODULE FUNCTION: jboss7.list_deployments")
     command_result = __salt__["jboss7_cli.run_command"](jboss_config, "deploy")
     deployments = []
@@ -587,10 +591,10 @@ def undeploy(jboss_config, deployment):
     .. code-block:: bash
 
         salt '*' jboss7.undeploy '{"cli_path": "integration.modules.sysmod.SysModuleTest.test_valid_docs", "controller": "10.11.12.13:9999", "cli_user": "jbossadm", "cli_password": "jbossadm"}' my_deployment
-       """
+    """
     log.debug(
         "======================== MODULE FUNCTION: jboss7.undeploy, deployment=%s",
         deployment,
     )
-    command = "undeploy {deployment} ".format(deployment=deployment)
+    command = f"undeploy {deployment} "
     return __salt__["jboss7_cli.run_command"](jboss_config, command)
