@@ -1,13 +1,9 @@
-# -*- coding: utf-8 -*-
 """
 Functions to view the minion's public key information
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import python libs
 import os
 
-# Import Salt libs
 import salt.utils.crypt
 
 
