@@ -687,7 +687,11 @@ def container_create(
     # Add devices if not wait and devices have been given.
     if devices:
         for dn, dargs in devices.items():
-            container_device_add(name, dn, **dargs)
+            if "type" in dargs:
+                # extract 'type' so it won't be overwritten
+                container_device_add(name, dn, device_type=dargs["type"], **dargs)
+            else:
+                container_device_add(name, dn, **dargs)
 
     if _raw:
         return container
@@ -3599,43 +3603,3 @@ def _pylxd_model_to_dict(obj):
         if hasattr(obj, key):
             marshalled[key] = getattr(obj, key)
     return marshalled
-
-
-#
-# Monkey patching for missing functionality in pylxd
-#
-
-if HAS_PYLXD:
-    import pylxd.exceptions  # NOQA
-
-    if not hasattr(pylxd.exceptions, "NotFound"):
-        # Old version of pylxd
-
-        class NotFound(pylxd.exceptions.LXDAPIException):
-            """An exception raised when an object is not found."""
-
-        pylxd.exceptions.NotFound = NotFound
-
-    try:
-        from pylxd.container import Container
-    except ImportError:
-        from pylxd.models.container import Container
-
-    def put(self, filepath, data, mode=None, uid=None, gid=None):
-        headers = {}
-        if mode is not None:
-            if isinstance(mode, int):
-                mode = oct(mode)
-            elif not mode.startswith("0"):
-                mode = f"0{mode}"
-            headers["X-LXD-mode"] = mode
-        if uid is not None:
-            headers["X-LXD-uid"] = str(uid)
-        if gid is not None:
-            headers["X-LXD-gid"] = str(gid)
-        response = self._client.api.containers[self._container.name].files.post(
-            params={"path": filepath}, data=data, headers=headers
-        )
-        return response.status_code == 200
-
-    Container.FilesManager.put = put
