@@ -1,6 +1,14 @@
 """
 Homebrew for macOS
 
+It is recommended for the ``salt-minion`` to have the ``HOMEBREW_PREFIX``
+environment variable set.
+
+This will ensure that Salt uses the correct path for the ``brew`` binary.
+
+Typically, this is set to ``/usr/local`` for Intel Macs and ``/opt/homebrew``
+for Apple Silicon Macs.
+
 .. important::
     If you feel that Salt should be using this module to manage packages on a
     minion, and it is using a different module (or gives an error similar to
@@ -9,9 +17,8 @@ Homebrew for macOS
 """
 
 import copy
-import functools
 import logging
-import re
+import os
 
 import salt.utils.data
 import salt.utils.functools
@@ -29,11 +36,11 @@ __virtualname__ = "pkg"
 
 def __virtual__():
     """
-    Confine this module to Mac OS with Homebrew.
+    Confine this module to macOS with Homebrew.
     """
     if __grains__["os"] != "MacOS":
         return False, "brew module is macos specific"
-    if not salt.utils.path.which("brew"):
+    if not _homebrew_bin():
         return False, "The 'brew' binary was not found"
     return __virtualname__
 
@@ -95,12 +102,43 @@ def _tap(tap, runas=None):
     return True
 
 
+def _homebrew_os_bin():
+    """
+    Fetch PATH binary brew full path eg: /usr/local/bin/brew (symbolic link)
+    """
+
+    original_path = os.environ.get("PATH")
+    try:
+        # Add "/opt/homebrew" temporary to the PATH for Apple Silicon if
+        # the PATH does not include "/opt/homebrew"
+        current_path = original_path or ""
+        homebrew_path = "/opt/homebrew/bin"
+        if homebrew_path not in current_path.split(os.path.pathsep):
+            extended_path = os.path.pathsep.join([current_path, homebrew_path])
+            os.environ["PATH"] = extended_path.lstrip(os.path.pathsep)
+
+        # Search for the brew executable in the current PATH
+        brew = salt.utils.path.which("brew")
+    finally:
+        # Restore original PATH
+        if original_path is None:
+            del os.environ["PATH"]
+        else:
+            os.environ["PATH"] = original_path
+
+    return brew
+
+
 def _homebrew_bin():
     """
-    Returns the full path to the homebrew binary in the PATH
+    Returns the full path to the homebrew binary in the homebrew installation folder
     """
-    ret = __salt__["cmd.run"]("brew --prefix", output_loglevel="trace")
-    ret += "/bin/brew"
+    ret = homebrew_prefix()
+    if ret is not None:
+        ret += "/bin/brew"
+    else:
+        log.warning("Failed to find homebrew prefix")
+
     return ret
 
 
@@ -108,10 +146,19 @@ def _call_brew(*cmd, failhard=True):
     """
     Calls the brew command with the user account of brew
     """
-    user = __salt__["file.get_user"](_homebrew_bin())
+    brew_exec = _homebrew_bin()
+
+    user = __salt__["file.get_user"](brew_exec)
     runas = user if user != __opts__["user"] else None
+    _cmd = []
+    if runas:
+        _cmd = [f"sudo -i -n -H -u {runas} -- "]
+    _cmd = _cmd + [brew_exec] + list(cmd)
+    _cmd = " ".join(_cmd)
+
+    runas = None
     result = __salt__["cmd.run_all"](
-        [salt.utils.path.which("brew")] + list(cmd),
+        cmd=_cmd,
         runas=runas,
         output_loglevel="trace",
         python_shell=False,
@@ -133,6 +180,47 @@ def _list_pkgs_from_context(versions_as_list):
         return ret
 
 
+def homebrew_prefix():
+    """
+    Returns the full path to the homebrew prefix.
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' pkg.homebrew_prefix
+    """
+
+    # If HOMEBREW_PREFIX env variable is present, use it
+    env_homebrew_prefix = "HOMEBREW_PREFIX"
+    if env_homebrew_prefix in os.environ:
+        log.debug("%s is set. Using it for homebrew prefix.", env_homebrew_prefix)
+        return os.environ[env_homebrew_prefix]
+
+    # Try brew --prefix otherwise
+    try:
+        log.debug("Trying to find homebrew prefix by running 'brew --prefix'")
+
+        brew = _homebrew_os_bin()
+        if brew is not None:
+            # Check if the found brew command is the right one
+            import salt.modules.cmdmod
+            import salt.modules.file
+
+            runas = salt.modules.file.get_user(brew)
+            ret = salt.modules.cmdmod.run(
+                "brew --prefix", runas=runas, output_loglevel="trace", raise_err=True
+            )
+
+            return ret
+    except CommandExecutionError as exc:
+        log.debug(
+            "Unable to find homebrew prefix by running 'brew --prefix'. Error: %s", exc
+        )
+
+    return None
+
+
 def list_pkgs(versions_as_list=False, **kwargs):
     """
     List the packages currently installed in a dict::
@@ -163,49 +251,30 @@ def list_pkgs(versions_as_list=False, **kwargs):
     for package in package_info["formulae"]:
         # Brew allows multiple versions of the same package to be installed.
         # Salt allows for this, so it must be accounted for.
-        versions = [v["version"] for v in package["installed"]]
+        pkg_versions = [v["version"] for v in package["installed"]]
         # Brew allows for aliasing of packages, all of which will be
         # installable from a Salt call, so all names must be accounted for.
-        names = package["aliases"] + [package["name"], package["full_name"]]
+        pkg_names = package["aliases"] + [package["name"], package["full_name"]]
         # Create a list of tuples containing all possible combinations of
         # names and versions, because all are valid.
-        combinations = [(n, v) for n in names for v in versions]
+        combinations = [(n, v) for n in pkg_names for v in pkg_versions]
 
-        for name, version in combinations:
-            __salt__["pkg_resource.add_pkg"](ret, name, version)
+        for pkg_name, pkg_version in combinations:
+            __salt__["pkg_resource.add_pkg"](ret, pkg_name, pkg_version)
 
-    # Grab packages from brew cask, if available.
-    # Brew Cask doesn't provide a JSON interface, must be parsed the old way.
-    try:
-        out = _call_brew("list", "--cask", "--versions")["stdout"]
-
-        for line in out.splitlines():
-            try:
-                name_and_versions = line.split(" ")
-                pkg_name = name_and_versions[0]
-
-                # Get cask namespace
-                match = re.search(
-                    r"^From: .*/(.+?)/homebrew-(.+?)/.*$",
-                    _call_brew("info", "--cask", pkg_name)["stdout"],
-                    re.MULTILINE,
-                )
-                if match:
-                    namespace = "/".join(
-                        (match.group(1).lower(), match.group(2).lower())
-                    )
-                else:
-                    namespace = "homebrew/cask"
-
-                name = "/".join((namespace, pkg_name))
-                installed_versions = name_and_versions[1:]
-                key_func = functools.cmp_to_key(salt.utils.versions.version_cmp)
-                newest_version = sorted(installed_versions, key=key_func).pop()
-            except ValueError:
-                continue
-            __salt__["pkg_resource.add_pkg"](ret, name, newest_version)
-    except CommandExecutionError:
-        pass
+    for package in package_info["casks"]:
+        pkg_version = package["installed"]
+        pkg_names = {package["full_token"], package["token"]}
+        pkg_tap = package.get("tap", None)
+        # The following name is appended to maintain backward compatibility
+        # with old salt formulas. Since full_token and token are the same
+        # for official taps (homebrew/*).
+        if not pkg_tap:
+            # Tap is null when the package is from homebrew/cask.
+            pkg_tap = "homebrew/cask"
+        pkg_names.add("/".join([pkg_tap, package["token"]]))
+        for pkg_name in pkg_names:
+            __salt__["pkg_resource.add_pkg"](ret, pkg_name, pkg_version)
 
     __salt__["pkg_resource.sort_pkglist"](ret)
     __context__["pkg.list_pkgs"] = copy.deepcopy(ret)
@@ -251,7 +320,10 @@ def latest_version(*names, **kwargs):
 
     def get_version(pkg_info):
         # Perhaps this will need an option to pick devel by default
-        return pkg_info["versions"]["stable"] or pkg_info["versions"]["devel"]
+        version = pkg_info["versions"]["stable"] or pkg_info["versions"]["devel"]
+        if pkg_info["versions"]["bottle"] and pkg_info["revision"] >= 1:
+            version = "{}_{}".format(version, pkg_info["revision"])
+        return version
 
     versions_dict = {key: get_version(val) for key, val in _info(*names).items()}
 
@@ -362,7 +434,21 @@ def _info(*pkgs):
         log.error("Failed to get info about packages: %s", " ".join(pkgs))
         return {}
     output = salt.utils.json.loads(brew_result["stdout"])
-    return dict(zip(pkgs, output["formulae"]))
+
+    meta_info = {"formulae": ["name", "full_name"], "casks": ["token", "full_token"]}
+
+    pkgs_info = dict()
+    for tap, keys in meta_info.items():
+        data = output[tap]
+        if len(data) == 0:
+            continue
+
+        for _pkg in data:
+            for key in keys:
+                if _pkg[key] in pkgs:
+                    pkgs_info[_pkg[key]] = _pkg
+
+    return pkgs_info
 
 
 def install(name=None, pkgs=None, taps=None, options=None, **kwargs):
@@ -474,7 +560,7 @@ def install(name=None, pkgs=None, taps=None, options=None, **kwargs):
     return ret
 
 
-def list_upgrades(refresh=True, **kwargs):  # pylint: disable=W0613
+def list_upgrades(refresh=True, include_casks=False, **kwargs):  # pylint: disable=W0613
     """
     Check whether or not an upgrade is available for all packages
 
@@ -491,15 +577,21 @@ def list_upgrades(refresh=True, **kwargs):  # pylint: disable=W0613
     ret = {}
 
     try:
-        data = salt.utils.json.loads(res["stdout"])["formulae"]
+        data = salt.utils.json.loads(res["stdout"])
     except ValueError as err:
-        msg = 'unable to interpret output from "brew outdated": {}'.format(err)
+        msg = f'unable to interpret output from "brew outdated": {err}'
         log.error(msg)
         raise CommandExecutionError(msg)
 
-    for pkg in data:
+    for pkg in data["formulae"]:
         # current means latest available to brew
         ret[pkg["name"]] = pkg["current_version"]
+
+    if include_casks:
+        for pkg in data["casks"]:
+            # current means latest available to brew
+            ret[pkg["name"]] = pkg["current_version"]
+
     return ret
 
 
@@ -513,7 +605,7 @@ def upgrade_available(pkg, **kwargs):
 
         salt '*' pkg.upgrade_available <package name>
     """
-    return pkg in list_upgrades()
+    return pkg in list_upgrades(**kwargs)
 
 
 def upgrade(refresh=True, **kwargs):
@@ -628,27 +720,23 @@ def hold(name=None, pkgs=None, sources=None, **kwargs):  # pylint: disable=W0613
         ret[target] = {"name": target, "changes": {}, "result": False, "comment": ""}
 
         if target not in installed:
-            ret[target]["comment"] = "Package {} does not have a state.".format(target)
+            ret[target]["comment"] = f"Package {target} does not have a state."
         elif target not in pinned:
             if "test" in __opts__ and __opts__["test"]:
                 ret[target].update(result=None)
-                ret[target]["comment"] = "Package {} is set to be held.".format(target)
+                ret[target]["comment"] = f"Package {target} is set to be held."
             else:
                 result = _pin(target)
                 if result:
                     changes = {"old": "install", "new": "hold"}
                     ret[target].update(changes=changes, result=True)
-                    ret[target]["comment"] = "Package {} is now being held.".format(
-                        target
-                    )
+                    ret[target]["comment"] = f"Package {target} is now being held."
                 else:
                     ret[target].update(result=False)
-                    ret[target]["comment"] = "Unable to hold package {}.".format(target)
+                    ret[target]["comment"] = f"Unable to hold package {target}."
         else:
             ret[target].update(result=True)
-            ret[target]["comment"] = "Package {} is already set to be held.".format(
-                target
-            )
+            ret[target]["comment"] = f"Package {target} is already set to be held."
     return ret
 
 
@@ -704,13 +792,11 @@ def unhold(name=None, pkgs=None, sources=None, **kwargs):  # pylint: disable=W06
         ret[target] = {"name": target, "changes": {}, "result": False, "comment": ""}
 
         if target not in installed:
-            ret[target]["comment"] = "Package {} does not have a state.".format(target)
+            ret[target]["comment"] = f"Package {target} does not have a state."
         elif target in pinned:
             if "test" in __opts__ and __opts__["test"]:
                 ret[target].update(result=None)
-                ret[target]["comment"] = "Package {} is set to be unheld.".format(
-                    target
-                )
+                ret[target]["comment"] = f"Package {target} is set to be unheld."
             else:
                 result = _unpin(target)
                 if result:
@@ -718,17 +804,13 @@ def unhold(name=None, pkgs=None, sources=None, **kwargs):  # pylint: disable=W06
                     ret[target].update(changes=changes, result=True)
                     ret[target][
                         "comment"
-                    ] = "Package {} is no longer being held.".format(target)
+                    ] = f"Package {target} is no longer being held."
                 else:
                     ret[target].update(result=False)
-                    ret[target]["comment"] = "Unable to unhold package {}.".format(
-                        target
-                    )
+                    ret[target]["comment"] = f"Unable to unhold package {target}."
         else:
             ret[target].update(result=True)
-            ret[target]["comment"] = "Package {} is already set not to be held.".format(
-                target
-            )
+            ret[target]["comment"] = f"Package {target} is already set not to be held."
     return ret
 
 
