@@ -8,14 +8,14 @@ import stat
 import salt.utils.files
 import salt.utils.stringutils
 
-PLUGINDIR = "/usr/pkg/etc/munin/plugins/"
+PLUGINDIR = "/etc/munin/plugins/"
 
 
 def __virtual__():
     """
     Only load the module if munin-node is installed
     """
-    if os.path.exists("/usr/pkg/etc/munin/munin-node.conf"):
+    if os.path.exists("/etc/munin/munin-node.conf"):
         return "munin"
     return (
         False,
@@ -23,7 +23,7 @@ def __virtual__():
     )
 
 
-def _get_conf(fname="/usr/pkg/etc/munin/munin-node.cfg"):
+def _get_conf(fname="/etc/munin/munin-node.cfg"):
     with salt.utils.files.fopen(fname, "r") as fp_:
         return salt.utils.stringutils.to_unicode(fp_.read())
 
@@ -49,9 +49,7 @@ def run(plugins):
         if plugin not in all_plugins:
             continue
         data[plugin] = {}
-        muninout = __salt__["cmd.run"](
-            "munin-run {}".format(plugin), python_shell=False
-        )
+        muninout = __salt__["cmd.run"](f"munin-run {plugin}", python_shell=False)
         for line in muninout.split("\n"):
             if "value" in line:  # This skips multigraph lines, etc
                 key, val = line.split(" ")
