@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 NAPALM BGP
 ==========
@@ -18,9 +17,6 @@ Dependencies
 .. versionadded:: 2016.11.0
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import python lib
 import logging
 
 # import NAPALM utils
@@ -62,7 +58,6 @@ def __virtual__():
 
 @proxy_napalm_wrap
 def config(group=None, neighbor=None, **kwargs):
-
     """
     Provides the BGP configuration on the device.
 
@@ -172,7 +167,6 @@ def config(group=None, neighbor=None, **kwargs):
 
 @proxy_napalm_wrap
 def neighbors(neighbor=None, **kwargs):
-
     """
     Provides details regarding the BGP sessions configured on the network device.
 
