@@ -90,6 +90,7 @@ import salt.utils.data
 import salt.utils.files
 import salt.utils.json
 import salt.utils.locales
+import salt.utils.package
 import salt.utils.platform
 import salt.utils.stringutils
 import salt.utils.url
@@ -144,7 +145,7 @@ def _check_bundled():
     """
     Gather run-time information to indicate if we are running from source or bundled.
     """
-    if hasattr(sys, "RELENV"):
+    if salt.utils.package.bundled():
         return True
     return False
 
@@ -252,7 +253,6 @@ def _get_env_activate(bin_env):
 
 
 def _find_req(link):
-
     logger.info("_find_req -- link = %s", link)
 
     with salt.utils.files.fopen(link) as fh_link:
@@ -848,9 +848,11 @@ def install(
         cmd.extend(["--build", build])
 
     # Use VENV_PIP_TARGET environment variable value as target
-    # if set and no target specified on the function call
+    # if set and no target specified on the function call.
+    # Do not set target if bin_env specified, use default
+    # for specified binary environment or expect explicit target specification.
     target_env = os.environ.get("VENV_PIP_TARGET", None)
-    if target is None and target_env is not None:
+    if target is None and target_env is not None and bin_env is None:
         target = target_env
 
     if target:
