@@ -35,7 +35,7 @@ def __virtual__():
         return __virtualname__
     return (
         False,
-        "{} module can only be loaded on SmartOS compute nodes".format(__virtualname__),
+        f"{__virtualname__} module can only be loaded on SmartOS compute nodes",
     )
 
 
@@ -43,10 +43,12 @@ def _exit_status(retcode):
     """
     Translate exit status of vmadm
     """
-    ret = {0: "Successful completion.", 1: "An error occurred.", 2: "Usage error."}[
-        retcode
-    ]
-    return ret
+    ret = {
+        0: "Successful completion.",
+        1: "An error occurred.",
+        2: "Usage error.",
+    }
+    return ret[retcode]
 
 
 def _create_update_from_file(mode="create", uuid=None, path=None):
@@ -55,7 +57,7 @@ def _create_update_from_file(mode="create", uuid=None, path=None):
     """
     ret = {}
     if not os.path.isfile(path) or path is None:
-        ret["Error"] = "File ({}) does not exists!".format(path)
+        ret["Error"] = f"File ({path}) does not exists!"
         return ret
     # vmadm validate create|update [-f <filename>]
     cmd = "vmadm validate {mode} {brand} -f {path}".format(
@@ -169,7 +171,7 @@ def start(vm, options=None, key="uuid"):
     if key not in ["uuid", "alias", "hostname"]:
         ret["Error"] = "Key must be either uuid, alias or hostname"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     # vmadm start <uuid> [option=value ...]
@@ -208,7 +210,7 @@ def stop(vm, force=False, key="uuid"):
     if key not in ["uuid", "alias", "hostname"]:
         ret["Error"] = "Key must be either uuid, alias or hostname"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     # vmadm stop <uuid> [-F]
@@ -245,7 +247,7 @@ def reboot(vm, force=False, key="uuid"):
     if key not in ["uuid", "alias", "hostname"]:
         ret["Error"] = "Key must be either uuid, alias or hostname"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     # vmadm reboot <uuid> [-F]
@@ -284,8 +286,8 @@ def list_vms(search=None, sort=None, order="uuid,type,ram,state,alias", keyed=Tr
     ret = {}
     # vmadm list [-p] [-H] [-o field,...] [-s field,...] [field=value ...]
     cmd = "vmadm list -p -H {order} {sort} {search}".format(
-        order="-o {}".format(order) if order else "",
-        sort="-s {}".format(sort) if sort else "",
+        order=f"-o {order}" if order else "",
+        sort=f"-s {sort}" if sort else "",
         search=search if search else "",
     )
     res = __salt__["cmd.run_all"](cmd)
@@ -339,7 +341,7 @@ def lookup(search=None, order=None, one=False):
     # vmadm lookup [-j|-1] [-o field,...] [field=value ...]
     cmd = "vmadm lookup {one} {order} {search}".format(
         one="-1" if one else "-j",
-        order="-o {}".format(order) if order else "",
+        order=f"-o {order}" if order else "",
         search=search if search else "",
     )
     res = __salt__["cmd.run_all"](cmd)
@@ -384,11 +386,11 @@ def sysrq(vm, action="nmi", key="uuid"):
     if action not in ["nmi", "screenshot"]:
         ret["Error"] = "Action must be either nmi or screenshot"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     # vmadm sysrq <uuid> <nmi|screenshot>
-    cmd = "vmadm sysrq {uuid} {action}".format(uuid=vm, action=action)
+    cmd = f"vmadm sysrq {vm} {action}"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     if retcode != 0:
@@ -417,11 +419,11 @@ def delete(vm, key="uuid"):
     if key not in ["uuid", "alias", "hostname"]:
         ret["Error"] = "Key must be either uuid, alias or hostname"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     # vmadm delete <uuid>
-    cmd = "vmadm delete {}".format(vm)
+    cmd = f"vmadm delete {vm}"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     if retcode != 0:
@@ -450,11 +452,11 @@ def get(vm, key="uuid"):
     if key not in ["uuid", "alias", "hostname"]:
         ret["Error"] = "Key must be either uuid, alias or hostname"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     # vmadm get <uuid>
-    cmd = "vmadm get {}".format(vm)
+    cmd = f"vmadm get {vm}"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     if retcode != 0:
@@ -501,11 +503,11 @@ def info(vm, info_type="all", key="uuid"):
     if key not in ["uuid", "alias", "hostname"]:
         ret["Error"] = "Key must be either uuid, alias or hostname"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     # vmadm info <uuid> [type,...]
-    cmd = "vmadm info {uuid} {type}".format(uuid=vm, type=info_type)
+    cmd = f"vmadm info {vm} {info_type}"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     if retcode != 0:
@@ -539,7 +541,7 @@ def create_snapshot(vm, name, key="uuid"):
     if key not in ["uuid", "alias", "hostname"]:
         ret["Error"] = "Key must be either uuid, alias or hostname"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     vmobj = get(vm)
@@ -553,7 +555,7 @@ def create_snapshot(vm, name, key="uuid"):
         ret["Error"] = "VM must be running to take a snapshot"
         return ret
     # vmadm create-snapshot <uuid> <snapname>
-    cmd = "vmadm create-snapshot {uuid} {snapshot}".format(snapshot=name, uuid=vm)
+    cmd = f"vmadm create-snapshot {vm} {name}"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     if retcode != 0:
@@ -587,7 +589,7 @@ def delete_snapshot(vm, name, key="uuid"):
     if key not in ["uuid", "alias", "hostname"]:
         ret["Error"] = "Key must be either uuid, alias or hostname"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     vmobj = get(vm)
@@ -598,7 +600,7 @@ def delete_snapshot(vm, name, key="uuid"):
         ret["Error"] = "VM must be of type OS"
         return ret
     # vmadm delete-snapshot <uuid> <snapname>
-    cmd = "vmadm delete-snapshot {uuid} {snapshot}".format(snapshot=name, uuid=vm)
+    cmd = f"vmadm delete-snapshot {vm} {name}"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     if retcode != 0:
@@ -632,7 +634,7 @@ def rollback_snapshot(vm, name, key="uuid"):
     if key not in ["uuid", "alias", "hostname"]:
         ret["Error"] = "Key must be either uuid, alias or hostname"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     vmobj = get(vm)
@@ -643,7 +645,7 @@ def rollback_snapshot(vm, name, key="uuid"):
         ret["Error"] = "VM must be of type OS"
         return ret
     # vmadm rollback-snapshot <uuid> <snapname>
-    cmd = "vmadm rollback-snapshot {uuid} {snapshot}".format(snapshot=name, uuid=vm)
+    cmd = f"vmadm rollback-snapshot {vm} {name}"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     if retcode != 0:
@@ -674,11 +676,11 @@ def reprovision(vm, image, key="uuid"):
     if key not in ["uuid", "alias", "hostname"]:
         ret["Error"] = "Key must be either uuid, alias or hostname"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     if image not in __salt__["imgadm.list"]():
-        ret["Error"] = "Image ({}) is not present on this host".format(image)
+        ret["Error"] = f"Image ({image}) is not present on this host"
         return ret
     # vmadm reprovision <uuid> [-f <filename>]
     cmd = "echo {image} | vmadm reprovision {uuid}".format(
@@ -753,7 +755,7 @@ def update(vm, from_file=None, key="uuid", **kwargs):
     if key not in ["uuid", "alias", "hostname"]:
         ret["Error"] = "Key must be either uuid, alias or hostname"
         return ret
-    uuid = lookup("{}={}".format(key, vm), one=True)
+    uuid = lookup(f"{key}={vm}", one=True)
     if "Error" in uuid:
         return uuid
 
@@ -788,12 +790,12 @@ def send(vm, target, key="uuid"):
     if not os.path.isdir(target):
         ret["Error"] = "Target must be a directory or host"
         return ret
-    vm = lookup("{}={}".format(key, vm), one=True)
+    vm = lookup(f"{key}={vm}", one=True)
     if "Error" in vm:
         return vm
     # vmadm send <uuid> [target]
     cmd = "vmadm send {uuid} > {target}".format(
-        uuid=vm, target=os.path.join(target, "{}.vmdata".format(vm))
+        uuid=vm, target=os.path.join(target, f"{vm}.vmdata")
     )
     res = __salt__["cmd.run_all"](cmd, python_shell=True)
     retcode = res["retcode"]
@@ -810,7 +812,7 @@ def send(vm, target, key="uuid"):
         name = name[-1]
         cmd = "zfs send {dataset} > {target}".format(
             dataset=dataset,
-            target=os.path.join(target, "{}-{}.zfsds".format(vm, name)),
+            target=os.path.join(target, f"{vm}-{name}.zfsds"),
         )
         res = __salt__["cmd.run_all"](cmd, python_shell=True)
         retcode = res["retcode"]
@@ -839,12 +841,12 @@ def receive(uuid, source):
     if not os.path.isdir(source):
         ret["Error"] = "Source must be a directory or host"
         return ret
-    if not os.path.exists(os.path.join(source, "{}.vmdata".format(uuid))):
-        ret["Error"] = "Unknow vm with uuid in {}".format(source)
+    if not os.path.exists(os.path.join(source, f"{uuid}.vmdata")):
+        ret["Error"] = f"Unknow vm with uuid in {source}"
         return ret
     # vmadm receive
     cmd = "vmadm receive < {source}".format(
-        source=os.path.join(source, "{}.vmdata".format(uuid))
+        source=os.path.join(source, f"{uuid}.vmdata")
     )
     res = __salt__["cmd.run_all"](cmd, python_shell=True)
     retcode = res["retcode"]
@@ -861,14 +863,14 @@ def receive(uuid, source):
         name = name[-1]
         cmd = "zfs receive {dataset} < {source}".format(
             dataset=dataset,
-            source=os.path.join(source, "{}-{}.zfsds".format(uuid, name)),
+            source=os.path.join(source, f"{uuid}-{name}.zfsds"),
         )
         res = __salt__["cmd.run_all"](cmd, python_shell=True)
         retcode = res["retcode"]
         if retcode != 0:
             ret["Error"] = res["stderr"] if "stderr" in res else _exit_status(retcode)
             return ret
-    cmd = "vmadm install {}".format(uuid)
+    cmd = f"vmadm install {uuid}"
     res = __salt__["cmd.run_all"](cmd, python_shell=True)
     retcode = res["retcode"]
     if retcode != 0 and not res["stderr"].endswith("datasets"):
