@@ -51,6 +51,7 @@ VALID_UNIT_TYPES = (
     "path",
     "timer",
 )
+SALT_MINION_SERVICE = "salt-minion.service"
 
 # Define the module's virtual name
 __virtualname__ = "service"
@@ -135,12 +136,8 @@ def _check_for_unit_changes(name):
     Check for modified/updated unit files, and run a daemon-reload if any are
     found.
     """
-    contextkey = f"systemd._check_for_unit_changes.{name}"
-    if contextkey not in __context__:
-        if _untracked_custom_unit_found(name) or _unit_file_changed(name):
-            systemctl_reload()
-        # Set context key to avoid repeating this check
-        __context__[contextkey] = True
+    if _untracked_custom_unit_found(name) or _unit_file_changed(name):
+        systemctl_reload()
 
 
 def _check_unmask(name, unmask, unmask_runtime, root=None):
@@ -154,20 +151,6 @@ def _check_unmask(name, unmask, unmask_runtime, root=None):
         unmask_(name, runtime=True, root=root)
 
 
-def _clear_context():
-    """
-    Remove context
-    """
-    # Using list() here because modifying a dictionary during iteration will
-    # raise a RuntimeError.
-    for key in list(__context__):
-        try:
-            if key.startswith("systemd._systemctl_status."):
-                __context__.pop(key)
-        except AttributeError:
-            continue
-
-
 def _default_runlevel():
     """
     Try to figure out the default runlevel.  It is kept in
@@ -326,7 +309,9 @@ def _strip_scope(msg):
     return "\n".join(ret).strip()
 
 
-def _systemctl_cmd(action, name=None, systemd_scope=False, no_block=False, root=None):
+def _systemctl_cmd(
+    action, name=None, systemd_scope=False, no_block=False, root=None, extra_args=None
+):
     """
     Build a systemctl command line. Treat unit names without one
     of the valid suffixes as a service.
@@ -350,24 +335,21 @@ def _systemctl_cmd(action, name=None, systemd_scope=False, no_block=False, root=
         ret.append(_canonical_unit_name(name))
     if "status" in ret:
         ret.extend(["-n", "0"])
+    if isinstance(extra_args, list):
+        ret.extend(extra_args)
     return ret
 
 
 def _systemctl_status(name):
     """
-    Helper function which leverages __context__ to keep from running 'systemctl
-    status' more than once.
+    Helper function to run 'systemctl status'.
     """
-    contextkey = "systemd._systemctl_status.%s" % name
-    if contextkey in __context__:
-        return __context__[contextkey]
-    __context__[contextkey] = __salt__["cmd.run_all"](
+    return __salt__["cmd.run_all"](
         _systemctl_cmd("status", name),
         python_shell=False,
         redirect_stderr=True,
         ignore_retcode=True,
     )
-    return __context__[contextkey]
 
 
 def _sysv_enabled(name, root):
@@ -403,6 +385,26 @@ def _unit_file_changed(name):
     return "'systemctl daemon-reload'" in status
 
 
+def _salt_minion_service(name):
+    """
+    Returns True if the service name is the salt-minion service, otherwise
+    returns False.
+    """
+    return _canonical_unit_name(name) == SALT_MINION_SERVICE
+
+
+def _no_block_default(name, no_block):
+    """
+    Return the default value for no_block if it is not set.
+
+    Defaults to True if the service is the salt-minion service, otherwise
+    defaults to False.
+    """
+    if no_block is None:
+        return True if _salt_minion_service(name) else False
+    return no_block
+
+
 def systemctl_reload():
     """
     .. versionadded:: 0.15.0
@@ -424,7 +426,6 @@ def systemctl_reload():
         raise CommandExecutionError(
             "Problem performing systemctl daemon-reload: %s" % out["stdout"]
         )
-    _clear_context()
     return True
 
 
@@ -870,7 +871,7 @@ def start(name, no_block=False, unmask=False, unmask_runtime=False):
     return True
 
 
-def stop(name, no_block=False):
+def stop(name, no_block=None):
     """
     .. versionchanged:: 2015.8.12,2016.3.3,2016.11.0
         On minions running systemd>=205, `systemd-run(1)`_ is now used to
@@ -886,16 +887,24 @@ def stop(name, no_block=False):
     Stop the specified service with systemd
 
     no_block : False
-        Set to ``True`` to start the service using ``--no-block``.
+        Set to ``True`` to stop the service using ``--no-block``.
+        Defaults to ``True`` for the salt-minion service.
 
         .. versionadded:: 2017.7.0
 
+        .. versionchanged:: 3006.15
+            The default value for this argument has changed if the service is
+            the salt-minion service, where it now defaults to ``True`` to
+            prevent a deadlock with the minion waiting for the service to stop
+            before exiting.
+
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' service.stop <service name>
     """
+    no_block = _no_block_default(name, no_block)
     _check_for_unit_changes(name)
     # Using cmd.run_all instead of cmd.retcode here to make unit tests easier
     return (
@@ -907,7 +916,7 @@ def stop(name, no_block=False):
     )
 
 
-def restart(name, no_block=False, unmask=False, unmask_runtime=False):
+def restart(name, no_block=None, unmask=False, unmask_runtime=False):
     """
     .. versionchanged:: 2015.8.12,2016.3.3,2016.11.0
         On minions running systemd>=205, `systemd-run(1)`_ is now used to
@@ -923,10 +932,17 @@ def restart(name, no_block=False, unmask=False, unmask_runtime=False):
     Restart the specified service with systemd
 
     no_block : False
-        Set to ``True`` to start the service using ``--no-block``.
+        Set to ``True`` to restart the service using ``--no-block``.
+        Defaults to ``True`` for the salt-minion service.
 
         .. versionadded:: 2017.7.0
 
+        .. versionchanged:: 3006.15
+            The default value for this argument has changed if the service is
+            the salt-minion service, where it now defaults to ``True``
+            to prevent a deadlock with the minion waiting for the service to
+            stop before exiting.
+
     unmask : False
         Set to ``True`` to remove an indefinite mask before attempting to
         restart the service.
@@ -949,6 +965,7 @@ def restart(name, no_block=False, unmask=False, unmask_runtime=False):
 
         salt '*' service.restart <service name>
     """
+    no_block = _no_block_default(name, no_block)
     _check_for_unit_changes(name)
     _check_unmask(name, unmask, unmask_runtime)
     ret = __salt__["cmd.run_all"](
@@ -1039,7 +1056,7 @@ def force_reload(name, no_block=True, unmask=False, unmask_runtime=False):
     Force-reload the specified service with systemd
 
     no_block : False
-        Set to ``True`` to start the service using ``--no-block``.
+        Set to ``True`` to force_reload the service using ``--no-block``.
 
         .. versionadded:: 2017.7.0
 
@@ -1146,7 +1163,7 @@ def enable(
     Enable the named service to start when the system boots
 
     no_block : False
-        Set to ``True`` to start the service using ``--no-block``.
+        Set to ``True`` to enable the service using ``--no-block``.
 
         .. versionadded:: 2017.7.0
 
@@ -1227,7 +1244,7 @@ def disable(
     Disable the named service to not start when the system boots
 
     no_block : False
-        Set to ``True`` to start the service using ``--no-block``.
+        Set to ``True`` to disable the service using ``--no-block``.
 
         .. versionadded:: 2017.7.0
 
@@ -1286,15 +1303,27 @@ def enabled(name, root=None, **kwargs):  # pylint: disable=unused-argument
     # Try 'systemctl is-enabled' first, then look for a symlink created by
     # systemctl (older systemd releases did not support using is-enabled to
     # check templated services), and lastly check for a sysvinit service.
-    if (
-        __salt__["cmd.retcode"](
-            _systemctl_cmd("is-enabled", name, root=root),
-            python_shell=False,
-            ignore_retcode=True,
-        )
-        == 0
-    ):
+    cmd_result = __salt__["cmd.run_all"](
+        _systemctl_cmd("is-enabled", name, root=root),
+        python_shell=False,
+        ignore_retcode=True,
+    )
+    if cmd_result["retcode"] == 0 and cmd_result["stdout"] != "alias":
         return True
+    elif cmd_result["stdout"] == "alias":
+        # check the service behind the alias
+        aliased_name = __salt__["cmd.run_stdout"](
+            _systemctl_cmd("show", name, root=root, extra_args=["-P", "Id"]),
+            python_shell=False,
+        )
+        if (
+            __salt__["cmd.retcode"](
+                _systemctl_cmd("is-enabled", aliased_name, root=root),
+                python_shell=False,
+                ignore_retcode=True,
+            )
+        ) == 0:
+            return True
     elif "@" in name:
         # On older systemd releases, templated services could not be checked
         # with ``systemctl is-enabled``. As a fallback, look for the symlinks
