@@ -104,7 +104,7 @@ def _post_message(message, chat_id, token):
     :param token:       The Telegram API token.
     :return:            Boolean if message was sent successfully.
     """
-    url = "https://api.telegram.org/bot{}/sendMessage".format(token)
+    url = f"https://api.telegram.org/bot{token}/sendMessage"
 
     parameters = dict()
     if chat_id:
@@ -113,10 +113,10 @@ def _post_message(message, chat_id, token):
         parameters["text"] = message
 
     try:
-        response = requests.post(url, data=parameters)
+        response = requests.post(url, data=parameters, timeout=120)
         result = response.json()
 
-        log.debug("Raw response of the telegram request is {}".format(response))
+        log.debug("Raw response of the telegram request is %s", response)
 
     except Exception:  # pylint: disable=broad-except
         log.exception("Sending telegram api request failed")
@@ -125,9 +125,9 @@ def _post_message(message, chat_id, token):
     # Check if the Telegram Bot API returned successfully.
     if not result.get("ok", False):
         log.debug(
-            "Sending telegram api request failed due to error {} ({})".format(
-                result.get("error_code"), result.get("description")
-            )
+            "Sending telegram api request failed due to error %s (%s)",
+            result.get("error_code"),
+            result.get("description"),
         )
         return False
 
