@@ -285,6 +285,8 @@ from salt.modules.state import _check_queue, _prior_running_states, _wait, runni
 
 __func_alias__ = {"apply_": "apply"}
 
+__virtualname__ = "transactional_update"
+
 log = logging.getLogger(__name__)
 
 
@@ -300,7 +302,7 @@ def __virtual__():
             _prior_running_states, globals()
         )
         running = salt.utils.functools.namespaced_function(running, globals())
-        return True
+        return __virtualname__
     else:
         return (False, "Module transactional_update requires a transactional system")
 
@@ -971,7 +973,7 @@ def call(function, *args, **kwargs):
                 return local.get("return", local)
             else:
                 return local
-        except ValueError:
+        except (ValueError, AttributeError):
             return {"result": False, "retcode": 1, "comment": ret_stdout}
     finally:
         # Check if reboot is needed
