@@ -37,6 +37,12 @@ from salt.utils.versions import Version
 
 log = logging.getLogger(__name__)
 
+__deprecated__ = (
+    3009,
+    "zabbix",
+    "https://github.com/salt-extensions/saltext-zabbix",
+)
+
 INTERFACE_DEFAULT_PORTS = [10050, 161, 623, 12345]
 
 ZABBIX_TOP_LEVEL_OBJECTS = (
@@ -189,11 +195,9 @@ def _query(method, params, url, auth=None):
             )
         return ret
     except ValueError as err:
-        raise SaltException(
-            "URL or HTTP headers are probably not correct! ({})".format(err)
-        )
+        raise SaltException(f"URL or HTTP headers are probably not correct! ({err})")
     except OSError as err:
-        raise SaltException("Check hostname in URL! ({})".format(err))
+        raise SaltException(f"Check hostname in URL! ({err})")
 
 
 def _login(**kwargs):
@@ -232,9 +236,9 @@ def _login(**kwargs):
                     name = name[len(prefix) :]
                 except IndexError:
                     return
-            val = __salt__["config.get"]("zabbix.{}".format(name), None) or __salt__[
+            val = __salt__["config.get"](f"zabbix.{name}", None) or __salt__[
                 "config.get"
-            ]("zabbix:{}".format(name), None)
+            ](f"zabbix:{name}", None)
             if val is not None:
                 connargs[key] = val
 
@@ -258,7 +262,7 @@ def _login(**kwargs):
         else:
             raise KeyError
     except KeyError as err:
-        raise SaltException("URL is probably not correct! ({})".format(err))
+        raise SaltException(f"URL is probably not correct! ({err})")
 
 
 def _params_extend(params, _ignore_name=False, **kwargs):
@@ -2143,7 +2147,7 @@ def usermacro_get(
     hostmacroids=None,
     globalmacroids=None,
     globalmacro=False,
-    **connection_args
+    **connection_args,
 ):
     """
     Retrieve user macros according to the given parameters.
