@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display clean output of an overstate stage
 ==========================================
@@ -7,15 +6,8 @@ This outputter is used to display :ref:`Orchestrate Runner
 <orchestrate-runner>` stages, and should not be called directly.
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import Salt libs
 import salt.utils.color
 
-# Import 3rd-party libs
-from salt.ext import six
-
 # [{'group2': {'match': ['fedora17-2', 'fedora17-3'],
 #              'require': ['group1'],
 #              'sls': ['nginx', 'edit']}
@@ -32,10 +24,10 @@ def output(data, **kwargs):  # pylint: disable=unused-argument
     )
     ostr = ""
     for comp in data:
-        for name, stage in six.iteritems(comp):
-            ostr += "{0}{1}: {2}\n".format(colors["LIGHT_BLUE"], name, colors["ENDC"])
+        for name, stage in comp.items():
+            ostr += "{}{}: {}\n".format(colors["LIGHT_BLUE"], name, colors["ENDC"])
             for key in sorted(stage):
-                ostr += "    {0}{1}: {2}{3}\n".format(
+                ostr += "    {}{}: {}{}\n".format(
                     colors["LIGHT_BLUE"], key, stage[key], colors["ENDC"]
                 )
     return ostr
