@@ -13,6 +13,7 @@ import collections
 import ctypes
 import logging
 import os
+import subprocess
 from ctypes import wintypes
 
 # pylint: disable=3rd-party-module-not-gated
@@ -39,8 +40,19 @@ SYSTEM_SID = "S-1-5-18"
 LOCAL_SRV_SID = "S-1-5-19"
 NETWORK_SRV_SID = "S-1-5-19"
 
+# STARTUPINFO
+STARTF_USESHOWWINDOW = 0x00000001
+STARTF_USESTDHANDLES = 0x00000100
+
+# dwLogonFlags
 LOGON_WITH_PROFILE = 0x00000001
 
+# Process Creation Flags
+CREATE_NEW_CONSOLE = 0x00000010
+CREATE_NO_WINDOW = 0x08000000
+CREATE_SUSPENDED = 0x00000004
+CREATE_UNICODE_ENVIRONMENT = 0x00000400
+
 WINSTA_ALL = (
     win32con.WINSTA_ACCESSCLIPBOARD
     | win32con.WINSTA_ACCESSGLOBALATOMS
@@ -185,7 +197,12 @@ class HANDLE(wintypes.HANDLE):
 
     def Close(self, CloseHandle=kernel32.CloseHandle):
         if self and not getattr(self, "closed", False):
-            CloseHandle(self.Detach())
+            try:
+                CloseHandle(self.Detach())
+            except OSError:
+                # Suppress the error when there is no handle (WinError 6)
+                if ctypes.get_last_error() == 6:
+                    pass
 
     __del__ = Close
 
@@ -1086,7 +1103,6 @@ def set_user_perm(obj, perm, sid):
     sd = win32security.GetUserObjectSecurity(obj, info)
     dacl = sd.GetSecurityDescriptorDacl()
     ace_cnt = dacl.GetAceCount()
-    found = False
     for idx in range(0, ace_cnt):
         (aceType, aceFlags), ace_mask, ace_sid = dacl.GetAce(idx)
         ace_exists = (
@@ -1142,7 +1158,7 @@ def CreateProcessWithTokenW(
         startupinfo = STARTUPINFO()
     if currentdirectory is not None:
         currentdirectory = ctypes.create_unicode_buffer(currentdirectory)
-    if environment is not None:
+    if environment is not None and isinstance(environment, dict):
         environment = ctypes.pointer(environment_string(environment))
     process_info = PROCESS_INFORMATION()
     ret = advapi32.CreateProcessWithTokenW(
@@ -1314,7 +1330,7 @@ def CreateProcessWithLogonW(
         commandline = ctypes.create_unicode_buffer(commandline)
     if startupinfo is None:
         startupinfo = STARTUPINFO()
-    if environment is not None:
+    if environment is not None and isinstance(environment, dict):
         environment = ctypes.pointer(environment_string(environment))
     process_info = PROCESS_INFORMATION()
     advapi32.CreateProcessWithLogonW(
@@ -1331,3 +1347,20 @@ def CreateProcessWithLogonW(
         ctypes.byref(process_info),
     )
     return process_info
+
+
+def prepend_cmd(win_shell, cmd):
+    """
+    Prep cmd when shell is cmd.exe. Always use a command string instead of a list to satisfy
+    both CreateProcess and CreateProcessWithToken.
+
+    cmd must be double-quoted to ensure proper handling of space characters. The first opening
+    quote and the closing quote are stripped automatically by the Win32 API.
+    """
+    if isinstance(cmd, (list, tuple)):
+        args = subprocess.list2cmdline(cmd)
+    else:
+        args = cmd
+    new_cmd = f'{win_shell} /c "{args}"'
+
+    return new_cmd
