@@ -35,6 +35,12 @@ name
 __proxyenabled__ = ["docker"]
 __virtualname__ = "docker"
 
+__deprecated__ = (
+    3009,
+    "docker",
+    "https://github.com/saltstack/saltext-docker",
+)
+
 
 def __virtual__():
     if __opts__.get("proxy", {}).get("proxytype") != __virtualname__:
