@@ -1,14 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 Cheetah Renderer for Salt
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import salt libs
-from salt.ext import six
-
-# Import 3rd party libs
 try:
     from Cheetah.Template import Template
 
@@ -26,7 +19,7 @@ def render(cheetah_data, saltenv="base", sls="", method="xml", **kws):
     if not HAS_LIBS:
         return {}
 
-    if not isinstance(cheetah_data, six.string_types):
+    if not isinstance(cheetah_data, str):
         cheetah_data = cheetah_data.read()
 
     if cheetah_data.startswith("#!"):
@@ -34,4 +27,4 @@ def render(cheetah_data, saltenv="base", sls="", method="xml", **kws):
     if not cheetah_data.strip():
         return {}
 
-    return six.text_type(Template(cheetah_data, searchList=[kws]))
+    return str(Template(cheetah_data, searchList=[kws]))
