@@ -100,11 +100,9 @@ Configuration
 import salt.output
 
 try:
-    from netaddr import IPNetwork
-    from netaddr import IPAddress
-
     # pylint: disable=unused-import,no-name-in-module
     from napalm.base import helpers as napalm_helpers
+    from netaddr import IPAddress, IPNetwork
 
     # pylint: enable=unused-import,no-name-in-module
 
@@ -333,9 +331,7 @@ def neighbors(*asns, **kwargs):
                 )
             )
         if ipnet:
-            title_parts.append(
-                "Selecting neighbors within the IP network: {ipnet}".format(ipnet=ipnet)
-            )
+            title_parts.append(f"Selecting neighbors within the IP network: {ipnet}")
         if kwargs:
             title_parts.append(
                 "Searching for BGP neighbors having the attributes: {attrmap}".format(
@@ -391,12 +387,14 @@ def neighbors(*asns, **kwargs):
                     if "vrf" in display_fields:
                         row["vrf"] = vrf
                     if "connection_stats" in display_fields:
-                        connection_stats = "{state} {active}/{received}/{accepted}/{damped}".format(
-                            state=neighbor.get("connection_state", -1),
-                            active=neighbor.get("active_prefix_count", -1),
-                            received=neighbor.get("received_prefix_count", -1),
-                            accepted=neighbor.get("accepted_prefix_count", -1),
-                            damped=neighbor.get("suppressed_prefix_count", -1),
+                        connection_stats = (
+                            "{state} {active}/{received}/{accepted}/{damped}".format(
+                                state=neighbor.get("connection_state", -1),
+                                active=neighbor.get("active_prefix_count", -1),
+                                received=neighbor.get("received_prefix_count", -1),
+                                accepted=neighbor.get("accepted_prefix_count", -1),
+                                damped=neighbor.get("suppressed_prefix_count", -1),
+                            )
                         )
                         row["connection_stats"] = connection_stats
                     if (
