@@ -61,7 +61,6 @@ run them.  And it will do this every minute, unless there are any jobs that are
 still running from the last time the process_runner task was executed.
 """
 
-
 import salt.loader
 from salt.exceptions import SaltInvocationError
 from salt.utils.event import get_event, tagify
@@ -81,9 +80,9 @@ def insert(queue, items, backend="sqlite"):
         salt-run queue.insert myqueue "['item1', 'item2', 'item3']" backend=sqlite
     """
     queue_funcs = salt.loader.queues(__opts__)
-    cmd = "{}.insert".format(backend)
+    cmd = f"{backend}.insert"
     if cmd not in queue_funcs:
-        raise SaltInvocationError('Function "{}" is not available'.format(cmd))
+        raise SaltInvocationError(f'Function "{cmd}" is not available')
     ret = queue_funcs[cmd](items=items, queue=queue)
     return ret
 
@@ -101,9 +100,9 @@ def delete(queue, items, backend="sqlite"):
         salt-run queue.delete myqueue "['item1', 'item2', 'item3']"
     """
     queue_funcs = salt.loader.queues(__opts__)
-    cmd = "{}.delete".format(backend)
+    cmd = f"{backend}.delete"
     if cmd not in queue_funcs:
-        raise SaltInvocationError('Function "{}" is not available'.format(cmd))
+        raise SaltInvocationError(f'Function "{cmd}" is not available')
     ret = queue_funcs[cmd](items=items, queue=queue)
     return ret
 
@@ -120,9 +119,9 @@ def list_queues(backend="sqlite"):
         salt-run queue.list_queues backend=sqlite
     """
     queue_funcs = salt.loader.queues(__opts__)
-    cmd = "{}.list_queues".format(backend)
+    cmd = f"{backend}.list_queues"
     if cmd not in queue_funcs:
-        raise SaltInvocationError('Function "{}" is not available'.format(cmd))
+        raise SaltInvocationError(f'Function "{cmd}" is not available')
     ret = queue_funcs[cmd]()
     return ret
 
@@ -139,9 +138,9 @@ def list_length(queue, backend="sqlite"):
         salt-run queue.list_length myqueue backend=sqlite
     """
     queue_funcs = salt.loader.queues(__opts__)
-    cmd = "{}.list_length".format(backend)
+    cmd = f"{backend}.list_length"
     if cmd not in queue_funcs:
-        raise SaltInvocationError('Function "{}" is not available'.format(cmd))
+        raise SaltInvocationError(f'Function "{cmd}" is not available')
     ret = queue_funcs[cmd](queue=queue)
     return ret
 
@@ -158,9 +157,9 @@ def list_items(queue, backend="sqlite"):
         salt-run queue.list_items myqueue backend=sqlite
     """
     queue_funcs = salt.loader.queues(__opts__)
-    cmd = "{}.list_items".format(backend)
+    cmd = f"{backend}.list_items"
     if cmd not in queue_funcs:
-        raise SaltInvocationError('Function "{}" is not available'.format(cmd))
+        raise SaltInvocationError(f'Function "{cmd}" is not available')
     ret = queue_funcs[cmd](queue=queue)
     return ret
 
@@ -180,9 +179,9 @@ def pop(queue, quantity=1, backend="sqlite", is_runner=False):
         salt-run queue.pop myqueue all backend=sqlite
     """
     queue_funcs = salt.loader.queues(__opts__)
-    cmd = "{}.pop".format(backend)
+    cmd = f"{backend}.pop"
     if cmd not in queue_funcs:
-        raise SaltInvocationError('Function "{}" is not available'.format(cmd))
+        raise SaltInvocationError(f'Function "{cmd}" is not available')
     ret = queue_funcs[cmd](quantity=quantity, queue=queue, is_runner=is_runner)
     return ret
 
@@ -212,7 +211,7 @@ def process_queue(queue, quantity=1, backend="sqlite", is_runner=False):
                 queue=queue, quantity=quantity, backend=backend, is_runner=is_runner
             )
         except SaltInvocationError as exc:
-            error_txt = "{}".format(exc)
+            error_txt = f"{exc}"
             __jid_event__.fire_event({"errors": error_txt}, "progress")
             return False
 
