@@ -191,7 +191,6 @@ Overriding the alarm values on the resource:
                 threshold: 50.0
 """
 
-
 import copy
 import hashlib
 import logging
@@ -450,7 +449,7 @@ def present(
                 ret["result"] = False
                 return ret
             if "id" not in r:
-                ret["comment"] = "Subnet {} does not exist.".format(i)
+                ret["comment"] = f"Subnet {i} does not exist."
                 ret["result"] = False
                 return ret
             vpc_zone_identifier.append(r["id"])
@@ -830,7 +829,7 @@ def _alarms_present(
                     if "scaling_policy" not in action:
                         scaling_policy_actions_only = False
                     if ":self:" in action:
-                        action = action.replace(":self:", ":{}:".format(name))
+                        action = action.replace(":self:", f":{name}:")
                     new_actions.append(action)
                 info["attributes"][action_type] = new_actions
         # skip alarms that only have actions for scaling policy, if min_size == max_size for this ASG
