@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage Kinesis Streams
 ======================
@@ -57,8 +56,6 @@ pillars or minion config:
 """
 
 # pylint: disable=undefined-variable
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 # Keep pylint from chocking on ret
 import logging
@@ -143,7 +140,7 @@ def present(
     if exists["result"] is False:
         if __opts__["test"]:
             ret["result"] = None
-            comments.append("Kinesis stream {0} would be created".format(name))
+            comments.append(f"Kinesis stream {name} would be created")
             _add_changes(ret, changes_old, changes_new, comments)
             return ret
         else:
@@ -153,16 +150,16 @@ def present(
             if "error" in is_created:
                 ret["result"] = False
                 comments.append(
-                    "Failed to create stream {0}: {1}".format(name, is_created["error"])
+                    "Failed to create stream {}: {}".format(name, is_created["error"])
                 )
                 _add_changes(ret, changes_old, changes_new, comments)
                 return ret
 
-            comments.append("Kinesis stream {0} successfully created".format(name))
+            comments.append(f"Kinesis stream {name} successfully created")
             changes_new["name"] = name
             changes_new["num_shards"] = num_shards
     else:
-        comments.append("Kinesis stream {0} already exists".format(name))
+        comments.append(f"Kinesis stream {name} already exists")
 
     stream_response = __salt__["boto_kinesis.get_stream_when_active"](
         name, region, key, keyid, profile
@@ -170,7 +167,7 @@ def present(
     if "error" in stream_response:
         ret["result"] = False
         comments.append(
-            "Kinesis stream {0}: error getting description: {1}".format(
+            "Kinesis stream {}: error getting description: {}".format(
                 name, stream_response["error"]
             )
         )
@@ -187,7 +184,7 @@ def present(
             if __opts__["test"]:
                 ret["result"] = None
                 comments.append(
-                    "Kinesis stream {0}: retention hours would be updated to {1}".format(
+                    "Kinesis stream {}: retention hours would be updated to {}".format(
                         name, retention_hours
                     )
                 )
@@ -204,7 +201,7 @@ def present(
                 if "error" in retention_updated:
                     ret["result"] = False
                     comments.append(
-                        "Kinesis stream {0}: failed to update retention hours: {1}".format(
+                        "Kinesis stream {}: failed to update retention hours: {}".format(
                             name, retention_updated["error"]
                         )
                     )
@@ -212,7 +209,7 @@ def present(
                     return ret
 
                 comments.append(
-                    "Kinesis stream {0}: retention hours was successfully updated".format(
+                    "Kinesis stream {}: retention hours was successfully updated".format(
                         name
                     )
                 )
@@ -227,7 +224,7 @@ def present(
                 if "error" in stream_response:
                     ret["result"] = False
                     comments.append(
-                        "Kinesis stream {0}: error getting description: {1}".format(
+                        "Kinesis stream {}: error getting description: {}".format(
                             name, stream_response["error"]
                         )
                     )
@@ -237,14 +234,11 @@ def present(
                 stream_details = stream_response["result"]["StreamDescription"]
         else:
             comments.append(
-                "Kinesis stream {0}: retention hours did not require change, already set at {1}".format(
-                    name, old_retention_hours
-                )
+                "Kinesis stream {}: retention hours did not require change, already set"
+                " at {}".format(name, old_retention_hours)
             )
     else:
-        comments.append(
-            "Kinesis stream {0}: did not configure retention hours".format(name)
-        )
+        comments.append(f"Kinesis stream {name}: did not configure retention hours")
 
     # Configure enhanced monitoring
     if enhanced_monitoring is not None:
@@ -277,7 +271,7 @@ def present(
             if __opts__["test"]:
                 ret["result"] = None
                 comments.append(
-                    "Kinesis stream {0}: would enable enhanced monitoring for {1}".format(
+                    "Kinesis stream {}: would enable enhanced monitoring for {}".format(
                         name, enable_metrics
                     )
                 )
@@ -289,7 +283,7 @@ def present(
                 if "error" in metrics_enabled:
                     ret["result"] = False
                     comments.append(
-                        "Kinesis stream {0}: failed to enable enhanced monitoring: {1}".format(
+                        "Kinesis stream {}: failed to enable enhanced monitoring: {}".format(
                             name, metrics_enabled["error"]
                         )
                     )
@@ -297,16 +291,15 @@ def present(
                     return ret
 
                 comments.append(
-                    "Kinesis stream {0}: enhanced monitoring was enabled for shard-level metrics {1}".format(
-                        name, enable_metrics
-                    )
+                    "Kinesis stream {}: enhanced monitoring was enabled for shard-level"
+                    " metrics {}".format(name, enable_metrics)
                 )
 
         if len(disable_metrics) != 0:
             if __opts__["test"]:
                 ret["result"] = None
                 comments.append(
-                    "Kinesis stream {0}: would disable enhanced monitoring for {1}".format(
+                    "Kinesis stream {}: would disable enhanced monitoring for {}".format(
                         name, disable_metrics
                     )
                 )
@@ -318,7 +311,7 @@ def present(
                 if "error" in metrics_disabled:
                     ret["result"] = False
                     comments.append(
-                        "Kinesis stream {0}: failed to disable enhanced monitoring: {1}".format(
+                        "Kinesis stream {}: failed to disable enhanced monitoring: {}".format(
                             name, metrics_disabled["error"]
                         )
                     )
@@ -326,14 +319,14 @@ def present(
                     return ret
 
                 comments.append(
-                    "Kinesis stream {0}: enhanced monitoring was disabled for shard-level metrics {1}".format(
-                        name, disable_metrics
-                    )
+                    "Kinesis stream {}: enhanced monitoring was disabled for"
+                    " shard-level metrics {}".format(name, disable_metrics)
                 )
 
         if len(disable_metrics) == 0 and len(enable_metrics) == 0:
             comments.append(
-                "Kinesis stream {0}: enhanced monitoring did not require change, already set at {1}".format(
+                "Kinesis stream {}: enhanced monitoring did not require change, already"
+                " set at {}".format(
                     name,
                     (
                         old_enhanced_monitoring
@@ -350,9 +343,7 @@ def present(
                 enhanced_monitoring if len(enhanced_monitoring) > 0 else "None"
             )
     else:
-        comments.append(
-            "Kinesis stream {0}: did not configure enhanced monitoring".format(name)
-        )
+        comments.append(f"Kinesis stream {name}: did not configure enhanced monitoring")
 
     # Reshard stream if necessary
     min_hash_key, max_hash_key, full_stream_details = __salt__[
@@ -366,14 +357,13 @@ def present(
             if __opts__["test"]:
                 ret["result"] = None
                 comments.append(
-                    "Kinesis stream {0}: would be resharded from {1} to {2} shards".format(
+                    "Kinesis stream {}: would be resharded from {} to {} shards".format(
                         name, old_num_shards, num_shards
                     )
                 )
             else:
                 log.info(
-                    "Resharding stream from %s to %s shards, this could take "
-                    "a while",
+                    "Resharding stream from %s to %s shards, this could take a while",
                     old_num_shards,
                     num_shards,
                 )
@@ -388,7 +378,7 @@ def present(
                     if "error" in reshard_response:
                         ret["result"] = False
                         comments.append(
-                            "Encountered error while resharding {0}: {1}".format(
+                            "Encountered error while resharding {}: {}".format(
                                 name, reshard_response["error"]
                             )
                         )
@@ -398,7 +388,7 @@ def present(
                     continue_reshard = reshard_response["result"]
 
                 comments.append(
-                    "Kinesis stream {0}: successfully resharded to {1} shards".format(
+                    "Kinesis stream {}: successfully resharded to {} shards".format(
                         name, num_shards
                     )
                 )
@@ -406,13 +396,13 @@ def present(
                 changes_new["num_shards"] = num_shards
         else:
             comments.append(
-                "Kinesis stream {0}: did not require resharding, remains at {1} shards".format(
+                "Kinesis stream {}: did not require resharding, remains at {} shards".format(
                     name, old_num_shards
                 )
             )
     else:
         comments.append(
-            "Kinesis stream {0}: did not reshard, remains at {1} shards".format(
+            "Kinesis stream {}: did not reshard, remains at {} shards".format(
                 name, old_num_shards
             )
         )
@@ -445,11 +435,11 @@ def absent(name, region=None, key=None, keyid=None, profile=None):
 
     exists = __salt__["boto_kinesis.exists"](name, region, key, keyid, profile)
     if exists["result"] is False:
-        ret["comment"] = "Kinesis stream {0} does not exist".format(name)
+        ret["comment"] = f"Kinesis stream {name} does not exist"
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "Kinesis stream {0} would be deleted".format(name)
+        ret["comment"] = f"Kinesis stream {name} would be deleted"
         ret["result"] = None
         return ret
 
@@ -457,14 +447,14 @@ def absent(name, region=None, key=None, keyid=None, profile=None):
         name, region, key, keyid, profile
     )
     if "error" in is_deleted:
-        ret["comment"] = "Failed to delete stream {0}: {1}".format(
+        ret["comment"] = "Failed to delete stream {}: {}".format(
             name, is_deleted["error"]
         )
         ret["result"] = False
     else:
-        ret["comment"] = "Deleted stream {0}".format(name)
-        ret["changes"].setdefault("old", "Stream {0} exists".format(name))
-        ret["changes"].setdefault("new", "Stream {0} deleted".format(name))
+        ret["comment"] = f"Deleted stream {name}"
+        ret["changes"].setdefault("old", f"Stream {name} exists")
+        ret["changes"].setdefault("new", f"Stream {name} deleted")
 
     return ret
 
