@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Installation of Cygwin packages.
 
@@ -10,11 +9,10 @@ or removed.
     dos2unix:
       cyg.installed
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 
-LOG = logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
 
 def __virtual__():
@@ -55,13 +53,10 @@ def installed(name, cyg_arch="x86_64", mirrors=None):
 
     if cyg_arch not in ["x86", "x86_64"]:
         ret["result"] = False
-        ret[
-            "comment"
-        ] = "The 'cyg_arch' argument must\
- be one of 'x86' or 'x86_64'"
+        ret["comment"] = "The 'cyg_arch' argument must be one of 'x86' or 'x86_64'"
         return ret
 
-    LOG.debug("Installed State: Initial Mirror list: {0}".format(mirrors))
+    log.debug("Installed State: Initial Mirror list: %s", mirrors)
 
     if not __salt__["cyg.check_valid_package"](
         name, cyg_arch=cyg_arch, mirrors=mirrors
@@ -77,12 +72,7 @@ def installed(name, cyg_arch="x86_64", mirrors=None):
         return ret
 
     if __opts__["test"]:
-        ret[
-            "comment"
-        ] = "The package {0} would\
- have been installed".format(
-            name
-        )
+        ret["comment"] = f"The package {name} would have been installed"
         return ret
 
     if __salt__["cyg.install"](name, cyg_arch=cyg_arch, mirrors=mirrors):
@@ -125,10 +115,7 @@ def removed(name, cyg_arch="x86_64", mirrors=None):
 
     if cyg_arch not in ["x86", "x86_64"]:
         ret["result"] = False
-        ret[
-            "comment"
-        ] = "The 'cyg_arch' argument must\
- be one of 'x86' or 'x86_64'"
+        ret["comment"] = "The 'cyg_arch' argument must be one of 'x86' or 'x86_64'"
         return ret
 
     if not __salt__["cyg.check_valid_package"](
@@ -144,7 +131,7 @@ def removed(name, cyg_arch="x86_64", mirrors=None):
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "The package {0} would have been removed".format(name)
+        ret["comment"] = f"The package {name} would have been removed"
         return ret
     if __salt__["cyg.uninstall"](name, cyg_arch):
         ret["result"] = True
@@ -185,10 +172,7 @@ def updated(name=None, cyg_arch="x86_64", mirrors=None):
 
     if cyg_arch not in ["x86", "x86_64"]:
         ret["result"] = False
-        ret[
-            "comment"
-        ] = "The 'cyg_arch' argument must\
- be one of 'x86' or 'x86_64'"
+        ret["comment"] = "The 'cyg_arch' argument must be one of 'x86' or 'x86_64'"
         return ret
 
     if __opts__["test"]:
@@ -196,7 +180,7 @@ def updated(name=None, cyg_arch="x86_64", mirrors=None):
         return ret
 
     if not mirrors:
-        LOG.warning("No mirror given, using the default.")
+        log.warning("No mirror given, using the default.")
 
     before = __salt__["cyg.list"](cyg_arch=cyg_arch)
     if __salt__["cyg.update"](cyg_arch, mirrors=mirrors):
@@ -223,7 +207,7 @@ def updated(name=None, cyg_arch="x86_64", mirrors=None):
 # http://stackoverflow.com/a/1165552
 
 
-class DictDiffer(object):
+class DictDiffer:
     """
     Calculate the difference between two dictionaries.
 
@@ -238,9 +222,9 @@ class DictDiffer(object):
         Iitialize the differ.
         """
         self.current_dict, self.past_dict = current_dict, past_dict
-        self.current_keys, self.past_keys = [
+        self.current_keys, self.past_keys = (
             set(d.keys()) for d in (current_dict, past_dict)
-        ]
+        )
         self.intersect = self.current_keys.intersection(self.past_keys)
 
     def same(self):
@@ -265,14 +249,10 @@ class DictDiffer(object):
         """
         Return a set of the keys with changed values.
         """
-        return set(
-            o for o in self.intersect if self.past_dict[o] != self.current_dict[o]
-        )
+        return {o for o in self.intersect if self.past_dict[o] != self.current_dict[o]}
 
     def unchanged(self):
         """
         Return a set of the keys with unchanged values.
         """
-        return set(
-            o for o in self.intersect if self.past_dict[o] == self.current_dict[o]
-        )
+        return {o for o in self.intersect if self.past_dict[o] == self.current_dict[o]}
