@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage chassis via Salt Proxies.
 
@@ -154,16 +153,12 @@ pillar stated above:
 
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 import os
 
 from salt.exceptions import CommandExecutionError
 
 # Import Salt lobs
-from salt.ext import six
 
 # Get logging started
 log = logging.getLogger(__name__)
@@ -246,10 +241,7 @@ def blade_idrac(
             idrac_dhcp = 1
         else:
             idrac_dhcp = 0
-        if (
-            six.text_type(module_network["Network"]["DHCP Enabled"]) == "0"
-            and idrac_dhcp == 1
-        ):
+        if str(module_network["Network"]["DHCP Enabled"]) == "0" and idrac_dhcp == 1:
             ch = {"Old": module_network["Network"]["DHCP Enabled"], "New": idrac_dhcp}
             ret["changes"]["DRAC DHCP"] = ch
 
@@ -425,7 +417,7 @@ def chassis(
     inventory = __salt__[chassis_cmd]("inventory")
 
     if idrac_launch:
-        idrac_launch = six.text_type(idrac_launch)
+        idrac_launch = str(idrac_launch)
 
     current_name = __salt__[chassis_cmd]("get_chassis_name")
     if chassis_name != current_name:
@@ -499,7 +491,7 @@ def chassis(
                     target_power_states[key] = "powerup"
                 if current_power_states[key] != -1 and current_power_states[key]:
                     target_power_states[key] = "powercycle"
-        for k, v in six.iteritems(target_power_states):
+        for k, v in target_power_states.items():
             old = {k: current_power_states[k]}
             new = {k: v}
             if ret["changes"].get("Blade Power States") is None:
@@ -558,7 +550,7 @@ def chassis(
             slot_names = True
 
     powerchange_all_ok = True
-    for k, v in six.iteritems(target_power_states):
+    for k, v in target_power_states.items():
         powerchange_ok = __salt__[chassis_cmd]("server_power", v, module=k)
         if not powerchange_ok:
             powerchange_all_ok = False
@@ -708,9 +700,9 @@ def switch(
 
     if any([password_ret, snmp_ret, net_ret, dhcp_ret]) is False:
         ret["result"] = False
-        ret["comment"] = "There was an error setting the switch {0}.".format(name)
+        ret["comment"] = f"There was an error setting the switch {name}."
 
-    ret["comment"] = "Dell chassis switch {0} was updated.".format(name)
+    ret["comment"] = f"Dell chassis switch {name} was updated."
     return ret
 
 
@@ -763,7 +755,7 @@ def firmware_update(hosts=None, directory=""):
             ret["changes"].update(
                 {
                     "host": {
-                        "comment": "Firmware update submitted for {0}".format(host),
+                        "comment": f"Firmware update submitted for {host}",
                         "success": True,
                     }
                 }
@@ -773,9 +765,9 @@ def firmware_update(hosts=None, directory=""):
             ret["changes"].update(
                 {
                     "host": {
-                        "comment": "FAILED to update firmware for {0}".format(host),
+                        "comment": f"FAILED to update firmware for {host}",
                         "success": False,
-                        "reason": six.text_type(err),
+                        "reason": str(err),
                     }
                 }
             )
