@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage JBoss 7 Application Server via CLI interface
 
@@ -36,21 +35,14 @@ For the sake of brevity, examples for each state assume that jboss_config is con
 
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 import re
 import time
 import traceback
 
-# Import Salt libs
 import salt.utils.dictdiffer as dictdiffer
 from salt.exceptions import CommandExecutionError
 
-# Import 3rd-party libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 
@@ -189,7 +181,7 @@ def datasource_exists(
                 )
         else:
             raise CommandExecutionError(
-                "Unable to handle error: {0}".format(ds_result["failure-description"])
+                "Unable to handle error: {}".format(ds_result["failure-description"])
             )
 
     if ret["result"]:
@@ -257,7 +249,7 @@ def __get_ds_value(dct, key):
     elif dct[key] is None:
         return "undefined"
     else:
-        return six.text_type(dct[key])
+        return str(dct[key])
 
 
 def bindings_exist(name, jboss_config, bindings, profile=None):
@@ -286,7 +278,8 @@ def bindings_exist(name, jboss_config, bindings, profile=None):
 
     """
     log.debug(
-        " ======================== STATE: jboss7.bindings_exist (name: %s) (profile: %s) ",
+        " ======================== STATE: jboss7.bindings_exist (name: %s) (profile:"
+        " %s) ",
         name,
         profile,
     )
@@ -300,7 +293,7 @@ def bindings_exist(name, jboss_config, bindings, profile=None):
 
     has_changed = False
     for key in bindings:
-        value = six.text_type(bindings[key])
+        value = str(bindings[key])
         query_result = __salt__["jboss7.read_simple_binding"](
             binding_name=key, jboss_config=jboss_config, profile=profile
         )
@@ -512,9 +505,10 @@ def __find_deployment(jboss_config, salt_source=None):
                 if result is not None:
                     success = False
                     comment = (
-                        "More than one deployment matches regular expression: {0}. \n"
-                        "For deployments from Salt file system deployments on JBoss are searched to find one that matches regular expression in 'undeploy' parameter.\n"
-                        "Existing deployments: {1}".format(
+                        "More than one deployment matches regular expression: {}. \nFor"
+                        " deployments from Salt file system deployments on JBoss are"
+                        " searched to find one that matches regular expression in"
+                        " 'undeploy' parameter.\nExisting deployments: {}".format(
                             salt_source["undeploy"], ",".join(deployments)
                         )
                     )
@@ -584,7 +578,7 @@ def __get_artifact(salt_source):
 
             except Exception as e:  # pylint: disable=broad-except
                 log.debug(traceback.format_exc())
-                comment = "Unable to manage file: {0}".format(e)
+                comment = f"Unable to manage file: {e}"
 
         else:
             resolved_source = salt_source["target_file"]
@@ -626,9 +620,10 @@ def reloaded(name, jboss_config, timeout=60, interval=5):
     status = __salt__["jboss7.status"](jboss_config)
     if not status["success"] or status["result"] not in ("running", "reload-required"):
         ret["result"] = False
-        ret[
-            "comment"
-        ] = "Cannot reload server configuration, it should be up and in 'running' or 'reload-required' state."
+        ret["comment"] = (
+            "Cannot reload server configuration, it should be up and in 'running' or"
+            " 'reload-required' state."
+        )
         return ret
 
     result = __salt__["jboss7.reload"](jboss_config)
@@ -653,10 +648,10 @@ def reloaded(name, jboss_config, timeout=60, interval=5):
             ret["changes"]["reloaded"] = "configuration"
         else:
             ret["result"] = False
-            ret[
-                "comment"
-            ] = "Could not reload the configuration. Timeout ({0} s) exceeded. ".format(
-                timeout
+            ret["comment"] = (
+                "Could not reload the configuration. Timeout ({} s) exceeded. ".format(
+                    timeout
+                )
             )
             if not status["success"]:
                 ret["comment"] = __append_comment(
@@ -664,7 +659,7 @@ def reloaded(name, jboss_config, timeout=60, interval=5):
                 )
             else:
                 ret["comment"] = __append_comment(
-                    ("Server is in {0} state".format(status["result"])), ret["comment"]
+                    "Server is in {} state".format(status["result"]), ret["comment"]
                 )
     else:
         ret["result"] = False
@@ -677,11 +672,9 @@ def reloaded(name, jboss_config, timeout=60, interval=5):
 
 def __check_dict_contains(dct, dict_name, keys, comment="", result=True):
     for key in keys:
-        if key not in six.iterkeys(dct):
+        if key not in dct.keys():
             result = False
-            comment = __append_comment(
-                "Missing {0} in {1}".format(key, dict_name), comment
-            )
+            comment = __append_comment(f"Missing {key} in {dict_name}", comment)
     return result, comment
 
 
