@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Management of OpenStack Keystone Domains
 ========================================
@@ -27,8 +26,6 @@ Example States
         - name: domain1
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 __virtualname__ = "keystone_domain"
 
 
@@ -37,7 +34,8 @@ def __virtual__():
         return __virtualname__
     return (
         False,
-        "The keystoneng execution module failed to load: shade python module is not available",
+        "The keystoneng execution module failed to load: shade python module is not"
+        " available",
     )
 
 
@@ -66,7 +64,7 @@ def present(name, auth=None, **kwargs):
         if __opts__["test"]:
             ret["result"] = None
             ret["changes"] = kwargs
-            ret["comment"] = "Domain {} will be created.".format(name)
+            ret["comment"] = f"Domain {name} will be created."
             return ret
 
         kwargs["name"] = name
@@ -80,7 +78,7 @@ def present(name, auth=None, **kwargs):
         if __opts__["test"]:
             ret["result"] = None
             ret["changes"] = changes
-            ret["comment"] = "Domain {} will be updated.".format(name)
+            ret["comment"] = f"Domain {name} will be updated."
             return ret
 
         kwargs["domain_id"] = domain.id
@@ -108,7 +106,7 @@ def absent(name, auth=None):
         if __opts__["test"] is True:
             ret["result"] = None
             ret["changes"] = {"name": name}
-            ret["comment"] = "Domain {} will be deleted.".format(name)
+            ret["comment"] = f"Domain {name} will be deleted."
             return ret
 
         __salt__["keystoneng.domain_delete"](name=domain)
