@@ -72,9 +72,10 @@ def installed(name, password, keychain="/Library/Keychains/System.keychain", **k
                 keychain_password=kwargs.get("keychain_password"),
             )
             if "unable" not in out:
-                ret[
-                    "comment"
-                ] += "Found a certificate with the same name but different hash, removing it.\n"
+                ret["comment"] += (
+                    "Found a certificate with the same name but different hash,"
+                    " removing it.\n"
+                )
                 ret["changes"]["uninstalled"] = friendly_name
 
                 # Reset the certs found
@@ -94,9 +95,9 @@ def installed(name, password, keychain="/Library/Keychains/System.keychain", **k
             ret["changes"]["installed"] = friendly_name
         else:
             ret["result"] = False
-            ret["comment"] += "Failed to install {}".format(friendly_name)
+            ret["comment"] += f"Failed to install {friendly_name}"
     else:
-        ret["comment"] += "{} already installed.".format(friendly_name)
+        ret["comment"] += f"{friendly_name} already installed."
 
     return ret
 
@@ -149,9 +150,9 @@ def uninstalled(
             ret["changes"]["uninstalled"] = friendly_name
         else:
             ret["result"] = False
-            ret["comment"] += "Failed to uninstall {}".format(friendly_name)
+            ret["comment"] += f"Failed to uninstall {friendly_name}"
     else:
-        ret["comment"] += "{} already uninstalled.".format(friendly_name)
+        ret["comment"] += f"{friendly_name} already uninstalled."
 
     return ret
 
@@ -174,18 +175,18 @@ def default_keychain(name, domain="user", user=None):
 
     if not os.path.exists(name):
         ret["result"] = False
-        ret["comment"] += "Keychain not found at {}".format(name)
+        ret["comment"] += f"Keychain not found at {name}"
     else:
         out = __salt__["keychain.get_default_keychain"](user, domain)
 
         if name in out:
-            ret["comment"] += "{} was already the default keychain.".format(name)
+            ret["comment"] += f"{name} was already the default keychain."
         else:
             out = __salt__["keychain.set_default_keychain"](name, domain, user)
             if len(out) == 0:
                 ret["changes"]["default"] = name
             else:
                 ret["result"] = False
-                ret["comment"] = "Failed to install keychain. {}".format(out)
+                ret["comment"] = f"Failed to install keychain. {out}"
 
     return ret
