@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Monit state
 ===========
@@ -20,9 +19,6 @@ Manage monit states
     execution module is available.
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 
 def __virtual__():
     """
@@ -44,20 +40,20 @@ def monitor(name):
     try:
         for key, value in result.items():
             if "Running" in value[name]:
-                ret["comment"] = ("{0} is being being monitored.").format(name)
+                ret["comment"] = f"{name} is being being monitored."
                 ret["result"] = True
             else:
                 if __opts__["test"]:
-                    ret["comment"] = "Service {0} is set to be monitored.".format(name)
+                    ret["comment"] = f"Service {name} is set to be monitored."
                     ret["result"] = None
                     return ret
                 __salt__["monit.monitor"](name)
-                ret["comment"] = ("{0} started to be monitored.").format(name)
+                ret["comment"] = f"{name} started to be monitored."
                 ret["changes"][name] = "Running"
                 ret["result"] = True
                 break
     except KeyError:
-        ret["comment"] = ("{0} not found in configuration.").format(name)
+        ret["comment"] = f"{name} not found in configuration."
         ret["result"] = False
 
     return ret
@@ -74,22 +70,20 @@ def unmonitor(name):
     try:
         for key, value in result.items():
             if "Not monitored" in value[name]:
-                ret["comment"] = ("{0} is not being monitored.").format(name)
+                ret["comment"] = f"{name} is not being monitored."
                 ret["result"] = True
             else:
                 if __opts__["test"]:
-                    ret["comment"] = "Service {0} is set to be unmonitored.".format(
-                        name
-                    )
+                    ret["comment"] = f"Service {name} is set to be unmonitored."
                     ret["result"] = None
                     return ret
                 __salt__["monit.unmonitor"](name)
-                ret["comment"] = ("{0} stopped being monitored.").format(name)
+                ret["comment"] = f"{name} stopped being monitored."
                 ret["changes"][name] = "Not monitored"
                 ret["result"] = True
                 break
     except KeyError:
-        ret["comment"] = ("{0} not found in configuration.").format(name)
+        ret["comment"] = f"{name} not found in configuration."
         ret["result"] = False
 
     return ret
