@@ -12,7 +12,6 @@ Example:
       rabbitmq_plugin.enabled: []
 """
 
-
 import logging
 
 from salt.exceptions import CommandExecutionError
@@ -45,11 +44,11 @@ def enabled(name, runas=None):
         plugin_enabled = __salt__["rabbitmq.plugin_is_enabled"](name, runas=runas)
     except CommandExecutionError as err:
         ret["result"] = False
-        ret["comment"] = "Error: {}".format(err)
+        ret["comment"] = f"Error: {err}"
         return ret
 
     if plugin_enabled:
-        ret["comment"] = "Plugin '{}' is already enabled.".format(name)
+        ret["comment"] = f"Plugin '{name}' is already enabled."
         return ret
 
     if not __opts__["test"]:
@@ -57,16 +56,16 @@ def enabled(name, runas=None):
             __salt__["rabbitmq.enable_plugin"](name, runas=runas)
         except CommandExecutionError as err:
             ret["result"] = False
-            ret["comment"] = "Error: {}".format(err)
+            ret["comment"] = f"Error: {err}"
             return ret
     ret["changes"].update({"old": "", "new": name})
 
     if __opts__["test"] and ret["changes"]:
         ret["result"] = None
-        ret["comment"] = "Plugin '{}' is set to be enabled.".format(name)
+        ret["comment"] = f"Plugin '{name}' is set to be enabled."
         return ret
 
-    ret["comment"] = "Plugin '{}' was enabled.".format(name)
+    ret["comment"] = f"Plugin '{name}' was enabled."
     return ret
 
 
@@ -86,11 +85,11 @@ def disabled(name, runas=None):
         plugin_enabled = __salt__["rabbitmq.plugin_is_enabled"](name, runas=runas)
     except CommandExecutionError as err:
         ret["result"] = False
-        ret["comment"] = "Error: {}".format(err)
+        ret["comment"] = f"Error: {err}"
         return ret
 
     if not plugin_enabled:
-        ret["comment"] = "Plugin '{}' is already disabled.".format(name)
+        ret["comment"] = f"Plugin '{name}' is already disabled."
         return ret
 
     if not __opts__["test"]:
@@ -98,14 +97,14 @@ def disabled(name, runas=None):
             __salt__["rabbitmq.disable_plugin"](name, runas=runas)
         except CommandExecutionError as err:
             ret["result"] = False
-            ret["comment"] = "Error: {}".format(err)
+            ret["comment"] = f"Error: {err}"
             return ret
     ret["changes"].update({"old": name, "new": ""})
 
     if __opts__["test"] and ret["changes"]:
         ret["result"] = None
-        ret["comment"] = "Plugin '{}' is set to be disabled.".format(name)
+        ret["comment"] = f"Plugin '{name}' is set to be disabled."
         return ret
 
-    ret["comment"] = "Plugin '{}' was disabled.".format(name)
+    ret["comment"] = f"Plugin '{name}' was disabled."
     return ret
