@@ -12,7 +12,7 @@ Hives
 This is the top level of the registry. They all begin with HKEY.
 
     - HKEY_CLASSES_ROOT (HKCR)
-    - HKEY_CURRENT_USER(HKCU)
+    - HKEY_CURRENT_USER (HKCU)
     - HKEY_LOCAL MACHINE (HKLM)
     - HKEY_USER (HKU)
     - HKEY_CURRENT_CONFIG
@@ -72,6 +72,8 @@ Value:
 import logging
 
 import salt.utils.stringutils
+import salt.utils.win_dacl as dacl
+import salt.utils.win_reg as reg
 
 log = logging.getLogger(__name__)
 
@@ -80,32 +82,6 @@ def __virtual__():
     """
     Load this state if the reg module exists
     """
-    if "reg.read_value" not in __utils__:
-        return (
-            False,
-            "reg state module failed to load: missing util function: reg.read_value",
-        )
-
-    if "reg.set_value" not in __utils__:
-        return (
-            False,
-            "reg state module failed to load: missing util function: reg.set_value",
-        )
-
-    if "reg.delete_value" not in __utils__:
-        return (
-            False,
-            "reg state module failed to load: "
-            "missing util function: reg.delete_value",
-        )
-
-    if "reg.delete_key_recursive" not in __utils__:
-        return (
-            False,
-            "reg state module failed to load: "
-            "missing util function: reg.delete_key_recursive",
-        )
-
     return "reg"
 
 
@@ -140,7 +116,7 @@ def present(
             A string value representing the full path of the key to include the
             HIVE, Key, and all Subkeys. For example:
 
-            ``HKEY_LOCAL_MACHINE\\SOFTWARE\\Salt``
+            ``HKEY_LOCAL_MACHINE\SOFTWARE\Salt``
 
             Valid hive values include:
 
@@ -299,24 +275,24 @@ def present(
     Example:
 
     The following example will set the ``(Default)`` value for the
-    ``SOFTWARE\\Salt`` key in the ``HKEY_CURRENT_USER`` hive to
+    ``SOFTWARE\Salt`` key in the ``HKEY_CURRENT_USER`` hive to
     ``2016.3.1``:
 
     .. code-block:: yaml
 
-        HKEY_CURRENT_USER\\SOFTWARE\\Salt:
+        HKEY_CURRENT_USER\SOFTWARE\Salt:
           reg.present:
             - vdata: 2016.3.1
 
     Example:
 
     The following example will set the value for the ``version`` entry under
-    the ``SOFTWARE\\Salt`` key in the ``HKEY_CURRENT_USER`` hive to
+    the ``SOFTWARE\Salt`` key in the ``HKEY_CURRENT_USER`` hive to
     ``2016.3.1``. The value will be reflected in ``Wow6432Node``:
 
     .. code-block:: yaml
 
-        HKEY_CURRENT_USER\\SOFTWARE\\Salt:
+        HKEY_CURRENT_USER\SOFTWARE\Salt:
           reg.present:
             - vname: version
             - vdata: 2016.3.1
@@ -324,7 +300,7 @@ def present(
     In the above example the path is interpreted as follows:
 
         - ``HKEY_CURRENT_USER`` is the hive
-        - ``SOFTWARE\\Salt`` is the key
+        - ``SOFTWARE\Salt`` is the key
         - ``vname`` is the value name ('version') that will be created under the key
         - ``vdata`` is the data that will be assigned to 'version'
 
@@ -397,22 +373,22 @@ def present(
     hive, key = _parse_key(name)
 
     # Determine what to do
-    reg_current = __utils__["reg.read_value"](
+    reg_current = reg.read_value(
         hive=hive, key=key, vname=vname, use_32bit_registry=use_32bit_registry
     )
 
     # Cast the vdata according to the vtype
-    vdata_decoded = __utils__["reg.cast_vdata"](vdata=vdata, vtype=vtype)
+    vdata_decoded = reg.cast_vdata(vdata=vdata, vtype=vtype)
 
     # Check if the key already exists
     # If so, check perms
     # We check `vdata` and `success` because `vdata` can be None
     if vdata_decoded == reg_current["vdata"] and reg_current["success"]:
-        ret["comment"] = "{} in {} is already present" "".format(
+        ret["comment"] = "{} in {} is already present".format(
             salt.utils.stringutils.to_unicode(vname, "utf-8") if vname else "(Default)",
             salt.utils.stringutils.to_unicode(name, "utf-8"),
         )
-        return __utils__["dacl.check_perms"](
+        return dacl.check_perms(
             obj_name="\\".join([hive, key]),
             obj_type="registry32" if use_32bit_registry else "registry",
             ret=ret,
@@ -424,7 +400,7 @@ def present(
         )
 
     add_change = {
-        "Key": r"{}\{}".format(hive, key),
+        "Key": rf"{hive}\{key}",
         "Entry": "{}".format(
             salt.utils.stringutils.to_unicode(vname, "utf-8") if vname else "(Default)"
         ),
@@ -438,10 +414,11 @@ def present(
     if __opts__["test"]:
         ret["result"] = None
         ret["changes"] = {"reg": {"Will add": add_change}}
+        ret["comment"] = rf"Will add {vname} to {hive}\{key}"
         return ret
 
     # Configure the value
-    ret["result"] = __utils__["reg.set_value"](
+    ret["result"] = reg.set_value(
         hive=hive,
         key=key,
         vname=vname,
@@ -452,13 +429,13 @@ def present(
 
     if not ret["result"]:
         ret["changes"] = {}
-        ret["comment"] = r"Failed to add {} to {}\{}".format(vname, hive, key)
+        ret["comment"] = rf"Failed to add {vname} to {hive}\{key}"
     else:
         ret["changes"] = {"reg": {"Added": add_change}}
-        ret["comment"] = r"Added {} to {}\{}".format(vname, hive, key)
+        ret["comment"] = rf"Added {vname} to {hive}\{key}"
 
     if ret["result"]:
-        ret = __utils__["dacl.check_perms"](
+        ret = dacl.check_perms(
             obj_name="\\".join([hive, key]),
             obj_type="registry32" if use_32bit_registry else "registry",
             ret=ret,
@@ -481,7 +458,7 @@ def absent(name, vname=None, use_32bit_registry=False):
             A string value representing the full path of the key to include the
             HIVE, Key, and all Subkeys. For example:
 
-            ``HKEY_LOCAL_MACHINE\\SOFTWARE\\Salt``
+            ``HKEY_LOCAL_MACHINE\SOFTWARE\Salt``
 
             Valid hive values include:
 
@@ -505,7 +482,7 @@ def absent(name, vname=None, use_32bit_registry=False):
 
         .. code-block:: yaml
 
-            'HKEY_CURRENT_USER\\SOFTWARE\\Salt':
+            'HKEY_CURRENT_USER\SOFTWARE\Salt':
               reg.absent
                 - vname: version
 
@@ -518,15 +495,15 @@ def absent(name, vname=None, use_32bit_registry=False):
     hive, key = _parse_key(name)
 
     # Determine what to do
-    reg_check = __utils__["reg.read_value"](
+    reg_check = reg.read_value(
         hive=hive, key=key, vname=vname, use_32bit_registry=use_32bit_registry
     )
     if not reg_check["success"] or reg_check["vdata"] == "(value not set)":
-        ret["comment"] = "{} is already absent".format(name)
+        ret["comment"] = f"{name} is already absent"
         return ret
 
     remove_change = {
-        "Key": r"{}\{}".format(hive, key),
+        "Key": rf"{hive}\{key}",
         "Entry": "{}".format(vname if vname else "(Default)"),
     }
 
@@ -534,18 +511,19 @@ def absent(name, vname=None, use_32bit_registry=False):
     if __opts__["test"]:
         ret["result"] = None
         ret["changes"] = {"reg": {"Will remove": remove_change}}
+        ret["comment"] = rf"Will remove {vname} to {hive}\{key}"
         return ret
 
     # Delete the value
-    ret["result"] = __utils__["reg.delete_value"](
+    ret["result"] = reg.delete_value(
         hive=hive, key=key, vname=vname, use_32bit_registry=use_32bit_registry
     )
     if not ret["result"]:
         ret["changes"] = {}
-        ret["comment"] = r"Failed to remove {} from {}".format(key, hive)
+        ret["comment"] = rf"Failed to remove {key} from {hive}"
     else:
         ret["changes"] = {"reg": {"Removed": remove_change}}
-        ret["comment"] = r"Removed {} from {}".format(key, hive)
+        ret["comment"] = rf"Removed {key} from {hive}"
 
     return ret
 
@@ -596,28 +574,29 @@ def key_absent(name, use_32bit_registry=False):
     hive, key = _parse_key(name)
 
     # Determine what to do
-    if not __utils__["reg.read_value"](
-        hive=hive, key=key, use_32bit_registry=use_32bit_registry
-    )["success"]:
-        ret["comment"] = "{} is already absent".format(name)
+    if not reg.read_value(hive=hive, key=key, use_32bit_registry=use_32bit_registry)[
+        "success"
+    ]:
+        ret["comment"] = f"{name} is already absent"
         return ret
 
-    ret["changes"] = {"reg": {"Removed": {"Key": r"{}\{}".format(hive, key)}}}
+    ret["changes"] = {"reg": {"Removed": {"Key": rf"{hive}\{key}"}}}
+    ret["comment"] = rf"Removed {hive}\{key}"
 
     # Check for test option
     if __opts__["test"]:
         ret["result"] = None
+        ret["changes"] = {"reg": {"Will remove": {"Key": rf"{hive}\{key}"}}}
+        ret["comment"] = rf"Will remove {hive}\{key}"
         return ret
 
     # Delete the value
-    __utils__["reg.delete_key_recursive"](
-        hive=hive, key=key, use_32bit_registry=use_32bit_registry
-    )
-    if __utils__["reg.read_value"](
-        hive=hive, key=key, use_32bit_registry=use_32bit_registry
-    )["success"]:
+    reg.delete_key_recursive(hive=hive, key=key, use_32bit_registry=use_32bit_registry)
+    if reg.read_value(hive=hive, key=key, use_32bit_registry=use_32bit_registry)[
+        "success"
+    ]:
         ret["result"] = False
         ret["changes"] = {}
-        ret["comment"] = "Failed to remove registry key {}".format(name)
+        ret["comment"] = f"Failed to remove registry key {name}"
 
     return ret
