@@ -357,7 +357,7 @@ class EtcdClient(EtcdBase):
         index = kwargs.pop("index", None)
         if index is not None:
             salt.utils.versions.warn_until(
-                "Argon",
+                3008,
                 "The index kwarg has been deprecated, and will be removed "
                 "in the Argon release. Please use start_revision instead.",
             )
@@ -447,14 +447,14 @@ class EtcdClient(EtcdBase):
         wait_index = kwargs.pop("waitIndex", None)
         if recursive is not None:
             salt.utils.versions.warn_until(
-                "Argon",
+                3008,
                 "The recursive kwarg has been deprecated, and will be removed "
                 "in the Argon release. Please use recurse instead.",
             )
             recurse = recursive
         if wait_index is not None:
             salt.utils.versions.warn_until(
-                "Argon",
+                3008,
                 "The waitIndex kwarg has been deprecated, and will be removed "
                 "in the Argon release. Please use start_revision instead.",
             )
@@ -611,7 +611,7 @@ class EtcdClient(EtcdBase):
         recursive = kwargs.pop("recursive", None)
         if recursive is not None:
             salt.utils.versions.warn_until(
-                "Argon",
+                3008,
                 "The recursive kwarg has been deprecated, and will be removed "
                 "in the Argon release. Please use recurse instead.",
             )
@@ -740,7 +740,7 @@ class EtcdClientV3(EtcdBase):
         index = kwargs.pop("index", None)
         if index is not None:
             salt.utils.versions.warn_until(
-                "Argon",
+                3008,
                 "The index kwarg has been deprecated, and will be removed "
                 "in the Argon release. Please use start_revision instead.",
             )
@@ -786,14 +786,14 @@ class EtcdClientV3(EtcdBase):
         wait_index = kwargs.pop("waitIndex", None)
         if recursive is not None:
             salt.utils.versions.warn_until(
-                "Argon",
+                3008,
                 "The recursive kwarg has been deprecated, and will be removed "
                 "in the Argon release. Please use recurse instead.",
             )
             recurse = recursive
         if wait_index is not None:
             salt.utils.versions.warn_until(
-                "Argon",
+                3008,
                 "The waitIndex kwarg has been deprecated, and will be removed "
                 "in the Argon release. Please use start_revision instead.",
             )
@@ -890,7 +890,7 @@ class EtcdClientV3(EtcdBase):
         recursive = kwargs.pop("recursive", None)
         if recursive is not None:
             salt.utils.versions.warn_until(
-                "Argon",
+                3008,
                 "The recursive kwarg has been deprecated, and will be removed "
                 "in the Argon release. Please use recurse instead.",
             )
@@ -983,7 +983,7 @@ def get_conn(opts, profile=None, **kwargs):
     use_v2 = conf.get("etcd.require_v2", True)
     if use_v2:
         salt.utils.versions.warn_until(
-            "Potassium",
+            3009,
             "etcd API v2 has been deprecated.  It will be removed in "
             "the Potassium release, and etcd API v3 will be the default.",
         )
