@@ -5,6 +5,7 @@
     Utilities that can only be used on a salt master.
 
 """
+
 import logging
 import os
 import signal
@@ -108,7 +109,7 @@ def _check_cmdline(data):
         return False
     if not os.path.isdir("/proc"):
         return True
-    path = os.path.join("/proc/{}/cmdline".format(pid))
+    path = os.path.join(f"/proc/{pid}/cmdline")
     if not os.path.isfile(path):
         return False
     try:
@@ -160,7 +161,7 @@ class MasterPillarUtil:
         if opts is None:
             log.error("%s: Missing master opts init arg.", self.__class__.__name__)
             raise SaltException(
-                "{}: Missing master opts init arg.".format(self.__class__.__name__)
+                f"{self.__class__.__name__}: Missing master opts init arg."
             )
         else:
             self.opts = opts
@@ -201,7 +202,7 @@ class MasterPillarUtil:
         for minion_id in minion_ids:
             if not salt.utils.verify.valid_id(self.opts, minion_id):
                 continue
-            mdata = self.cache.fetch("minions/{}".format(minion_id), "mine")
+            mdata = self.cache.fetch(f"minions/{minion_id}", "mine")
             if isinstance(mdata, dict):
                 mine_data[minion_id] = mdata
         return mine_data
@@ -219,7 +220,7 @@ class MasterPillarUtil:
         for minion_id in minion_ids:
             if not salt.utils.verify.valid_id(self.opts, minion_id):
                 continue
-            mdata = self.cache.fetch("minions/{}".format(minion_id), "data")
+            mdata = self.cache.fetch(f"minions/{minion_id}", "data")
             if not isinstance(mdata, dict):
                 log.warning(
                     "cache.fetch should always return a dict. ReturnedType: %s,"
@@ -488,7 +489,7 @@ class MasterPillarUtil:
         if clear_mine:
             clear_what.append("mine")
         if clear_mine_func is not None:
-            clear_what.append("mine_func: '{}'".format(clear_mine_func))
+            clear_what.append(f"mine_func: '{clear_mine_func}'")
         if not clear_what:
             log.debug("No cached data types specified for clearing.")
             return False
@@ -514,7 +515,7 @@ class MasterPillarUtil:
                 if minion_id not in c_minions:
                     # Cache bank for this minion does not exist. Nothing to do.
                     continue
-                bank = "minions/{}".format(minion_id)
+                bank = f"minions/{minion_id}"
                 minion_pillar = pillars.pop(minion_id, False)
                 minion_grains = grains.pop(minion_id, False)
                 if (
@@ -822,7 +823,7 @@ def get_master_key(key_user, opts, skip_perm_errors=False):
         # The username may contain '\' if it is in Windows
         # 'DOMAIN\username' format. Fix this for the keyfile path.
         key_user = key_user.replace("\\", "_")
-    keyfile = os.path.join(opts["cachedir"], ".{}_key".format(key_user))
+    keyfile = os.path.join(opts["cachedir"], f".{key_user}_key")
     # Make sure all key parent directories are accessible
     salt.utils.verify.check_path_traversal(opts["cachedir"], key_user, skip_perm_errors)
 
