@@ -1,17 +1,3 @@
-# -*- coding: utf-8 -*-
-# Copyright 2017 Damon Atkins
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#    http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
 r"""
 Collect information about software installed on Windows OS
 ================
@@ -19,22 +5,12 @@ Collect information about software installed on Windows OS
 :maintainer: Salt Stack <https://github.com/saltstack>
 :codeauthor: Damon Atkins <https://github.com/damon-atkins>
 :maturity: new
-:depends: pywin32, six
+:depends: pywin32
 :platform: windows
 
 Known Issue: install_date may not match Control Panel\Programs\Programs and Features
 """
 
-
-# Note although this code will work with Python 2.7, win32api does not
-# support Unicode. i.e non ASCII characters may be returned with unexpected
-# results e.g. a '?' instead of the correct character
-# Python 3.6 or newer is recommended.
-
-# Import _future_ python libs first & before any other code
-# pylint: disable=incompatible-py3-code
-from __future__ import absolute_import, print_function, unicode_literals
-
 import collections
 import datetime
 import locale
@@ -42,26 +18,18 @@ import logging
 import os.path
 import platform
 import re
-
-# Import Standard libs
 import sys
 import time
 from functools import cmp_to_key
 
 __version__ = "0.1"
 
-# Import third party libs
-try:
-    from salt.ext import six
-except ImportError:
-    import six  # pylint: disable=blacklisted-external-import
-
 try:
+    import pywintypes
     import win32api
     import win32con
     import win32process
     import win32security
-    import pywintypes
     import winerror
 
 except ImportError:
@@ -86,16 +54,12 @@ try:
 except ImportError:
     from collections import OrderedDict
 
-try:
-    from salt.utils.versions import LooseVersion
-except ImportError:
-    from distutils.version import LooseVersion  # pylint: disable=blacklisted-module
-
+from salt.utils.versions import Version
 
 # pylint: disable=too-many-instance-attributes
 
 
-class RegSoftwareInfo(object):
+class RegSoftwareInfo:
     """
     Retrieve Registry data on a single installed software item or component.
 
@@ -170,38 +134,42 @@ class RegSoftwareInfo(object):
             self.__reg_32bit_access = (
                 0  # HKEY_USERS does not have a 32bit and 64bit view
             )
-            self.__reg_uninstall_path = (
-                "{0}\\Software\\Microsoft\\Windows\\" "CurrentVersion\\Uninstall\\{1}"
-            ).format(sid, key_guid)
+            self.__reg_uninstall_path = "{}\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{}".format(
+                sid, key_guid
+            )
             if self.__squid:
-                self.__reg_products_path = "{0}\\Software\\Classes\\Installer\\Products\\{1}".format(
-                    sid, self.__squid
+                self.__reg_products_path = (
+                    "{}\\Software\\Classes\\Installer\\Products\\{}".format(
+                        sid, self.__squid
+                    )
                 )
-                self.__reg_upgradecode_path = "{0}\\Software\\Microsoft\\Installer\\UpgradeCodes".format(
-                    sid
+                self.__reg_upgradecode_path = (
+                    f"{sid}\\Software\\Microsoft\\Installer\\UpgradeCodes"
                 )
                 self.__reg_patches_path = (
                     "Software\\Microsoft\\Windows\\CurrentVersion\\Installer\\UserData\\"
-                    "{0}\\Products\\{1}\\Patches"
-                ).format(sid, self.__squid)
+                    "{}\\Products\\{}\\Patches".format(sid, self.__squid)
+                )
         else:
             self.__reg_hive = "HKEY_LOCAL_MACHINE"
             self.__reg_32bit = use_32bit
             self.__reg_32bit_access = self.__use_32bit_lookup[use_32bit]
-            self.__reg_uninstall_path = "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{0}".format(
-                key_guid
+            self.__reg_uninstall_path = (
+                "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{}".format(
+                    key_guid
+                )
             )
             if self.__squid:
-                self.__reg_products_path = "Software\\Classes\\Installer\\Products\\{0}".format(
-                    self.__squid
+                self.__reg_products_path = (
+                    f"Software\\Classes\\Installer\\Products\\{self.__squid}"
                 )
                 self.__reg_upgradecode_path = (
                     "Software\\Classes\\Installer\\UpgradeCodes"
                 )
                 self.__reg_patches_path = (
                     "Software\\Microsoft\\Windows\\CurrentVersion\\Installer\\UserData\\"
-                    "S-1-5-18\\Products\\{0}\\Patches"
-                ).format(self.__squid)
+                    "S-1-5-18\\Products\\{}\\Patches".format(self.__squid)
+                )
 
         # OpenKey is expensive, open in advance and keep it open.
         # This must exist
@@ -306,12 +274,12 @@ class RegSoftwareInfo(object):
         Returns:
             bool: ``True`` if 1 otherwise ``False``.
         """
-        if isinstance(value, six.integer_types) and value == 1:
+        if isinstance(value, int) and value == 1:
             return True
         elif (
-            isinstance(value, six.string_types)
+            isinstance(value, str)
             and re.match(r"\d+", value, flags=re.IGNORECASE + re.UNICODE) is not None
-            and six.text_type(value) == "1"
+            and str(value) == "1"
         ):
             return True
         return False
@@ -335,15 +303,6 @@ class RegSoftwareInfo(object):
         item_value, item_type = win32api.RegQueryValueEx(
             handle, value_name
         )  # pylint: disable=no-member
-        if (
-            six.PY2
-            and isinstance(item_value, six.string_types)
-            and not isinstance(item_value, six.text_type)
-        ):
-            try:
-                item_value = six.text_type(item_value, encoding="mbcs")
-            except UnicodeError:
-                pass
         if item_type == win32con.REG_EXPAND_SZ:
             # expects Unicode input
             win32api.ExpandEnvironmentStrings(item_value)  # pylint: disable=no-member
@@ -484,7 +443,7 @@ class RegSoftwareInfo(object):
 
         # GUID/SQUID are unique, so it does not matter if they are 32bit or
         # 64bit or user install so all items are cached into a single dict
-        have_scan_key = "{0}\\{1}\\{2}".format(
+        have_scan_key = "{}\\{}\\{}".format(
             self.__reg_hive, self.__reg_upgradecode_path, self.__reg_32bit
         )
         if not self.__upgrade_codes or self.__reg_key_guid not in self.__upgrade_codes:
@@ -513,11 +472,13 @@ class RegSoftwareInfo(object):
 
             # Check if we have already scanned these upgrade codes before, and also
             # check if they have been updated in the registry since last time we scanned.
-            if have_scan_key in self.__upgrade_code_have_scan and self.__upgrade_code_have_scan[
-                have_scan_key
-            ] == (
-                squid_upgrade_code_all,
-                suc_pytime,
+            if (
+                have_scan_key in self.__upgrade_code_have_scan
+                and self.__upgrade_code_have_scan[have_scan_key]
+                == (
+                    squid_upgrade_code_all,
+                    suc_pytime,
+                )
             ):
                 log.debug(
                     "Scan skipped for upgrade codes, no changes (%s)", have_scan_key
@@ -600,11 +561,13 @@ class RegSoftwareInfo(object):
             # Scan the patches for the DisplayName of active patches.
             for patch_squid in squid_patch_all:
                 try:
-                    patch_squid_handle = win32api.RegOpenKeyEx(  # pylint: disable=no-member
-                        pat_all_handle,
-                        patch_squid,
-                        0,
-                        win32con.KEY_READ | self.__reg_32bit_access,
+                    patch_squid_handle = (
+                        win32api.RegOpenKeyEx(  # pylint: disable=no-member
+                            pat_all_handle,
+                            patch_squid,
+                            0,
+                            win32con.KEY_READ | self.__reg_32bit_access,
+                        )
                     )
                     (
                         patch_display_name,
@@ -615,7 +578,7 @@ class RegSoftwareInfo(object):
                     )
                     if (
                         patch_state_type != win32con.REG_DWORD
-                        or not isinstance(patch_state_type, six.integer_types)
+                        or not isinstance(patch_state_type, int)
                         or patch_state != 1
                         or patch_display_name_type  # 1 is Active, 2 is Superseded/Obsolute
                         != win32con.REG_SZ
@@ -641,7 +604,7 @@ class RegSoftwareInfo(object):
         Returns:
             str: <hive>\\<uninstall registry entry>
         """
-        return "{0}\\{1}".format(self.__reg_hive, self.__reg_uninstall_path)
+        return f"{self.__reg_hive}\\{self.__reg_uninstall_path}"
 
     @property
     def registry_path(self):
@@ -710,11 +673,11 @@ class RegSoftwareInfo(object):
         version_src = ""
         if item_value:
             if item_type == win32con.REG_DWORD:
-                if isinstance(item_value, six.integer_types):
+                if isinstance(item_value, int):
                     version_binary_raw = item_value
                 if version_binary_raw:
                     # Major.Minor.Build
-                    version_binary_text = "{0}.{1}.{2}".format(
+                    version_binary_text = "{}.{}.{}".format(
                         version_binary_raw >> 24 & 0xFF,
                         version_binary_raw >> 16 & 0xFF,
                         version_binary_raw & 0xFFFF,
@@ -723,7 +686,7 @@ class RegSoftwareInfo(object):
 
             elif (
                 item_type == win32con.REG_SZ
-                and isinstance(item_value, six.string_types)
+                and isinstance(item_value, str)
                 and self.__version_pattern.match(item_value) is not None
             ):
                 # Hey, version should be a int/REG_DWORD, an installer has set
@@ -734,7 +697,7 @@ class RegSoftwareInfo(object):
         return (version_binary_text, version_src)
 
 
-class WinSoftware(object):
+class WinSoftware:
     """
     Point in time snapshot of the software and components installed on
     a system.
@@ -863,7 +826,7 @@ class WinSoftware(object):
         Returns:
             str: Package Id
         """
-        return self.__next__()
+        return next(self)
 
     def get(self, pkg_id, default_value=None):
         """
@@ -883,14 +846,14 @@ class WinSoftware(object):
         """
         Used for sorting version numbers oldest to latest
         """
-        return 1 if LooseVersion(ver1) > LooseVersion(ver2) else -1
+        return 1 if Version(ver1) > Version(ver2) else -1
 
     @staticmethod
-    def __latest_to_oldest_version(ver1, ver2):
+    def __latest_to_oldest_version(ver1, ver2):  # pylint: disable=unused-private-member
         """
         Used for sorting version numbers, latest to oldest
         """
-        return 1 if LooseVersion(ver1) < LooseVersion(ver2) else -1
+        return 1 if Version(ver1) < Version(ver2) else -1
 
     def pkg_version_list(self, pkg_id):
         """
@@ -959,7 +922,7 @@ class WinSoftware(object):
             sid_bin = win32security.GetBinarySid(sid)  # pylint: disable=no-member
         except pywintypes.error as exc:  # pylint: disable=no-member
             raise ValueError(
-                "pkg: Software owned by {0} is not valid: [{1}] {2}".format(
+                "pkg: Software owned by {} is not valid: [{}] {}".format(
                     sid, exc.winerror, exc.strerror
                 )
             )
@@ -967,7 +930,7 @@ class WinSoftware(object):
             name, domain, _account_type = win32security.LookupAccountSid(
                 None, sid_bin
             )  # pylint: disable=no-member
-            user_name = "{0}\\{1}".format(domain, name)
+            user_name = f"{domain}\\{name}"
         except pywintypes.error as exc:  # pylint: disable=no-member
             # if user does not exist...
             # winerror.ERROR_NONE_MAPPED = No mapping between account names and
@@ -978,7 +941,7 @@ class WinSoftware(object):
                 return sid
             else:
                 raise ValueError(
-                    "Failed looking up sid '{0}' username: [{1}] {2}".format(
+                    "Failed looking up sid '{}' username: [{}] {}".format(
                         sid, exc.winerror, exc.strerror
                     )
                 )
@@ -999,7 +962,7 @@ class WinSoftware(object):
                 winerror.ERROR_INVALID_DOMAINNAME,
                 winerror.ERROR_NONE_MAPPED,
             ):
-                return "{0}@{1}".format(name.lower(), domain.lower())
+                return f"{name.lower()}@{domain.lower()}"
             else:
                 raise
         return user_principal
@@ -1077,10 +1040,10 @@ class WinSoftware(object):
                 return version_str, src, version_user_str
             elif src != "use-default":
                 raise ValueError(
-                    "version capture within object '{0}' failed "
-                    "for pkg id: '{1}' it returned '{2}' '{3}' "
-                    "'{4}'".format(
-                        six.text_type(self.__pkg_obj),
+                    "version capture within object '{}' failed "
+                    "for pkg id: '{}' it returned '{}' '{}' "
+                    "'{}'".format(
+                        str(self.__pkg_obj),
                         pkg_id,
                         version_str,
                         src,
@@ -1208,7 +1171,7 @@ class WinSoftware(object):
                     # Not expecting the list to be big, simple search and insert
                     insert_point = 0
                     for ver_item in self.__reg_software[dict_key]:
-                        if LooseVersion(version_text) <= LooseVersion(ver_item):
+                        if Version(version_text) <= Version(ver_item):
                             break
                         insert_point += 1
                     self.__reg_software[dict_key].insert(insert_point, version_text)
@@ -1330,7 +1293,7 @@ class WinSoftware(object):
         # Do not add fields which are blank.
         language_number = reg_soft_info.get_install_value("Language")
         if (
-            isinstance(language_number, six.integer_types)
+            isinstance(language_number, int)
             and language_number in locale.windows_locale
         ):
             version_data.update(
@@ -1385,7 +1348,7 @@ class WinSoftware(object):
         a match in the sub keys, it will return a dict with the
         display name as the key and the version as the value
         .. sectionauthor:: Damon Atkins <https://github.com/damon-atkins>
-        .. versionadded:: Carbon
+        .. versionadded:: 2016.11.0
         """
 
         # FUNCTION MAIN CODE #
@@ -1444,7 +1407,7 @@ class WinSoftware(object):
             if (
                 self.__sid_pattern.match(sid) is not None
             ):  # S-1-5-18 needs to be ignored?
-                user_uninstall_path = "{0}\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall".format(
+                user_uninstall_path = "{}\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall".format(
                     sid
                 )
                 try:
@@ -1474,24 +1437,23 @@ class WinSoftware(object):
 
 def __main():
     """This module can also be run directly for testing
-        Args:
-            detail|list : Provide ``detail`` or version ``list``.
-            system|system+user: System installed and System and User installs.
+    Args:
+        detail|list : Provide ``detail`` or version ``list``.
+        system|system+user: System installed and System and User installs.
     """
     if len(sys.argv) < 3:
-        sys.stderr.write(
-            "usage: {0} <detail|list> <system|system+user>\n".format(sys.argv[0])
-        )
+        sys.stderr.write(f"usage: {sys.argv[0]} <detail|list> <system|system+user>\n")
         sys.exit(64)
     user_pkgs = False
     version_only = False
-    if six.text_type(sys.argv[1]) == "list":
+    if str(sys.argv[1]) == "list":
         version_only = True
-    if six.text_type(sys.argv[2]) == "system+user":
+    if str(sys.argv[2]) == "system+user":
         user_pkgs = True
-    import salt.utils.json
     import timeit
 
+    import salt.utils.json
+
     def run():
         """
         Main run code, when this module is run directly
@@ -1500,10 +1462,10 @@ def __main():
         print(
             salt.utils.json.dumps(pkg_list.data, sort_keys=True, indent=4)
         )  # pylint: disable=superfluous-parens
-        print("Total: {}".format(len(pkg_list)))  # pylint: disable=superfluous-parens
+        print(f"Total: {len(pkg_list)}")  # pylint: disable=superfluous-parens
 
     print(
-        "Time Taken: {}".format(timeit.timeit(run, number=1))
+        f"Time Taken: {timeit.timeit(run, number=1)}"
     )  # pylint: disable=superfluous-parens
 
 
