@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 Utils for proxy.
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
 import salt.utils.platform
