@@ -1,10 +1,5 @@
-# -*- coding: utf-8 -*-
-
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 import re
 
-# Import salt libs
 import salt.utils.files
 import salt.utils.stringutils
 from salt.exceptions import CommandExecutionError
@@ -14,17 +9,17 @@ def key_is_encrypted(key):
     # NOTE: this is a temporary workaround until we can get salt/modules/ssh.py
     # working on Windows.
     try:
-        with salt.utils.files.fopen(key, 'r') as fp_:
+        with salt.utils.files.fopen(key, "r") as fp_:
             key_data = salt.utils.stringutils.to_unicode(fp_.read())
-    except (IOError, OSError) as exc:
+    except OSError as exc:
         # Raise a CommandExecutionError
         salt.utils.files.process_read_exception(exc, key)
 
-    is_private_key = re.search(r'BEGIN (?:\w+\s)*PRIVATE KEY', key_data)
-    is_encrypted = 'ENCRYPTED' in key_data
+    is_private_key = re.search(r"BEGIN (?:\w+\s)*PRIVATE KEY", key_data)
+    is_encrypted = "ENCRYPTED" in key_data
     del key_data
 
     if not is_private_key:
-        raise CommandExecutionError('{0} is not a private key'.format(key))
+        raise CommandExecutionError(f"{key} is not a private key")
 
     return is_encrypted
