@@ -115,7 +115,7 @@ def get_xml_node(node, xpath):
         xpath: simple XPath to look for.
     """
     if not xpath.startswith("./"):
-        xpath = "./{}".format(xpath)
+        xpath = f"./{xpath}"
     res = node.find(xpath)
     if res is None:
         parent_xpath = xpath[: xpath.rfind("/")]
@@ -156,18 +156,24 @@ def clean_node(parent_map, node, ignored=None):
     :param parent_map: dictionary mapping each node to its parent
     :param node: the node to clean
     :param ignored: a list of ignored attributes.
+    :return: True if anything has been removed, False otherwise
     """
     has_text = node.text is not None and node.text.strip()
     parent = parent_map.get(node)
+    removed = False
     if (
         len(node.attrib.keys() - (ignored or [])) == 0
         and not list(node)
         and not has_text
+        and parent
     ):
         parent.remove(node)
+        removed = True
     # Clean parent nodes if needed
     if parent is not None:
-        clean_node(parent_map, parent, ignored)
+        parent_cleaned = clean_node(parent_map, parent, ignored)
+        removed = removed or parent_cleaned
+    return removed
 
 
 def del_text(parent_map, node):
@@ -179,6 +185,7 @@ def del_text(parent_map, node):
     parent = parent_map[node]
     parent.remove(node)
     clean_node(parent, node)
+    return True
 
 
 def del_attribute(attribute, ignored=None):
@@ -196,13 +203,54 @@ def del_attribute(attribute, ignored=None):
 
     def _do_delete(parent_map, node):
         if attribute not in node.keys():
-            return
+            return False
         node.attrib.pop(attribute)
         clean_node(parent_map, node, ignored)
+        return True
 
     return _do_delete
 
 
+def attribute(path, xpath, attr_name, ignored=None, convert=None):
+    """
+    Helper function creating a change_xml mapping entry for a text XML attribute.
+
+    :param path: the path to the value in the data
+    :param xpath: the xpath to the node holding the attribute
+    :param attr_name: the attribute name
+    :param ignored: the list of attributes to ignore when cleaning up the node
+    :param convert: a function used to convert the value
+    """
+    entry = {
+        "path": path,
+        "xpath": xpath,
+        "get": lambda n: n.get(attr_name),
+        "set": lambda n, v: n.set(attr_name, str(v)),
+        "del": salt.utils.xmlutil.del_attribute(attr_name, ignored),
+    }
+    if convert:
+        entry["convert"] = convert
+    return entry
+
+
+def int_attribute(path, xpath, attr_name, ignored=None):
+    """
+    Helper function creating a change_xml mapping entry for a text XML integer attribute.
+
+    :param path: the path to the value in the data
+    :param xpath: the xpath to the node holding the attribute
+    :param attr_name: the attribute name
+    :param ignored: the list of attributes to ignore when cleaning up the node
+    """
+    return {
+        "path": path,
+        "xpath": xpath,
+        "get": lambda n: int(n.get(attr_name)) if n.get(attr_name) else None,
+        "set": lambda n, v: n.set(attr_name, str(v)),
+        "del": salt.utils.xmlutil.del_attribute(attr_name, ignored),
+    }
+
+
 def change_xml(doc, data, mapping):
     """
     Change an XML ElementTree document according.
@@ -236,6 +284,7 @@ def change_xml(doc, data, mapping):
             del
                 function deleting the value in the XML.
                 Takes two parameters for the parent node and the node matched by the XPath.
+                Returns True if anything was removed, False otherwise.
                 Default is to remove the text value.
                 More cleanup may be performed, see the :py:func:`clean_node` function for details.
 
@@ -255,7 +304,7 @@ def change_xml(doc, data, mapping):
         xpath = param["xpath"]
         # Prepend the xpath with ./ to handle the root more easily
         if not xpath.startswith("./"):
-            xpath = "./{}".format(xpath)
+            xpath = f"./{xpath}"
 
         placeholders = [
             s[1:-1]
@@ -280,8 +329,15 @@ def change_xml(doc, data, mapping):
                 continue
 
             if new_value is not None:
+                # We need to increment ids from arrays since xpath starts at 1
+                converters = {
+                    p: ((lambda n: n + 1) if f"[${p}]" in xpath else (lambda n: n))
+                    for p in placeholders
+                }
                 ctx = {
-                    placeholder: value_item.get(placeholder, "")
+                    placeholder: converters[placeholder](
+                        value_item.get(placeholder, "")
+                    )
                     for placeholder in placeholders
                 }
                 node_xpath = string.Template(xpath).substitute(ctx)
@@ -298,7 +354,9 @@ def change_xml(doc, data, mapping):
                 if convert_fn:
                     new_value = convert_fn(new_value)
 
-                if str(current_value) != str(new_value):
+                # Allow custom comparison. Can be useful for almost equal numeric values
+                compare_fn = param.get("equals", lambda o, n: str(o) == str(n))
+                if not compare_fn(current_value, new_value):
                     set_fn(node, new_value)
                     need_update = True
             else:
@@ -306,17 +364,45 @@ def change_xml(doc, data, mapping):
                 del_fn = param.get("del", del_text)
                 parent_map = {c: p for p in doc.iter() for c in p}
                 for node in nodes:
-                    del_fn(parent_map, node)
-                    need_update = True
+                    deleted = del_fn(parent_map, node)
+                    need_update = need_update or deleted
 
         # Clean the left over XML elements if there were placeholders
-        if placeholders and values[0].get("value") != []:
+        if placeholders and [v for v in values if v.get("value") != []]:
             all_nodes = set(doc.findall(all_nodes_xpath))
             to_remove = all_nodes - kept_nodes
             del_fn = param.get("del", del_text)
             parent_map = {c: p for p in doc.iter() for c in p}
             for node in to_remove:
-                del_fn(parent_map, node)
-                need_update = True
-
+                deleted = del_fn(parent_map, node)
+                need_update = need_update or deleted
     return need_update
+
+
+def strip_spaces(node):
+    """
+    Remove all spaces and line breaks before and after nodes.
+    This helps comparing XML trees.
+
+    :param node: the XML node to remove blanks from
+    :return: the node
+    """
+
+    if node.tail is not None:
+        node.tail = node.tail.strip(" \t\n")
+    if node.text is not None:
+        node.text = node.text.strip(" \t\n")
+    try:
+        for child in node:
+            strip_spaces(child)
+    except RecursionError:
+        raise Exception("Failed to recurse on the node")
+
+    return node
+
+
+def element_to_str(node):
+    """
+    Serialize an XML node into a string
+    """
+    return salt.utils.stringutils.to_str(ElementTree.tostring(node))
