@@ -14,6 +14,7 @@ from functools import total_ordering
 MAX_SIZE = sys.maxsize
 VERSION_LIMIT = MAX_SIZE - 200
 
+
 # ----- ATTENTION --------------------------------------------------------------------------------------------------->
 #
 # ALL major version bumps, new release codenames, MUST be defined in the SaltStackVersion.NAMES dictionary, i.e.:
@@ -80,7 +81,7 @@ class SaltVersionsInfo(type):
     SILICON       = SaltVersion("Silicon"      , info=3004,       released=True)
     PHOSPHORUS    = SaltVersion("Phosphorus"   , info=3005,       released=True)
     SULFUR        = SaltVersion("Sulfur"       , info=3006,       released=True)
-    CHLORINE      = SaltVersion("Chlorine"     , info=3007)
+    CHLORINE      = SaltVersion("Chlorine"     , info=3007,       released=True)
     ARGON         = SaltVersion("Argon"        , info=3008)
     POTASSIUM     = SaltVersion("Potassium"    , info=3009)
     CALCIUM       = SaltVersion("Calcium"      , info=3010)
@@ -456,7 +457,7 @@ class SaltStackVersion:
             version_string += f".{self.mbugfix}"
         if self.pre_type:
             version_string += f"{self.pre_type}{self.pre_num}"
-        if self.noc and self.sha:
+        if self.noc is not None and self.sha:
             noc = self.noc
             if noc < 0:
                 noc = "0na"
@@ -615,6 +616,7 @@ def __discover_version(saltstack_version):
                 "--match",
                 "v[0-9]*",
                 "--always",
+                "--candidates=150",
             ],
             **kwargs,
         )
@@ -705,7 +707,8 @@ def dependency_information(include_salt_cloud=False):
         ("msgpack", "msgpack", "version"),
         ("msgpack-pure", "msgpack_pure", "version"),
         ("pycrypto", "Crypto", "__version__"),
-        ("pycryptodome", "Crypto", "version_info"),
+        ("pycryptodome", "Cryptodome", "version_info"),
+        ("cryptography", "cryptography", "__version__"),
         ("PyYAML", "yaml", "__version__"),
         ("PyZMQ", "zmq", "__version__"),
         ("ZMQ", "zmq", "zmq_version"),
