@@ -29,12 +29,11 @@ def __virtual__():
         return __virtualname__
     return (
         False,
-        "The aix_group execution module failed to load: "
-        "only available on AIX systems.",
+        "The aix_group execution module failed to load: only available on AIX systems.",
     )
 
 
-def add(name, gid=None, system=False, root=None):
+def add(name, gid=None, system=False, root=None, **kwargs):
     """
     Add the specified group
 
@@ -49,7 +48,7 @@ def add(name, gid=None, system=False, root=None):
         cmd += "-a "
 
     if gid:
-        cmd += "id={} ".format(gid)
+        cmd += f"id={gid} "
 
     cmd += name
 
@@ -68,7 +67,7 @@ def delete(name):
 
         salt '*' group.delete foo
     """
-    ret = __salt__["cmd.run_all"]("rmgroup {}".format(name), python_shell=False)
+    ret = __salt__["cmd.run_all"](f"rmgroup {name}", python_shell=False)
 
     return not ret["retcode"]
 
@@ -130,7 +129,7 @@ def chgid(name, gid):
     pre_gid = __salt__["file.group_to_gid"](name)
     if gid == pre_gid:
         return True
-    cmd = "chgroup id={} {}".format(gid, name)
+    cmd = f"chgroup id={gid} {name}"
     __salt__["cmd.run"](cmd, python_shell=False)
     post_gid = __salt__["file.group_to_gid"](name)
     if post_gid != pre_gid:
@@ -151,7 +150,7 @@ def adduser(name, username, root=None):
     Verifies if a valid username 'bar' as a member of an existing group 'foo',
     if not then adds it.
     """
-    cmd = "chgrpmem -m + {} {}".format(username, name)
+    cmd = f"chgrpmem -m + {username} {name}"
 
     retcode = __salt__["cmd.retcode"](cmd, python_shell=False)
 
@@ -174,7 +173,7 @@ def deluser(name, username, root=None):
     grp_info = __salt__["group.info"](name)
     try:
         if username in grp_info["members"]:
-            cmd = "chgrpmem -m - {} {}".format(username, name)
+            cmd = f"chgrpmem -m - {username} {name}"
             ret = __salt__["cmd.run"](cmd, python_shell=False)
             return not ret["retcode"]
         else:
@@ -196,7 +195,7 @@ def members(name, members_list, root=None):
     Replaces a membership list for a local group 'foo'.
         foo:x:1234:user1,user2,user3,...
     """
-    cmd = "chgrpmem -m = {} {}".format(members_list, name)
+    cmd = f"chgrpmem -m = {members_list} {name}"
     retcode = __salt__["cmd.retcode"](cmd, python_shell=False)
 
     return not retcode
