@@ -41,6 +41,7 @@ Connection module for Amazon Autoscale Groups
 :depends: boto
 :depends: boto3
 """
+
 # keep lint from choking on _get_conn and _cache_id
 # pylint: disable=E0602
 
@@ -63,9 +64,9 @@ DATE_FORMAT = "%Y-%m-%dT%H:%M:%SZ"
 try:
     import boto
     import boto.ec2
-    import boto.ec2.instance
-    import boto.ec2.blockdevicemapping as blockdevicemapping
     import boto.ec2.autoscale as autoscale
+    import boto.ec2.blockdevicemapping as blockdevicemapping
+    import boto.ec2.instance
 
     logging.getLogger("boto").setLevel(logging.CRITICAL)
     import boto3  # pylint: disable=unused-import
@@ -105,7 +106,9 @@ def exists(name, region=None, key=None, keyid=None, profile=None):
     """
     Check to see if an autoscale group exists.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_asg.exists myasg region=us-east-1
     """
@@ -117,7 +120,7 @@ def exists(name, region=None, key=None, keyid=None, profile=None):
             if _conn:
                 return True
             else:
-                msg = "The autoscale group does not exist in region {}".format(region)
+                msg = f"The autoscale group does not exist in region {region}"
                 log.debug(msg)
                 return False
         except boto.exception.BotoServerError as e:
@@ -134,7 +137,9 @@ def get_config(name, region=None, key=None, keyid=None, profile=None):
     """
     Get the configuration for an autoscale group.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_asg.get_config myasg region=us-east-1
     """
@@ -184,7 +189,7 @@ def get_config(name, region=None, key=None, keyid=None, profile=None):
                 # convert SuspendedProcess objects to names
                 elif attr == "suspended_processes":
                     suspended_processes = getattr(asg, attr)
-                    ret[attr] = sorted([x.process_name for x in suspended_processes])
+                    ret[attr] = sorted(x.process_name for x in suspended_processes)
                 else:
                     ret[attr] = getattr(asg, attr)
             # scaling policies
@@ -259,7 +264,9 @@ def create(
     """
     Create an autoscale group.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_asg.create myasg mylc '["us-east-1a", "us-east-1e"]' 1 10 load_balancers='["myelb", "myelb2"]' tags='[{"key": "Name", value="myasg", "propagate_at_launch": True}]'
     """
@@ -372,7 +379,9 @@ def update(
     """
     Update an autoscale group.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_asg.update myasg mylc '["us-east-1a", "us-east-1e"]' 1 10 load_balancers='["myelb", "myelb2"]' tags='[{"key": "Name", value="myasg", "propagate_at_launch": True}]'
     """
@@ -421,12 +430,12 @@ def update(
                 key = tag.get("key")
             except KeyError:
                 log.error("Tag missing key.")
-                return False, "Tag {} missing key".format(tag)
+                return False, f"Tag {tag} missing key"
             try:
                 value = tag.get("value")
             except KeyError:
                 log.error("Tag missing value.")
-                return False, "Tag {} missing value".format(tag)
+                return False, f"Tag {tag} missing value"
             propagate_at_launch = tag.get("propagate_at_launch", False)
             _tag = {
                 "key": key,
@@ -500,7 +509,7 @@ def update(
                 retries -= 1
                 continue
             log.error(e)
-            msg = "Failed to update ASG {}".format(name)
+            msg = f"Failed to update ASG {name}"
             log.error(msg)
             return False, str(e)
 
@@ -550,7 +559,9 @@ def delete(name, force=False, region=None, key=None, keyid=None, profile=None):
     """
     Delete an autoscale group.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_asg.delete myasg region=us-east-1
     """
@@ -559,7 +570,7 @@ def delete(name, force=False, region=None, key=None, keyid=None, profile=None):
     while True:
         try:
             conn.delete_auto_scaling_group(name, force)
-            msg = "Deleted autoscale group {}.".format(name)
+            msg = f"Deleted autoscale group {name}."
             log.info(msg)
             return True
         except boto.exception.BotoServerError as e:
@@ -569,7 +580,7 @@ def delete(name, force=False, region=None, key=None, keyid=None, profile=None):
                 retries -= 1
                 continue
             log.error(e)
-            msg = "Failed to delete autoscale group {}".format(name)
+            msg = f"Failed to delete autoscale group {name}"
             log.error(msg)
             return False
 
@@ -610,7 +621,9 @@ def launch_configuration_exists(name, region=None, key=None, keyid=None, profile
     """
     Check for a launch configuration's existence.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_asg.launch_configuration_exists mylc
     """
@@ -641,7 +654,9 @@ def get_all_launch_configurations(region=None, key=None, keyid=None, profile=Non
     """
     Fetch and return all Launch Configuration with details.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_asg.get_all_launch_configurations
     """
@@ -664,7 +679,9 @@ def list_launch_configurations(region=None, key=None, keyid=None, profile=None):
     """
     List all Launch Configurations.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_asg.list_launch_configurations
     """
@@ -678,7 +695,9 @@ def describe_launch_configuration(
     """
     Dump details of a given launch configuration.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_asg.describe_launch_configuration mylc
     """
@@ -734,7 +753,9 @@ def create_launch_configuration(
     """
     Create a launch configuration.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_asg.create_launch_configuration mylc image_id=ami-0b9c9f62 key_name='mykey' security_groups='["mygroup"]' instance_type='c3.2xlarge'
     """
@@ -801,7 +822,7 @@ def create_launch_configuration(
                 retries -= 1
                 continue
             log.error(e)
-            msg = "Failed to create LC {}".format(name)
+            msg = f"Failed to create LC {name}"
             log.error(msg)
             return False
 
@@ -810,7 +831,9 @@ def delete_launch_configuration(name, region=None, key=None, keyid=None, profile
     """
     Delete a launch configuration.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_asg.delete_launch_configuration mylc
     """
@@ -828,7 +851,7 @@ def delete_launch_configuration(name, region=None, key=None, keyid=None, profile
                 retries -= 1
                 continue
             log.error(e)
-            msg = "Failed to delete LC {}".format(name)
+            msg = f"Failed to delete LC {name}"
             log.error(msg)
             return False
 
@@ -841,7 +864,9 @@ def get_scaling_policy_arn(
     if not found. Mainly used as a helper method for boto_cloudwatch_alarm, for
     linking alarms to scaling policies.
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' boto_asg.get_scaling_policy_arn mygroup mypolicy
     """
@@ -873,7 +898,7 @@ def get_all_groups(region=None, key=None, keyid=None, profile=None):
 
     .. versionadded:: 2016.11.0
 
-    CLI example:
+    CLI Example:
 
     .. code-block:: bash
 
@@ -908,7 +933,7 @@ def list_groups(region=None, key=None, keyid=None, profile=None):
 
     .. versionadded:: 2016.11.0
 
-    CLI example:
+    CLI Example:
 
     .. code-block:: bash
 
@@ -935,7 +960,9 @@ def get_instances(
     """
     return attribute of all instances in the named autoscale group.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt-call boto_asg.get_instances my_autoscale_group_name
 
@@ -1009,7 +1036,9 @@ def enter_standby(
 
     .. versionadded:: 2016.11.0
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt-call boto_asg.enter_standby my_autoscale_group_name '["i-xxxxxx"]'
 
@@ -1047,7 +1076,9 @@ def exit_standby(
 
     .. versionadded:: 2016.11.0
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt-call boto_asg.exit_standby my_autoscale_group_name '["i-xxxxxx"]'
 
