@@ -1,20 +1,11 @@
-# -*- coding: utf-8 -*-
 """
 Manage Dell DRAC
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
-# Import Salt libs
 import salt.utils.path
 
-# Import 3rd-party libs
-from salt.ext import six
-from salt.ext.six.moves import range
-
 log = logging.getLogger(__name__)
 
 
@@ -51,7 +42,7 @@ def __execute_cmd(command):
     """
     Execute rac commands
     """
-    cmd = __salt__["cmd.run_all"]("racadm {0}".format(command))
+    cmd = __salt__["cmd.run_all"](f"racadm {command}")
 
     if cmd["retcode"] != 0:
         log.warning("racadm return an exit code '%s'.", cmd["retcode"])
@@ -114,10 +105,7 @@ def nameservers(*ns):
 
     for i in range(1, len(ns) + 1):
         if not __execute_cmd(
-            "config -g cfgLanNetworking -o \
-                cfgDNSServer{0} {1}".format(
-                i, ns[i - 1]
-            )
+            f"config -g cfgLanNetworking -o cfgDNSServer{i} {ns[i - 1]}"
         ):
             return False
 
@@ -137,15 +125,9 @@ def syslog(server, enable=True):
         salt dell drac.syslog [SYSLOG IP] [ENABLE/DISABLE]
         salt dell drac.syslog 0.0.0.0 False
     """
-    if enable and __execute_cmd(
-        "config -g cfgRemoteHosts -o \
-                cfgRhostsSyslogEnable 1"
-    ):
+    if enable and __execute_cmd("config -g cfgRemoteHosts -o cfgRhostsSyslogEnable 1"):
         return __execute_cmd(
-            "config -g cfgRemoteHosts -o \
-                cfgRhostsSyslogServer1 {0}".format(
-                server
-            )
+            f"config -g cfgRemoteHosts -o cfgRhostsSyslogServer1 {server}"
         )
 
     return __execute_cmd("config -g cfgRemoteHosts -o cfgRhostsSyslogEnable 0")
@@ -164,15 +146,9 @@ def email_alerts(action):
     """
 
     if action:
-        return __execute_cmd(
-            "config -g cfgEmailAlert -o \
-                cfgEmailAlertEnable -i 1 1"
-        )
+        return __execute_cmd("config -g cfgEmailAlert -o cfgEmailAlertEnable -i 1 1")
     else:
-        return __execute_cmd(
-            "config -g cfgEmailAlert -o \
-                cfgEmailAlertEnable -i 1 0"
-        )
+        return __execute_cmd("config -g cfgEmailAlert -o cfgEmailAlertEnable -i 1 0")
 
 
 def list_users():
@@ -189,12 +165,7 @@ def list_users():
     _username = ""
 
     for idx in range(1, 17):
-        cmd = __salt__["cmd.run_all"](
-            "racadm getconfig -g \
-                cfgUserAdmin -i {0}".format(
-                idx
-            )
-        )
+        cmd = __salt__["cmd.run_all"](f"racadm getconfig -g cfgUserAdmin -i {idx}")
 
         if cmd["retcode"] != 0:
             log.warning("racadm return an exit code '%s'.", cmd["retcode"])
@@ -235,10 +206,7 @@ def delete_user(username, uid=None):
 
     if uid:
         return __execute_cmd(
-            'config -g cfgUserAdmin -o \
-                              cfgUserAdminUserName -i {0} ""'.format(
-                uid
-            )
+            f'config -g cfgUserAdmin -o cfgUserAdminUserName -i {uid} ""'
         )
 
     else:
@@ -265,8 +233,7 @@ def change_password(username, password, uid=None):
 
     if uid:
         return __execute_cmd(
-            "config -g cfgUserAdmin -o \
-                cfgUserAdminPassword -i {0} {1}".format(
+            "config -g cfgUserAdmin -o cfgUserAdminPassword -i {} {}".format(
                 uid, password
             )
         )
@@ -308,17 +275,14 @@ def create_user(username, password, permissions, users=None):
         log.warning("'%s' already exists", username)
         return False
 
-    for idx in six.iterkeys(users):
+    for idx in users.keys():
         _uids.add(users[idx]["index"])
 
     uid = sorted(list(set(range(2, 12)) - _uids), reverse=True).pop()
 
     # Create user accountvfirst
     if not __execute_cmd(
-        "config -g cfgUserAdmin -o \
-                 cfgUserAdminUserName -i {0} {1}".format(
-            uid, username
-        )
+        f"config -g cfgUserAdmin -o cfgUserAdminUserName -i {uid} {username}"
     ):
         delete_user(username, uid)
         return False
@@ -336,12 +300,7 @@ def create_user(username, password, permissions, users=None):
         return False
 
     # Enable users admin
-    if not __execute_cmd(
-        "config -g cfgUserAdmin -o \
-                          cfgUserAdminEnable -i {0} 1".format(
-            uid
-        )
-    ):
+    if not __execute_cmd(f"config -g cfgUserAdmin -o cfgUserAdminEnable -i {uid} 1"):
         delete_user(username, uid)
         return False
 
@@ -397,8 +356,7 @@ def set_permissions(username, permissions, uid=None):
             permission += int(privileges[perm], 16)
 
     return __execute_cmd(
-        "config -g cfgUserAdmin -o \
-            cfgUserAdminPrivilege -i {0} 0x{1:08X}".format(
+        "config -g cfgUserAdmin -o cfgUserAdminPrivilege -i {} 0x{:08X}".format(
             uid, permission
         )
     )
@@ -416,10 +374,7 @@ def set_snmp(community):
         salt dell drac.set_snmp public
     """
     return __execute_cmd(
-        "config -g cfgOobSnmp -o \
-            cfgOobSnmpAgentCommunity {0}".format(
-            community
-        )
+        f"config -g cfgOobSnmp -o cfgOobSnmpAgentCommunity {community}"
     )
 
 
@@ -434,7 +389,7 @@ def set_network(ip, netmask, gateway):
         salt dell drac.set_network [DRAC IP] [NETMASK] [GATEWAY]
         salt dell drac.set_network 192.168.0.2 255.255.255.0 192.168.0.1
     """
-    return __execute_cmd("setniccfg -s {0} {1} {2}".format(ip, netmask, gateway))
+    return __execute_cmd(f"setniccfg -s {ip} {netmask} {gateway}")
 
 
 def server_reboot():
@@ -501,10 +456,7 @@ def server_pxe():
 
         salt dell drac.server_pxe
     """
-    if __execute_cmd(
-        "config -g cfgServerInfo -o \
-            cfgServerFirstBootDevice PXE"
-    ):
+    if __execute_cmd("config -g cfgServerInfo -o cfgServerFirstBootDevice PXE"):
         if __execute_cmd("config -g cfgServerInfo -o cfgServerBootOnce 1"):
             return server_reboot
         else:
