@@ -141,7 +141,6 @@ Delete also accepts a VPC peering connection id.
 
 """
 
-
 import logging
 
 import salt.utils.dictupdate as dictupdate
@@ -228,7 +227,7 @@ def present(
 
     if not r.get("exists"):
         if __opts__["test"]:
-            ret["comment"] = "VPC {} is set to be created.".format(name)
+            ret["comment"] = f"VPC {name} is set to be created."
             ret["result"] = None
             return ret
         r = __salt__["boto_vpc.create"](
@@ -252,7 +251,7 @@ def present(
         )
         ret["changes"]["old"] = {"vpc": None}
         ret["changes"]["new"] = _describe
-        ret["comment"] = "VPC {} created.".format(name)
+        ret["comment"] = f"VPC {name} created."
         return ret
     ret["comment"] = "VPC present."
     return ret
@@ -294,11 +293,11 @@ def absent(name, tags=None, region=None, key=None, keyid=None, profile=None):
 
     _id = r.get("id")
     if not _id:
-        ret["comment"] = "{} VPC does not exist.".format(name)
+        ret["comment"] = f"{name} VPC does not exist."
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "VPC {} is set to be removed.".format(name)
+        ret["comment"] = f"VPC {name} is set to be removed."
         ret["result"] = None
         return ret
     r = __salt__["boto_vpc.delete"](
@@ -310,7 +309,7 @@ def absent(name, tags=None, region=None, key=None, keyid=None, profile=None):
         return ret
     ret["changes"]["old"] = {"vpc": _id}
     ret["changes"]["new"] = {"vpc": None}
-    ret["comment"] = "VPC {} deleted.".format(name)
+    ret["comment"] = f"VPC {name} deleted."
     return ret
 
 
@@ -429,7 +428,7 @@ def dhcp_options_present(
         return ret
     else:
         if __opts__["test"]:
-            ret["comment"] = "DHCP options {} are set to be created.".format(name)
+            ret["comment"] = f"DHCP options {name} are set to be created."
             ret["result"] = None
             return ret
 
@@ -457,7 +456,7 @@ def dhcp_options_present(
 
         ret["changes"]["old"] = {"dhcp_options": None}
         ret["changes"]["new"] = {"dhcp_options": _new}
-        ret["comment"] = "DHCP options {} created.".format(name)
+        ret["comment"] = f"DHCP options {name} created."
         return ret
 
 
@@ -509,11 +508,11 @@ def dhcp_options_absent(
     _id = r.get("id")
 
     if not _id:
-        ret["comment"] = "DHCP options {} do not exist.".format(name)
+        ret["comment"] = f"DHCP options {name} do not exist."
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "DHCP options {} are set to be deleted.".format(name)
+        ret["comment"] = f"DHCP options {name} are set to be deleted."
         ret["result"] = None
         return ret
 
@@ -529,7 +528,7 @@ def dhcp_options_absent(
 
     ret["changes"]["old"] = {"dhcp_options": _id}
     ret["changes"]["new"] = {"dhcp_options": None}
-    ret["comment"] = "DHCP options {} deleted.".format(name)
+    ret["comment"] = f"DHCP options {name} deleted."
     return ret
 
 
@@ -548,7 +547,6 @@ def subnet_present(
     route_table_name=None,
     auto_assign_public_ipv4=False,
 ):
-
     """
     Ensure a subnet exists.
 
@@ -669,7 +667,7 @@ def subnet_present(
 
     if not r.get("exists"):
         if __opts__["test"]:
-            ret["comment"] = "Subnet {} is set to be created.".format(name)
+            ret["comment"] = f"Subnet {name} is set to be created."
             ret["result"] = None
             return ret
         r = __salt__["boto_vpc.create_subnet"](
@@ -694,7 +692,7 @@ def subnet_present(
         )
         ret["changes"]["old"] = {"subnet": None}
         ret["changes"]["new"] = _describe
-        ret["comment"] = "Subnet {} created.".format(name)
+        ret["comment"] = f"Subnet {name} created."
     else:
         ret["comment"] = "Subnet present."
 
@@ -705,7 +703,7 @@ def subnet_present(
             )
         if not _verify_subnet_association(route_table_desc, _describe["subnet"]["id"]):
             if __opts__["test"]:
-                msg = "Subnet is set to be associated with route table {}".format(rtid)
+                msg = f"Subnet is set to be associated with route table {rtid}"
                 ret["comment"] = " ".join([ret["comment"], msg])
                 ret["result"] = None
                 return ret
@@ -743,7 +741,7 @@ def subnet_present(
                 ret["result"] = False
                 return ret
             else:
-                msg = "Subnet successfully associated with route table {}.".format(rtid)
+                msg = f"Subnet successfully associated with route table {rtid}."
                 ret["comment"] = " ".join([ret["comment"], msg])
                 if "new" not in ret["changes"]:
                     ret["changes"]["new"] = __salt__["boto_vpc.describe_subnet"](
@@ -761,7 +759,7 @@ def subnet_present(
             ret["comment"] = " ".join(
                 [
                     ret["comment"],
-                    "Subnet is already associated with route table {}".format(rtid),
+                    f"Subnet is already associated with route table {rtid}",
                 ]
             )
     return ret
@@ -823,7 +821,7 @@ def subnet_absent(
     _id = r.get("id")
 
     if not _id:
-        ret["comment"] = "{} subnet does not exist.".format(name)
+        ret["comment"] = f"{name} subnet does not exist."
         return ret
 
     if __opts__["test"]:
@@ -841,7 +839,7 @@ def subnet_absent(
 
     ret["changes"]["old"] = {"subnet": _id}
     ret["changes"]["new"] = {"subnet": None}
-    ret["comment"] = "Subnet {} deleted.".format(name)
+    ret["comment"] = f"Subnet {name} deleted."
     return ret
 
 
@@ -904,7 +902,7 @@ def internet_gateway_present(
 
     if not r.get("exists"):
         if __opts__["test"]:
-            ret["comment"] = "Internet gateway {} is set to be created.".format(name)
+            ret["comment"] = f"Internet gateway {name} is set to be created."
             ret["result"] = None
             return ret
         r = __salt__["boto_vpc.create_internet_gateway"](
@@ -926,9 +924,9 @@ def internet_gateway_present(
 
         ret["changes"]["old"] = {"internet_gateway": None}
         ret["changes"]["new"] = {"internet_gateway": r["id"]}
-        ret["comment"] = "Internet gateway {} created.".format(name)
+        ret["comment"] = f"Internet gateway {name} created."
         return ret
-    ret["comment"] = "Internet gateway {} present.".format(name)
+    ret["comment"] = f"Internet gateway {name} present."
     return ret
 
 
@@ -977,11 +975,11 @@ def internet_gateway_absent(
 
     igw_id = r["id"]
     if not igw_id:
-        ret["comment"] = "Internet gateway {} does not exist.".format(name)
+        ret["comment"] = f"Internet gateway {name} does not exist."
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "Internet gateway {} is set to be removed.".format(name)
+        ret["comment"] = f"Internet gateway {name} is set to be removed."
         ret["result"] = None
         return ret
     r = __salt__["boto_vpc.delete_internet_gateway"](
@@ -1000,7 +998,7 @@ def internet_gateway_absent(
         return ret
     ret["changes"]["old"] = {"internet_gateway": igw_id}
     ret["changes"]["new"] = {"internet_gateway": None}
-    ret["comment"] = "Internet gateway {} deleted.".format(name)
+    ret["comment"] = f"Internet gateway {name} deleted."
     return ret
 
 
@@ -1162,7 +1160,7 @@ def _route_table_present(
 
     if not _id:
         if __opts__["test"]:
-            msg = "Route table {} is set to be created.".format(name)
+            msg = f"Route table {name} is set to be created."
             ret["comment"] = msg
             ret["result"] = None
             return ret
@@ -1186,9 +1184,9 @@ def _route_table_present(
 
         ret["changes"]["old"] = {"route_table": None}
         ret["changes"]["new"] = {"route_table": r["id"]}
-        ret["comment"] = "Route table {} created.".format(name)
+        ret["comment"] = f"Route table {name} created."
         return ret
-    ret["comment"] = "Route table {} ({}) present.".format(name, _id)
+    ret["comment"] = f"Route table {name} ({_id}) present."
     return ret
 
 
@@ -1247,7 +1245,7 @@ def _routes_present(
                     ret["result"] = False
                     return ret
                 if r["id"] is None:
-                    msg = "Internet gateway {} does not exist.".format(i)
+                    msg = f"Internet gateway {i} does not exist."
                     ret["comment"] = msg
                     ret["result"] = False
                     return ret
@@ -1262,14 +1260,16 @@ def _routes_present(
                     profile=profile,
                 )
                 if "error" in r:
-                    msg = "Error looking up id for VPC peering connection {}: {}".format(
-                        i.get("vpc_peering_connection_name"), r["error"]["message"]
+                    msg = (
+                        "Error looking up id for VPC peering connection {}: {}".format(
+                            i.get("vpc_peering_connection_name"), r["error"]["message"]
+                        )
                     )
                     ret["comment"] = msg
                     ret["result"] = False
                     return ret
                 if r["id"] is None:
-                    msg = "VPC peering connection {} does not exist.".format(i)
+                    msg = f"VPC peering connection {i} does not exist."
                     ret["comment"] = msg
                     ret["result"] = False
                     return ret
@@ -1323,7 +1323,7 @@ def _routes_present(
                 to_delete.append(route)
     if to_create or to_delete:
         if __opts__["test"]:
-            msg = "Route table {} set to have routes modified.".format(route_table_name)
+            msg = f"Route table {route_table_name} set to have routes modified."
             ret["comment"] = msg
             ret["result"] = None
             return ret
@@ -1357,7 +1357,7 @@ def _routes_present(
                     key=key,
                     keyid=keyid,
                     profile=profile,
-                    **r
+                    **r,
                 )
                 if not res["created"]:
                     msg = "Failed to create route {} in route table {}: {}.".format(
@@ -1412,7 +1412,7 @@ def _subnets_present(
                 ret["result"] = False
                 return ret
             if r["id"] is None:
-                msg = "Subnet {} does not exist.".format(i)
+                msg = f"Subnet {i} does not exist."
                 ret["comment"] = msg
                 ret["result"] = False
                 return ret
@@ -1478,8 +1478,10 @@ def _subnets_present(
                     profile=profile,
                 )
                 if "error" in r:
-                    msg = "Failed to associate subnet {} with route table {}: {}.".format(
-                        sn, route_table_name, r["error"]["message"]
+                    msg = (
+                        "Failed to associate subnet {} with route table {}: {}.".format(
+                            sn, route_table_name, r["error"]["message"]
+                        )
                     )
                     ret["comment"] = msg
                     ret["result"] = False
@@ -1534,11 +1536,11 @@ def route_table_absent(name, region=None, key=None, keyid=None, profile=None):
     rtbl_id = r["id"]
 
     if not rtbl_id:
-        ret["comment"] = "Route table {} does not exist.".format(name)
+        ret["comment"] = f"Route table {name} does not exist."
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "Route table {} is set to be removed.".format(name)
+        ret["comment"] = f"Route table {name} is set to be removed."
         ret["result"] = None
         return ret
 
@@ -1553,7 +1555,7 @@ def route_table_absent(name, region=None, key=None, keyid=None, profile=None):
         return ret
     ret["changes"]["old"] = {"route_table": rtbl_id}
     ret["changes"]["new"] = {"route_table": None}
-    ret["comment"] = "Route table {} deleted.".format(name)
+    ret["comment"] = f"Route table {name} deleted."
     return ret
 
 
@@ -1648,7 +1650,7 @@ def nat_gateway_present(
 
     inst = r[0]
     _id = inst.get("NatGatewayId")
-    ret["comment"] = "Nat gateway {} present.".format(_id)
+    ret["comment"] = f"Nat gateway {_id} present."
     return ret
 
 
@@ -1738,9 +1740,7 @@ def nat_gateway_absent(
                 r["error"]["message"]
             )
             return ret
-        ret["comment"] = ", ".join(
-            (ret["comment"], "Nat gateway {} deleted.".format(rtbl_id))
-        )
+        ret["comment"] = ", ".join((ret["comment"], f"Nat gateway {rtbl_id} deleted."))
     ret["changes"]["old"] = {"nat_gateway": rtbl_id}
     ret["changes"]["new"] = {"nat_gateway": None}
     return ret
@@ -1855,6 +1855,7 @@ def request_vpc_peering_connection(
     peer_vpc_name=None,
     conn_name=None,
     peer_owner_id=None,
+    peer_region=None,
     region=None,
     key=None,
     keyid=None,
@@ -1874,7 +1875,7 @@ def request_vpc_peering_connection(
         ID of the VPC tp crete VPC peering connection with.  This can be a VPC in another account. Exclusive with peer_vpc_name. String type.
 
     peer_vpc_name
-        Name tag of the VPC tp crete VPC peering connection with.  This can only be a VPC the same account. Exclusive with peer_vpc_id.  String type.
+        Name tag of the VPC tp crete VPC peering connection with.  This can only be a VPC the same account and region. Exclusive with peer_vpc_id.  String type.
 
     conn_name
         The (optional) name to use for this VPC peering connection. String type.
@@ -1882,6 +1883,11 @@ def request_vpc_peering_connection(
     peer_owner_id
         ID of the owner of the peer VPC. String type. If this isn't supplied AWS uses your account ID.  Required if peering to a different account.
 
+    peer_region
+        Region of peer VPC. For inter-region vpc peering connections. Not required for intra-region peering connections.
+
+        .. versionadded:: 3005
+
     region
         Region to connect to.
 
@@ -1923,7 +1929,7 @@ def request_vpc_peering_connection(
         vpc_ids = []
 
     if vpc_ids:
-        ret["comment"] = "VPC peering connection already exists, " "nothing to be done."
+        ret["comment"] = "VPC peering connection already exists, nothing to be done."
         return ret
 
     if __opts__["test"]:
@@ -1940,6 +1946,7 @@ def request_vpc_peering_connection(
         peer_vpc_name,
         name=conn_name,
         peer_owner_id=peer_owner_id,
+        peer_region=peer_region,
         region=region,
         key=key,
         keyid=keyid,
@@ -1963,6 +1970,7 @@ def vpc_peering_connection_present(
     peer_vpc_name=None,
     conn_name=None,
     peer_owner_id=None,
+    peer_region=None,
     region=None,
     key=None,
     keyid=None,
@@ -1994,6 +2002,12 @@ def vpc_peering_connection_present(
         ID of the owner of the peer VPC. Defaults to your account ID, so a value
         is required if peering with a VPC in a different account.
 
+    peer_region
+        Region of peer VPC. For inter-region vpc peering connections. Not required
+        for intra-region peering connections.
+
+        .. versionadded:: 3005
+
     region
         Region to connect to.
 
@@ -2036,8 +2050,7 @@ def vpc_peering_connection_present(
             profile=profile,
         ):
             ret["comment"] = (
-                "VPC peering {} already requested - pending "
-                "acceptance by {}".format(
+                "VPC peering {} already requested - pending acceptance by {}".format(
                     conn_name, peer_owner_id or peer_vpc_name or peer_vpc_id
                 )
             )
@@ -2059,6 +2072,7 @@ def vpc_peering_connection_present(
         peer_vpc_name=peer_vpc_name,
         conn_name=conn_name,
         peer_owner_id=peer_owner_id,
+        peer_region=peer_region,
         region=region,
         key=key,
         keyid=keyid,
